/*-------------------------------------------------------------------------
 |                                                                         
 |             SAS SUPPLEMENTAL SYNTAX FILE FOR ICPSR 02934
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1998
 |
 | This SAS program is provided for optional use with the SAS transport
 | version of this data file as distributed by ICPSR. The metadata
 | provided below are not stored in the SAS transport version of this data
 | collection.  Users need to use SAS PROC CIMPORT to import the SAS
 | transport file to a SAS data set on their system. This program can
 | then be used in conjunction with the SAS system data file.
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions.  Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set. Users
 | should replace "SAS-dataset" with their name for the SAS data set copied
 | from the SAS transport file. Users can add a SAS libname statement
 | and an output SAS data set name to make a permanent SAS data set.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .;
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables stored in the SAS data set. Users can refer to their
 | SAS manual for information on how to permanently store formats in a
 | SAS catalog.
 |
 | NOTE:  Users should modify this file to suit their specific needs.
 | The MISSING VALUE RECODES section has been commented out (i.e., '/*').
 | To make this section active in the program, users should remove the SAS
 | comment indicators from this section.
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

PROC FORMAT;
  VALUE skpmartl  1='(1) Respondent is 12-14 years old - SKIP'
                  2='(2) Respondent is 15 years old or older'
                  3='(3) 12-14 years old LOGICALLY ASSIGNED - SKI'
                  4='(4) 15 years or older LOGICALLY ASSIGNED' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Never been married' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nomarr2f  1='(1) Married once' 2='(2) Married 2 or more times'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpmilt   1='(1) Respondent is 12-16 years old - SKIP'
                  2='(2) Respondent is 17 years old or older'
                  3='(3) 12-16 years old LOGICALLY ASSIGNED - SKI'
                  4='(4) 17 years or older LOGICALLY ASSIGNED' ;
  VALUE service   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE milstat   2='(2) In a reserves component'
                  3='(3) Now separated or retired from reserves/a'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE educ2fff  5='(5) Fifth grade or less' 6='(6) Sixth grade' 7='(7) Seventh grade'
                  8='(8) Eighth grade' 9='(9) Ninth grade' 10='(10) Tenth grade'
                  11='(11) Eleventh grade' 12='(12) Twelfth grade'
                  13='(13) Freshman/13th year' 14='(14) Sophomore/14th year'
                  15='(15) Junior/15th year' 16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diploma   1='(1) High School Diploma' 2='(2) GED Certificate'
                  3='(3) Neither of the above'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE enroll9f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  51='(51) School not in session (RAW QD12 = 1)'
                  52='(52) School not in session (RAW QD12 = 2)'
                  55='(55) School not in session (RAW QD12 > 2 OR M'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE enrl949f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  5='(5) School not in session (RAW QD12 NOT 2)'
                  11='(11) QD12 marked Yes but QD16 marked not en'
                  15='(15) School not in session (RAW QD12 = 2)'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job but out: illness/leave/furlou'
                  4='(4) Have a job, but it is seasonal'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed and not looking for work'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled, not able to work' 11='(11) Other, not specified'
                  21='(21) Working full-time, 35 hours or more a we'
                  22='(22) Working part-time, less than 35 hours a'
                  23='(23) Have a job but out: illness/leave/furlou'
                  24='(24) Have a job, but it is seasonal'
                  25='(25) Unemployed or laid off and looking for w'
                  26='(26) Unemployed and not looking for work'
                  27='(27) Full-time homemaker' 28='(28) In school only' 29='(29) Retired'
                  30='(30) Disabled, not able to work' 31='(31) Other, in labor force'
                  32='(32) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned' 98='(98) BLANK (NO ANSWER)' ;
  VALUE height2f  55='(55) 55 or under' 75='(75) 75 or over'
                  985='(985) BAD DATA Logically assigned' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE pounds2f  75='(75) 75 or under' 301='(301) Over 300'
                  985='(985) BAD DATA Logically assigned' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE health    1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigtry    981='(981) NEVER USED CIGARETTES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cigtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cig30use  35='(35) Date specified within the past 30 days'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES IN PAST 30 DAYS L'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE avcig     1='(1) At least a puff but less than one cig ea'
                  2='(2) 1 to 5 cigarettes each day'
                  3='(3) 6 to 15 cigarettes (about 1/2 pack) each'
                  4='(4) 16 to 25 cigarettes (about 1 pack) each'
                  5='(5) 26 to 35 cigarettes (about 1 1/2 pk) eac'
                  6='(6) 35 or more cigarettes (about 2 packs) ea'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES PAST 30 DAYS Log'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cig30wok  1='(1) 5 minutes or less' 2='(2) 6 to 30 minutes'
                  3='(3) 31 to 60 minutes' 4='(4) 1 to 3 hours' 5='(5) 4 or more hours'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES IN PAST 30 DAYS L'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigevyda  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigage    981='(981) NEVER USED CIGARETTES Logically assigned'
                  983='(983) NEVER USED CIGARETTES EVERYDAY Log assn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES'
                  993='(993) NEVER USED CIGARETTES EVERYDAY' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cigyrs    0='(0) I smoked cigs every day but only for < o'
                  981='(981) NEVER USED CIGARETTES Logically assigned'
                  983='(983) NEVER USED CIGARETTES EVERYDAY Log assn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES'
                  993='(993) NEVER USED CIGARETTES EVERYDAY' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE snufever  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE snufrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SMOKELESS TOBACCO Logically a'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpalcrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE alctry    981='(981) NEVER USED ALCOHOL Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED ALCOHOL'
                  994='(994) DON''T KNOW' 995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcpat    1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned'
                  90='(90) HAD A DRINK BUT DID NOT GET DRUNK PST 12'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcdays   35='(35) Date specified within the past 30 days'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    0='(0) None' 35='(35) Date specified within the past 30 days'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT DRINK ALCOHOL IN PAST 30 DAYS Lo'
                  85='(85) BAD DATA Logically assigned'
                  90='(90) HAD A DRINK BUT NEVER MORE THAN 5 PAST 3'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjever    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE mjage     981='(981) NEVER USED MARIJUANA Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED MARIJUANA' 994='(994) DON''T KNOW' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjyrfreq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjday30a  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA IN THE PST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpcocrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cocever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE cocage    981='(981) NEVER USED COCAINE Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED COCAINE'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocus30a  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpcrkrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE crkever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkage    981='(981) NEVER USED CRACK Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED CRACK'
                  994='(994) DON''T KNOW' 998='(998) BLANK (NO ANSWER)' ;
  VALUE crktot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED CRACK Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED CRACK Logically assigned'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PAST 12 MONTHS Log a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crkus30a  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpherrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE herever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herage    981='(981) NEVER USED HEROIN Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED HEROIN'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  91='(91) NEVER USED HEROIN' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE heryrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN PAST 12 MONTHS Log as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 12 MONTHS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN IN PAST 30 DAYS Log a'
                  91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skphalrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lsd       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (LSDREC=1,2,3,4 o'
                  4='(4) No LOGICALLY ASSIGNED (LSDREC=81 or 91)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (PCPREC=1,2,3,4 o'
                  4='(4) No LOGICALLY ASSIGNED (PCPREC=81 or 91)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE haldknam  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   112='(112) Rasepam, Restoril, Temaz, Temazepam' 142='(142) Belladona'
                  322='(322) Methamphetamine (speed,ice,crank),'
                  334='(334) Crossroads, Cross tops'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 418='(418) Methadone'
                  501='(501) Gasoline or lighter fluids'
                  504='(504) Shoeshine liq,glue,toluene,Super Glue,ru'
                  506='(506) Amyl nitrate, poppers, locker room odo'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 519='(519) Helium'
                  521='(521) see also 525,544' 524='(524) see also 509' 576='(576) C.A.T'
                  601='(601) LSD (acid, white lightning) [see als' 602='(602) Peyote'
                  604='(604) Psilocybin (mushrooms), shrooms'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 609='(609) sic'
                  612='(612) Happy stick, sherm, sherman, shermstick'
                  614='(614) MDA, Methylenedioxy amphetamine'
                  616='(616) DET, Dimethyltryptamine, DMT'
                  617='(617) Morning glory seeds, morning glory tandr'
                  618='(618) Acid paper, blotter (acid) [see also 601'
                  622='(622) Microdot(s), purple microdot'
                  624='(624) Orange sunshine, sunshine, yellow sunshi'
                  625='(625) Window, window pane' 636='(636) STP' 637='(637) Purple haze'
                  639='(639) Cloves, Nutmeg' 643='(643) Mount queen, queen' 650='(650) Daytura'
                  658='(658) Special K' 679='(679) Hell bells' 680='(680) Tweak'
                  698='(698) Nexus, 2C-B' 703='(703) Opium' 704='(704) Dope'
                  802='(802) THC, cannabinol, marinol' 803='(803) sic' 806='(806) Crack, rock'
                  834='(834) Loveboat'
                  840='(840) Cough medicine (contents not specified)' 847='(847) sic'
                  852='(852) sic' 864='(864) Dramamine <OTC>, Motion sickness pill <O'
                  883='(883) Dextromethorphan Hydrobromide <OTC>' 5009='(5009) Robo'
                  6026='(6026) KJ' 6027='(6027) Judyfly' 6030='(6030) Root' 6031='(6031) Strychnine'
                  6032='(6032) TSP' 6033='(6033) Ramstein' 6035='(6035) Campana (flower)'
                  6037='(6037) Fry' 6038='(6038) Triplets' 6039='(6039) Blue Hawaii' 6040='(6040) Dank'
                  6042='(6042) Super K' 6043='(6043) Salviadivinorum'
                  6044='(6044) Gel caps, gel tabs' 6046='(6046) Aquafoot' 6047='(6047) Water'
                  8001='(8001) Robitussin elixir'
                  9981='(9981) NEVER USED HALLUCINOGENS Logically assin'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE halnewb   161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople'
                  327='(327) Black beauties, Black Beauty'
                  339='(339) Amphetamines (speed generically)'
                  504='(504) Shoeshine liq,glue,toluene,Super Glue,ru'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  526='(526) Nail polish'
                  601='(601) LSD (acid, white lightning) [see als' 610='(610) Crystal T'
                  616='(616) DET, Dimethyltryptamine, DMT'
                  618='(618) Acid paper, blotter (acid) [see also 601'
                  653='(653) Cricket, cricketshit' 658='(658) Special K' 707='(707) Black Tar'
                  805='(805) Cocaine, coca, coke'
                  813='(813) Cigarettes, smoking (sub unspec), tobacc' 852='(852) sic'
                  6028='(6028) Laced flower' 6029='(6029) DXM' 6034='(6034) Pigface'
                  6036='(6036) Coco weed' 6041='(6041) Leaky leak' 6045='(6045) Blackboards'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE halnewc   601='(601) LSD (acid, white lightning) [see als'
                  657='(657) Orange barrel' 9991='(9991) NEVER USED HALLUCINOGENS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER' ;
  VALUE halnewd   618='(618) Acid paper, blotter (acid) [see also 601'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE halnewe   9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE hallage   981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halyrfrq  1='(1) More than 300 days (every day/almost eve'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGENS PST 12 MOS Log'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 12'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  0='(0) None' 81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGENS IN PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE lsdrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED LSD Logically assigned' 91='(91) NEVER USED LSD'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PCP Logically assigned' 91='(91) NEVER USED PCP'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpinhrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE amylnit   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gas       1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas      1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   146='(146) Bentyl, Dicyclomine'
                  377='(377) Albuterol, Proventil, Ventolin' 419='(419) Stadol'
                  502='(502) Spray paints' 503='(503) Other aerosol sprays'
                  504='(504) Shoeshine liq,glue,toluene,Super Glue,ru'
                  506='(506) Amyl nitrate, poppers, locker room odo'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  509='(509) Corr flds, degreasers, cleaning flds, Li'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, felt-tip pens, ink pens' 514='(514) sic'
                  516='(516) Freon' 519='(519) Helium' 521='(521) see also 525,544'
                  524='(524) see also 509' 526='(526) Nail polish'
                  528='(528) Whipped-cream can'
                  530='(530) Asthma inhaler, asthma med, bronchial di'
                  539='(539) ScotchGard' 540='(540) PAM'
                  545='(545) Car tailpipe exhaust fumes, CO2' 547='(547) sic'
                  548='(548) Cologne, isopropanol vapors, rubbing alc' 582='(582) WD-40'
                  583='(583) sic' 590='(590) Canned air'
                  592='(592) Computer air duster, computer cleaner' 599='(599) Potpourri'
                  803='(803) sic' 3007='(3007) Nasal inhalant' 5004='(5004) Ink print, paper'
                  5006='(5006) Brake fluid' 5007='(5007) Fly nap' 5008='(5008) R-R' 5010='(5010) Panfilo'
                  5011='(5011) Ozone' 5012='(5012) Negros' 5014='(5014) Spray O Buzz'
                  9981='(9981) NEVER USED INHALANTS Logically assigned'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE inhnewb   503='(503) Other aerosol sprays'
                  504='(504) Shoeshine liq,glue,toluene,Super Glue,ru'
                  511='(511) Markers, felt-tip pens, ink pens' 516='(516) Freon'
                  518='(518) Acetone, nail polish remover' 520='(520) Old paint, paint'
                  524='(524) see also 509' 526='(526) Nail polish' 594='(594) Starting fluid'
                  3007='(3007) Nasal inhalant' 5013='(5013) Lebel 12'
                  9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE inhnewc   504='(504) Shoeshine liq,glue,toluene,Super Glue,ru'
                  511='(511) Markers, felt-tip pens, ink pens'
                  9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE inhnewd   9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE inhnewe   9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE inhage    981='(981) NEVER USED INHALANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED INHALANTS' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpanlrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anlread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE codeine   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  101='(101) Butisol' 109='(109) Seconal' 110='(110) Tuinal, rainbows'
                  115='(115) Phenobarbital'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  119='(119) Secobarbital'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople' 201='(201) Valium'
                  202='(202) Librium, Chlordiazepoxide HCL' 207='(207) Ativan'
                  209='(209) Xanax' 221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  234='(234) Cyclobenzaprine, Flexeril'
                  246='(246) Clonazepam, Clonopin, Klonopin'
                  250='(250) Aventyl, Nortriptyline, Pamelor'
                  318='(318) Ritalin, Methylphenidate'
                  327='(327) Black beauties, Black Beauty'
                  330='(330) Blue birds, blue jays, blue robins, spec'
                  332='(332) see also 346' 363='(363) Bam(s)' 402='(402) Dolene'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  409='(409) Tylenol with Codeine, Tylenol 3, Tylenol'
                  413='(413) Talacen' 415='(415) Codeine'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  421='(421) USED ANALGESIC, DON''T KNOW NAME' 422='(422) Motrin'
                  423='(423) Percocet' 424='(424) Fioricet' 425='(425) Advil' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>' 431='(431) Tylox'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  435='(435) Tylenol, Tylenol Extra Strength <OTC>'
                  438='(438) Anaprox, Naprosyn, Naproxen' 440='(440) Soma'
                  442='(442) Ibuprofen' 454='(454) Novocain, Procaine'
                  456='(456) Lorcet HD, Lorcet Plus, Lortab [see also'
                  476='(476) Isocom, Midrin'
                  481='(481) Acular, Ketorolactromethamine, Toradol'
                  496='(496) Tramadol, Ultram' 499='(499) Aleve <OTC>'
                  663='(663) Animal tranquilizer, horse tranquilizer' 703='(703) Opium'
                  820='(820) Penicillin'
                  840='(840) Cough medicine (contents not specified)'
                  4018='(4018) Nuprin <OTC>' 4019='(4019) sic' 4020='(4020) sic' 4022='(4022) Buprenex'
                  8001='(8001) Robitussin elixir'
                  9981='(9981) NEVER USED PAIN KILLERS Logically assign'
                  9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE analnewb  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople' 201='(201) Valium'
                  209='(209) Xanax' 241='(241) Prozac'
                  246='(246) Clonazepam, Clonopin, Klonopin' 301='(301) Dexedrine'
                  318='(318) Ritalin, Methylphenidate' 403='(403) SK-65'
                  406='(406) Oxycodone, Percodan, Roxicet'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 422='(422) Motrin'
                  423='(423) Percocet' 425='(425) Advil' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  435='(435) Tylenol, Tylenol Extra Strength <OTC>' 440='(440) Soma'
                  496='(496) Tramadol, Ultram' 497='(497) sic' 4017='(4017) sic' 4021='(4021) sic'
                  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE analnewc  201='(201) Valium' 209='(209) Xanax'
                  410='(410) Phenaphen with Codeine, Phenaphen 3' 415='(415) Codeine'
                  423='(423) Percocet' 430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  499='(499) Aleve <OTC>' 841='(841) Allerest, Contact <OTC>'
                  8002='(8002) Zantac' 9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE analnewd  345='(345) Black Molly' 9991='(9991) NEVER USED PAIN KILLERS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER' ;
  VALUE analnewe  326='(326) White cross' 9991='(9991) NEVER USED PAIN KILLERS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analage   981='(981) NEVER USED PAIN KILLERS Logically assign'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED PAIN KILLERS' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  83='(83) DID NOT USE PAIN KILLERS IN PST 12 MONTH'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS'
                  93='(93) DID NOT USE PAIN KILLERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skptrnrd  1='(1) Yes, I think resp can complete answer sh'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE atarax    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnolst   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    110='(110) Tuinal, rainbows' 113='(113) Halcion' 115='(115) Phenobarbital'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor' 129='(129) Reds'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople' 201='(201) Valium'
                  203='(203) Libritabs, Limbitrol, Mitran [see also 2'
                  210='(210) Paxipam' 211='(211) Buspar' 213='(213) Equanil' 214='(214) Deprol'
                  222='(222) USED TRANQUILIZER, DON''T KNOW NAME' 227='(227) Thorazine'
                  234='(234) Cyclobenzaprine, Flexeril' 239='(239) see also 228'
                  241='(241) Prozac' 246='(246) Clonazepam, Clonopin, Klonopin'
                  271='(271) Zoloft' 282='(282) Clozapine, Clozaril' 286='(286) sic' 287='(287) sic'
                  426='(426) Butalbital, Esgic, Fiorinal, Phrenilin F' 440='(440) Soma'
                  459='(459) Ketamine' 658='(658) Special K'
                  663='(663) Animal tranquilizer, horse tranquilizer'
                  820='(820) Penicillin' 9985='(9985) BAD DATA Logically assigned'
                  9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE trnewb    116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople'
                  246='(246) Clonazepam, Clonopin, Klonopin'
                  285='(285) Risperdal, Resperidone'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  658='(658) Special K'
                  663='(663) Animal tranquilizer, horse tranquilizer'
                  9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE trnewc    218='(218) Diazepam' 9991='(9991) NEVER USED TRANQUILIZERS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER' ;
  VALUE trnewd    9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE trnewe    9991='(9991) NEVER USED TRANQUILIZERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranage   981='(981) NEVER USED TRANQUILIZERS Logically assig'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED TRANQUILIZERS' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  83='(83) DID NOT USE PAIN KILLERS IN PST 12 MONTH'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS'
                  93='(93) DID NOT USE PAIN KILLERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpstmrd  1='(1) Yes, I think respondent can complete it'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE benz      1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  124='(124) Yellow jackets' 135='(135) Mini Thins'
                  306='(306) Desoxyn, Methamphetamine hydrochloride'
                  307='(307) Tenuate, Diethylpropion'
                  318='(318) Ritalin, Methylphenidate'
                  322='(322) Methamphetamine (speed,ice,crank),'
                  325='(325) USED STIMULANT, DON''T KNOW NAME' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty' 328='(328) Pink hearts'
                  331='(331) Blancas, Whites' 332='(332) see also 346'
                  333='(333) 357 Magnum, Magnum 44' 334='(334) Crossroads, Cross tops'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  344='(344) Bennies' 345='(345) Black Molly' 348='(348) Crystal'
                  353='(353) No-Doz <OTC>' 354='(354) Vivarin <OTC>' 355='(355) Crystal meth'
                  390='(390) Max Alert' 396='(396) Black RJs' 414='(414) Propoxyphene'
                  417='(417) Morphine' 606='(606) sic' 704='(704) Dope'
                  805='(805) Cocaine, coca, coke' 3003='(3003) Primatine tablets'
                  3008='(3008) Miniwhites'
                  3015='(3015) Fen-Phen (fenfluramine and phentermine)' 3022='(3022) sic'
                  3023='(3023) Adderall' 3024='(3024) Yohimbe' 9991='(9991) NEVER USED STIMULANTS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER' ;
  VALUE stimnewb  124='(124) Yellow jackets' 135='(135) Mini Thins' 239='(239) see also 228'
                  271='(271) Zoloft' 315='(315) Voranil' 318='(318) Ritalin, Methylphenidate'
                  319='(319) Cylert' 322='(322) Methamphetamine (speed,ice,crank),'
                  324='(324) Uppers; OTHER Stimulant, NOT SPECIFIED'
                  326='(326) White cross' 327='(327) Black beauties, Black Beauty'
                  328='(328) Pink hearts'
                  329='(329) Bird eggs, robins eggs, speckled eggs'
                  334='(334) Crossroads, Cross tops'
                  339='(339) Amphetamines (speed generically)' 680='(680) Tweak'
                  806='(806) Crack, rock' 876='(876) Glass' 8004='(8004) Guaifenesin'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE stimnewc  322='(322) Methamphetamine (speed,ice,crank),' 328='(328) Pink hearts'
                  339='(339) Amphetamines (speed generically)' 349='(349) sic'
                  622='(622) Microdot(s), purple microdot' 814='(814) Caffeine'
                  3021='(3021) Blue balls' 9991='(9991) NEVER USED STIMULANTS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER' ;
  VALUE stimnewd  327='(327) Black beauties, Black Beauty' 363='(363) Bam(s)'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE stimnewe  326='(326) White cross' 9991='(9991) NEVER USED STIMULANTS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimage   981='(981) NEVER USED STIMULANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED STIMULANTS' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED STIMULANTS Logically assigne'
                  83='(83) DID NOT USE STIMULANTS IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpsedrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dalmane   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   101='(101) Butisol' 104='(104) Mebaral'
                  112='(112) Rasepam, Restoril, Temaz, Temazepam' 113='(113) Halcion'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  117='(117) Chloral hydrate' 121='(121) USED SEDATIVE, DON''T KNOW NAME'
                  129='(129) Reds' 137='(137) 7-14' 138='(138) sic'
                  161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople'
                  171='(171) NyQuil <OTC>' 174='(174) Ambien, Zolpidem'
                  228='(228) see also 239' 247='(247) Adapin, Doxepin, Sinequan'
                  801='(801) OTHER Drugs, NOT SPECIFIED'
                  9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE sednewb   116='(116) Methaqualone, Parest, Quaalude, Sopor' 177='(177) Bean'
                  9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE sednewc   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE sednewd   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE sednewe   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedage    981='(981) NEVER USED SEDATIVES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 994='(994) DON''T KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  83='(83) DID NOT USE SEDATIVES IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE biryearf  1913='(1913) 1913 and under' 1916='(1916) 1914-1918' 1921='(1921) 1919-1923'
                  1926='(1926) 1924-1928' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE eibdate   1='(1) Birthdate established from questionnaire'
                  2='(2) Portions of birthdate logically imputed'
                  3='(3) Birthdate missing' ;
  VALUE irage2ff  72='(72) 70-74' 77='(77) 75-79' 82='(82) 80-84' 85='(85) 85 and over' ;
  VALUE iiage     1='(1) Age from birthdate' 2='(2) Age from cover of questionnaire'
                  3='(3) Age from roster' 4='(4) Age statistically imputed' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from questionnaire'
                  2='(2) Sex from relationship on roster' 3='(3) Sex from roster' ;
  VALUE irrace    1='(1) American Indian or Alaskan native'
                  2='(2) Asian or Pacific islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Race from questionnaire'
                  2='(2) Race from interview observation' 3='(3) Race from roster'
                  4='(4) Race statis imputed using race - Other'
                  5='(5) Race statistically imputed, no infor. fr' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Nonhispanic' ;
  VALUE iihoind   1='(1) Hispanicity derived from questionnaire'
                  2='(2) Hispanicity derived from roster' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questio'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE irhogrpf  1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  5='(5) Central American' 6='(6) South American' 7='(7) Caribbean'
                  99='(99) LEGITIMATE SKIP Respondent is not hispa' ;
  VALUE iihogrpf  1='(1) Hispanic-Origin Group taken from questio'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Questionnaire data' 2='(2) Screener data'
                  3='(3) Logical Assignment Based on Roster Alpha'
                  4='(4) Statistically imputed data'
                  9='(9) Less than or equal to 14 years old' ;
  VALUE ireduc2f  5='(5) Fifth grade or less' 6='(6) Sixth grade' 7='(7) Seventh grade'
                  8='(8) Eighth grade' 9='(9) Ninth grade' 10='(10) Tenth grade'
                  11='(11) Eleventh grade' 12='(12) Twelfth grade'
                  13='(13) Freshman/13th year' 14='(14) Sophomore/14th year'
                  15='(15) Junior/15th year' 16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhsgrad  1='(1) Yes, graduated from high school'
                  2='(2) No, did not graduate from high school' ;
  VALUE iihsgrad  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job, but not at work, illness/mat'
                  4='(4) Have a job but not at work b/c it is sea'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed or laid off and not looking f'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled for work' 11='(11) Other, in labor force'
                  12='(12) Other, not in labor force' ;
  VALUE iiworkst  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used smokeless tobacco' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircrkrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used CRACK' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irlsdrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used LSD' ;
  VALUE iilsdrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtrnrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstmrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjfq    1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircrkfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week past year'
                  3='(3) Used 3-4 days per week past year'
                  4='(4) Used 1-2 days per week past year'
                  5='(5) Used 3-4 days per month past year'
                  6='(6) Used 1-2 days per month past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iicrkfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week past year'
                  3='(3) Used 3-4 days per week past year'
                  4='(4) Used 1-2 days per week past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iiherfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iihalfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinhfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iiinhfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iianlfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irtrnfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iitrnfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irstmfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iistmfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iisedfq   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE catag2ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26+ years' ;
  VALUE catag3ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35-49 years' 5='(5) 50+ years' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND = 2)' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Nonhispanic Black' 3='(3) Nonhispanic Nonblack' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC2=0-11 and'
                  2='(2) High school graduate (IREDUC2 = 12 and'
                  3='(3) Some college (IREDUC2 = 13-15 and IRAGE'
                  4='(4) College graduate (IREDUC2 = 16-17 and I'
                  5='(5) 12-17 year olds (IRAGE2 = 12-17)' ;
  VALUE empstatf  1='(1) Full-time (IRWORKST = 1,3 and IRAGE2 =>'
                  2='(2) Part-time (IRWORKST = 2 and IRAGE2 => 1'
                  3='(3) Unemployed (IRWORKST = 4,5,6,11 and IRA'
                  4='(4) Other (IRWORKST = 7,8,9,10,12 and IRAGE'
                  5='(5) 12-17 year olds (IRAGE2 = 12-17)' ;
  VALUE maristat  1='(1) Married (IRMARIT=1)' 2='(2) Not Married (IRMARIT=2,3,4)'
                  3='(3) LEGITIMATE SKIP (IRMARIT=99)' ;
  VALUE notmar    1='(1) Never Married (IRMARIT=4)'
                  2='(2) Divorced/Separated or Widowed (IRMARIT=2'
                  3='(3) Married/Legitimate Skip (IRMARIT=1,99)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-4)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC ='
                  1='(1) Used within the past year (IRCIGRC = 1,2' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC'
                  1='(1) Used within the past month (IRCIGRC = 1' ;
  VALUE smkflag   0='(0) Never used (IROTBRC = 9)' 1='(1) Ever used (IROTBRC = 1-4)' ;
  VALUE smkyr     0='(0) Did not use in the past year (IROTBRC ='
                  1='(1) Used within the past year (IROTBRC = 1,' ;
  VALUE smkmon    0='(0) Did not use in the past month (IROTBRC'
                  1='(1) Used within the past month (IROTBRC = 1' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-4)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC ='
                  1='(1) Used within the past year (IRALCRC = 1,' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC'
                  1='(1) Used within the past month (IRALCRC = 1' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-4)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC ='
                  1='(1) Used within the past year (IRMJRC = 1,2' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC ='
                  1='(1) Used within the past month (IRMJRC = 1)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-4)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC ='
                  1='(1) Used within the past year (IRCOCRC = 1,' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC'
                  1='(1) Used within the past month (IRCOCRC = 1' ;
  VALUE crkflag   0='(0) Never used (IRCRKRC = 9)' 1='(1) Ever used (IRCRKRC = 1-4)' ;
  VALUE crkyr     0='(0) Did not use in the past year (IRCRKRC ='
                  1='(1) Used within the past year (IRCRKRC = 1,' ;
  VALUE crkmon    0='(0) Did not use in the past month (IRCRKRC'
                  1='(1) Used within the past month (IRCRKRC = 1' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-4)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC ='
                  1='(1) Used within the past year (IRHERRC = 1,' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC ='
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-4)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC ='
                  1='(1) Used within the past year (IRHALRC = 1,' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC'
                  1='(1) Used within the past month (IRHALRC = 1' ;
  VALUE lsdflag   0='(0) Never used (IRLSDRC = 9)' 1='(1) Ever used (IRLSDRC = 1-4)' ;
  VALUE lsdyr     0='(0) Did not use in the past year (IRLSDRC ='
                  1='(1) Used within the past year (IRLSDRC = 1,' ;
  VALUE lsdmon    0='(0) Did not use in the past month (IRLSDRC'
                  1='(1) Used within the past month (IRLSDRC = 1' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-4)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC ='
                  1='(1) Used within the past year (IRPCPRC = 1,' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC'
                  1='(1) Used within the past month (IRPCPRC = 1' ;
  VALUE inhflag   0='(0) Never used (IRINHRC = 9)' 1='(1) Ever used (IRINHRC = 1-4)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC ='
                  1='(1) Used within the past year (IRINHRC = 1,' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC ='
                  1='(1) Used within the past month (IRINHRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-4)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC ='
                  1='(1) Used within the past year (IRANLRC = 1,' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC'
                  1='(1) Used within the past month (IRANLRC = 1' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-4)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC ='
                  1='(1) Used within the past year (IRTRNRC = 1,' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC'
                  1='(1) Used within the past month (IRTRNRC = 1' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-4)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC ='
                  1='(1) Used within the past year (IRSTMRC = 1,' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC'
                  1='(1) Used within the past month (IRSTMRC = 1' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-4)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC ='
                  1='(1) Used within the past year (IRSEDRC = 1,' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC'
                  1='(1) Used within the past month (IRSEDRC = 1' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRA'
                  1='(1) Any use within the past year (IRALCFQ=1-' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRAL'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE alcwkf    0='(0) Did not use weekly or more pst year (IRA'
                  1='(1) Used weekly or more in past year (IRALCF' ;
  VALUE alcoccf   0='(0) Used monthly/more or none pst yr (IRALCF'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE alcdlyf   0='(0) Did not use daily/almost dly pst yr(IRAL'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRMJFQ=1-9' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJ'
                  1='(1) Used monthly or more in past year (IRMJF' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJF'
                  1='(1) Used weekly or more in past year (IRMJFQ' ;
  VALUE mrjoccf   0='(0) Used monthly/more or none in pst yr(IRMJ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE mrjdlyf   0='(0) Did not use daily/almost daily pst yr(IR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE cocyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRCOCFQ =' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCO'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE cocwkf    0='(0) Did not use weekly or more pst year (IRC'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE cococcf   0='(0) Used mnthly/more or none in pst yr(IRCOC'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE cocdlyf   0='(0) Did not use daily/almost dly pst yr(IRCO'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE crkyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRCRKFQ =' ;
  VALUE crkmonf   0='(0) Did not use monthly/more past year (IRCR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE crkwkf    0='(0) Did not use weekly or more pst year (IRC'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE crkoccf   0='(0) Used mnthly/more or none in pst yr(IRCRK'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE crkdlyf   0='(0) Did not use daily/almost dly pst yr(IRCR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE heryrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRHERFQ=1-' ;
  VALUE hermonf   0='(0) Did not use monthly/more past year (IRHE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE herwkf    0='(0) Did not use weekly or more pst year (IRH'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE heroccf   0='(0) Used monthly/more or none pst yr(IRHERFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE herdlyf   0='(0) Did not use daily/almost daly pst yr(IRH'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE halyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRHALFQ=1-' ;
  VALUE halmonf   0='(0) Did not use monthly/more past year (IRHA'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE halwkf    0='(0) Did not use weekly or more pst year (IRH'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE haloccf   0='(0) Used monthly/more or none pst yr(IRHALFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE haldlyf   0='(0) Did not use daily/almost dly pst yr(IRHA'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE inhyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRINHFQ=1-' ;
  VALUE inhmonf   0='(0) Did not use monthly/more past year (IRIN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE inhwkf    0='(0) Did not use weekly or more pst year (IRI'
                  1='(1) Used weekly or more often past year (IRI' ;
  VALUE inhoccf   0='(0) Used monthly/more or none pst yr(IRINHFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE inhdlyf   0='(0) Did not use daily/almost dly pst yr(IRIN'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE anlyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRANLFQ=1-' ;
  VALUE anlmonf   0='(0) Did not use monthly/more past year (IRAN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE anlwkf    0='(0) Did not use weekly or more pst year (IRA'
                  1='(1) Used weekly or more often past year (IRA' ;
  VALUE anloccf   0='(0) Used monthly/more or none pst yr(IRANLFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE anldlyf   0='(0) Did not use daily/almost dly pst yr(IRAN'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE trqyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRTRNFQ=1-' ;
  VALUE trqmonf   0='(0) Did not use monthly/more past year (IRTR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE trqwkf    0='(0) Did not use weekly or more pst year (IRT'
                  1='(1) Used weekly or more often past year (IRT' ;
  VALUE trqoccf   0='(0) Used monthly/more or none pst yr(IRTRNFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE trqdlyf   0='(0) Did not use daily/almost dly pst yr(IRTR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE stmyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRSTMFQ=1-' ;
  VALUE stmmonf   0='(0) Did not use monthly/more past year (IRST'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE stmwkf    0='(0) Did not use weekly or more pst year (IRS'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE stmoccf   0='(0) Used mnthly/more or none in pst yr(IRSTM'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE stmdlyf   0='(0) Did not use daily/almost dly pst yr(IRST'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE sedyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRSEDFQ=1-' ;
  VALUE sedmonf   0='(0) Did not use monthly/more past year (IRSE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE sedwkf    0='(0) Did not use weekly or more pst year (IRS'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE sedoccf   0='(0) Used monthly/more or none pst yr(IRSEDFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE seddlyf   0='(0) Did not use daily/almost dly pst yr(IRSE'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE'
                  1='(1) Used in past year (ANY SOURCE VARIABLE <' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VAR'
                  1='(1) Used in past year (ANY SOURCE VARIABLE' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anothr'
                  1='(1) Marijuana is only (illicit) drug ever us' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug'
                  1='(1) Marijuana is only (illicit) drug in past' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr dr'
                  1='(1) Marijuana only (illicit) drug in past mo' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ev' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE bingedrk  0='(0) Never/No Binge ALC use (DR5DAY=0,81,83'
                  1='(1) Binge alcohol use (DR5DAY = 1-30,35)'
                  99='(99) Unknown (DR5DAY = 85,94,95,97,98)' ;
  VALUE hvydrk2f  0='(0) Never/No hvy ALC use(DR5DAY=0-4,35,81,83'
                  1='(1) Heavy alcohol use (DR5DAY = 5-30)'
                  99='(99) Unknown (DR5DAY = 85,94,95,97,98)' ;
  VALUE bingehvy  1='(1) Heavy alcohol use'
                  2='(2) Binge alcohol use but not heavy use'
                  3='(3) Past 30 day alcohol use but not binge'
                  4='(4) Did not use alcohol in the past 30 days' 99='(99) Unknown' ;
  VALUE peyote2f  0='(0) No/Unknown (PEYOTE=2,81,91,94,97,98)' 1='(1) Yes (PEYOTE=1)' ;
  VALUE mesc2fff  0='(0) No/Unknown (MESC=2,81,91,94,97,98)' 1='(1) Yes (MESC=1)' ;
  VALUE psilcy2f  0='(0) No/Unknown (PSILCY=2,81,91,94,97,98)'
                  1='(1) Yes (PSILCY=1,3)' ;
  VALUE ecstasyf  0='(0) No/Unknown (ECSTASY=2,81,91,94,97,98)'
                  1='(1) Yes (ECSTASY=1)' ;
  VALUE methampf  0='(0) No/Unknown (METHAMP=2,81,91,97,98)'
                  1='(1) Yes (METHAMP=1,3)' ;
  VALUE amylnitf  0='(0) No/Unknown (AMYLNIT=2,81,91,97,98)'
                  1='(1) Yes (AMYLNIT=1,3)' ;
  VALUE cleflu2f  0='(0) No/Unknown (CLEFLU=2,81,91,97,98)' 1='(1) Yes (CLEFLU=1,3)' ;
  VALUE gas2ffff  0='(0) No/Unknown (GAS=2,81,91,97,98)' 1='(1) Yes (GAS=1)' ;
  VALUE glue2fff  0='(0) No/Unknown (GLUE=2,81,91,97,98)' 1='(1) Yes (GLUE=1,3)' ;
  VALUE ether2ff  0='(0) No/Unknown (ETHER=2,81,91,97,98)' 1='(1) Yes (ETHER=1)' ;
  VALUE solventf  0='(0) No/Unknown (SOLVENT=2,81,91,97,98)' 1='(1) Yes (SOLVENT=1)' ;
  VALUE lgas2fff  0='(0) No/Unknown (LGAS=2,81,91,97,98)' 1='(1) Yes (LGAS=1)' ;
  VALUE nitoxidf  0='(0) No/Unknown (NITOXID=2,81,91,97,98)' 1='(1) Yes (NITOXID=1)' ;
  VALUE sppaintf  0='(0) No/Unknown (SPPAINT=2,81,91,97,98)' 1='(1) Yes (SPPAINT=1)' ;
  VALUE aeros2ff  0='(0) No/Unknown (AEROS=2,81,91,97,98)' 1='(1) Yes (AEROS=1,3)' ;
  VALUE mjdy30af  1='(1) 1-2 Days (MJDAY30A = 1-2)' 2='(2) 3-4 Days (MJDAY30A = 3-4)'
                  3='(3) 5-19 Days (MJDAY30A = 5-19)'
                  4='(4) 20-30 Days (MJDAY30A = 20-30)'
                  5='(5) None/Never used MRJ (MJDAY30A = 81,83,91'
                  6='(6) Unknown (MJDAY30A = 85,95,98)' ;
  VALUE cg04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cg12ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE al03ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 91='(91) NEVER USED ALCOHOL'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE al04ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mj04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mj05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cc04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cc05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ck04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CRACK' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ck05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 12 MONTH' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE he04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HEROIN' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE he05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 12 MONTHS' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls05ffff  1='(1) More than 300 days (every day/almost eve'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 12'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls07ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED LSD' 94='(94) DON''T KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls08ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PCP' 94='(94) DON''T KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE in04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED INHALANTS' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE in05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 12 MON'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pk04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pk05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE PAIN KILLERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tr04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tr05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE st04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE se04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE se05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpsdrd   1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sdread    1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hranyfrm  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hersmoke  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hrsmkrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  83='(83) USED HEROIN BUT NEVER SMOKED IT Logicall'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN'
                  93='(93) USED HEROIN BUT NEVER SMOKED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hersniff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hrsnfrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  83='(83) USED HEROIN BUT NEVER SNIFFED IT Log ass'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN'
                  93='(93) USED HEROIN BUT NEVER SNIFFED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE gnndllif  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocneedl  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) USED COCAINE BUT NEVER WITH A NEEDLE Log'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER WITH A NEEDLE' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE condlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) USED COCAINE BUT NEVER WITH A NEEDLE Log'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER WITH A NEEDLE' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE herneedl  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE hrndlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE stneedle  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) USED STIMULANTS BUT NEVER WITH A NEEDLE' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE stndlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) USED STIMULANTS BUT NEVER WITH A NEEDLE'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) USED STIMULANTS BUT NEVER WITH A NEEDLE' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndreus  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE gnndlshf  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndclen  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndls0f  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndget   1='(1) I bought the needle from a pharmacy'
                  2='(2) I got the needle from a needle exchange'
                  3='(3) I bought the needle on the street'
                  4='(4) I got the needle in a shooting gallery'
                  5='(5) I got the needle some other way'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndgtsp  6='(6) Given by, stolen from a friend'
                  7='(7) Given by, stolen from a relative'
                  8='(8) Given by, stolen from someone, relation'
                  9='(9) Came with drugs'
                  11='(11) I bought the needle from a pharmacy'
                  13='(13) I bought the needle on the street'
                  15='(15) Given by, stolen from med facility/profe'
                  16='(16) Given by, stolen from work'
                  17='(17) Given by, stolen from a pharmacy'
                  21='(21) Given by, stolen from vet facility/profe'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE skprskrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktrylsd  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rklsdreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rktryher  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkherreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskdifmj  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdiflsd  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcoc  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcrk  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifher  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rsksell   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqdngr  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqrsky  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqpblt  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkfqdblt  1='(1) Never' 2='(2) Seldom' 3='(3) Sometimes' 4='(4) Always'
                  91='(91) I dont drive' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpdrgrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drgread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE usedcig   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedmrj   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedcoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedher   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedhal   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedinh   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedanl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedtrn   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedstm   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedsed   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nodrugyr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE grtmcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtminh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE grtmsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamther   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamthal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamttrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE lamtsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btoltrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE btolsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE acrdsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE empbsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE hlpbsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdcig    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdalc    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdmrj    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdcoc    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdher    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdhal    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdinh    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdanl    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdtrn    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdstm    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE ucdsed    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (NODRUGYR=1,3)' ;
  VALUE skpsptrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt it alo' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sptread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxrcvd  1='(1) Yes' 2='(2) No' 5='(5) Yes (NDTXNEED=YES) LOGICALLY ASSIGNED'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ndtxneed  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxmj    1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxcoc   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxher   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxhal   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxinh   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxanl   1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtran  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxstim  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsed   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsod   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxdrgf  322='(322) Methamphetamine (speed,ice,crank),'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (sub unspec), tobacc'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr0f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr1f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr2f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr3f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxstep  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtrsp  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxtfar  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxbdhr  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxopen  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxtype  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxnhcv  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxnocv  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxcost  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxhcap  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxtcmp  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxlang  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxspsv  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsor   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxrscf  5='(5) Programs did not offer what I wanted'
                  6='(6) Had no insurance and couldnt afford tre'
                  12='(12) Programs did not offer special services'
                  14='(14) Did not need it'
                  16='(16) Do not want to (quit/get treatment)'
                  17='(17) Was using at the time/not ready/unmotiva'
                  18='(18) Can do it myself'
                  19='(19) Do not know where to go/did not look for'
                  20='(20) Do not use/infrequently use drugs and al'
                  21='(21) Lack of time'
                  22='(22) Shame/wanted to hide problem (from paren'
                  26='(26) Can do it with the support of my family/'
                  27='(27) Drug/alcohol free now' 28='(28) Treatment unavailable'
                  30='(30) I have problems in addition to alcohol/d'
                  32='(32) Completed treatment in the past, success'
                  34='(34) Dont use drugs/alcohol everyday'
                  35='(35) Need to find a non-smoking facility/grou'
                  36='(36) Can do it with the help of God/religion'
                  37='(37) Did not qualify for the program'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE booked    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nobookyr  83='(83) NOT BEEN ARRSTD & BKD PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (BOO'
                  93='(93) NOT ARRESTED AND BOOKED PAST 12 MONTHS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (BOOKED=2)' ;
  VALUE bklarcny  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkburgl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkagaslt  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bksmaslt  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkmvthft  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkrob     1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkrape    1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkmurder  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkarson   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrvinf  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrunk   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrug    1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkpros    1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkvandal  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkoth     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkothoff  1='(1) Larceny or theft' 2='(2) Burglary or breaking and entering'
                  3='(3) Aggravated assault'
                  4='(4) Other assault, such as simple assault or'
                  5='(5) Motor vehicle theft' 6='(6) Robbery'
                  10='(10) Driving under the influence'
                  11='(11) Drunkenness or other liquor law violatio'
                  12='(12) Possession or sale of drugs'
                  14='(14) Oth proprty offns:fraud, poss stln goods'
                  15='(15) Other offenses (NOT SPECIFIED)' 16='(16) Weapons offenses'
                  17='(17) Other offenses against persons'
                  18='(18) Violation of court order, parole, probat'
                  19='(19) Public order offenses' 20='(20) Juvenile status offenses'
                  22='(22) Traffic violations' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE probaton  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE parole    1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drvaldr   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE driveal   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drivedr   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skptmtrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tmtread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE txever    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE txstrtlf  1='(1) One time' 2='(2) Two times' 3='(3) Three or more times'
                  975='(975) Indicated treatment received at least on'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned (TXEV'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txyrever  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txstrtyf  1='(1) One time' 2='(2) Two or more times'
                  975='(975) Indicated treatment received at least on'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalhosp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTHOSP'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalrfin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFIN'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalrfop  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFOP'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalmhc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTMHC'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalemrg  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txaldoc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTDOC'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txaljail  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalshg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSHG'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSOP'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txalsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  10='(10) Church or religious influence'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  22='(22) Hospital' 24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrhosp  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTHOSP'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrfin   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTRFIN'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrfop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFOP'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrmhc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTMHC'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdremrg  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrdoc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTDOC'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrjail  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTJAIL'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrshg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSHG'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSOP'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txdrsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  10='(10) Church or religious influence'
                  13='(13) Court or correctional facilities' 15='(15) School'
                  24='(24) Drug treatment or rehab. center'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrins   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXPDINS'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrcare  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXPDCARE'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrcaid  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXPDCAID'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrpubp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXPDPUBP'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrsave  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXPDSAVE'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrfmly  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXPDFMLY'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrcort  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXPDCORT'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrmilc  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXPDMILC'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrempl  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXPDEMPL'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrfree  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXPDFREE'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrsos   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXPDSOS'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyrsp    1='(1) Health Insurance' 2='(2) Own savings or earnings'
                  3='(3) Family member' 6='(6) Free'
                  9='(9) State/city public assistance/welfare/rel' 10='(10) Court'
                  16='(16) Indian Health Service' 19='(19) Medicare'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txyremgf  0='(0) None' 1='(1) One' 2='(2) Two or more'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Log assn (TXEVER=2/TXYRE'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2/TXYREVER=2,4)' ;
  VALUE txadgrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Treatment in past year LOGICALLY ASSIGNE'
                  9='(9) Treatment in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED ALCOHOL OR DRUGS Logically as'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  91='(91) NEVER USED ALCOHOL OR DRUGS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlthosp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltrfin  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltrfop  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltmhc   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltemrg  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltdoc   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltjail  1='(1) Response marked'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltshg   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsop   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  8='(8) Research Facility' 10='(10) Church or religious influence'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 18='(18) Homeless shelter' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltmj    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltcoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlther   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlthal   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltinh   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltanl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltran   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltstim  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsed   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsod   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Treatment drug unknown, LOGICALLY ASSIGN'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlta     239='(239) see also 228' 322='(322) Methamphetamine (speed,ice,crank),'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  355='(355) Crystal meth' 605='(605) PCP (angel dust, phencyclidine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  808='(808) All of the ones Ive tried'
                  4011='(4011) Carbamazepine, epital, tegretol' 6027='(6027) Judyfly'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltb     322='(322) Methamphetamine (speed,ice,crank),'
                  339='(339) Amphetamines (speed generically)'
                  4011='(4011) Carbamazepine, epital, tegretol' 6026='(6026) KJ'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltc     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltd     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txlte     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrga    115='(115) Phenobarbital'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 239='(239) see also 228'
                  318='(318) Ritalin, Methylphenidate'
                  322='(322) Methamphetamine (speed,ice,crank),'
                  339='(339) Amphetamines (speed generically)' 348='(348) Crystal'
                  349='(349) sic' 355='(355) Crystal meth' 411='(411) Talwin'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  426='(426) Butalbital, Esgic, Fiorinal, Phrenilin F'
                  601='(601) LSD (acid, white lightning) [see als'
                  604='(604) Psilocybin (mushrooms), shrooms'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coca, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (sub unspec), tobacc'
                  816='(816) Smokeless tobacco, snuff, chewing tobacc' 875='(875) Buds'
                  4011='(4011) Carbamazepine, epital, tegretol'
                  8001='(8001) Robitussin elixir' 9985='(9985) BAD DATA Logically assigned'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgb    322='(322) Methamphetamine (speed,ice,crank),' 348='(348) Crystal'
                  415='(415) Codeine' 601='(601) LSD (acid, white lightning) [see als'
                  605='(605) PCP (angel dust, phencyclidine)' 702='(702) Heroin'
                  708='(708) Powder (heroin?)' 803='(803) sic' 805='(805) Cocaine, coca, coke'
                  806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  4011='(4011) Carbamazepine, epital, tegretol' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgc    322='(322) Methamphetamine (speed,ice,crank),'
                  339='(339) Amphetamines (speed generically)' 803='(803) sic'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ' 8003='(8003) Yesca'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgd    9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrge    9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txoutc    1='(1) Still in treatment' 2='(2) Successfully completed treatment'
                  3='(3) Had a problem with program'
                  4='(4) Couldnt afford to continue treatment'
                  5='(5) Family needed me' 6='(6) Began using drug(s) again'
                  7='(7) Other outcome, not specified' 8='(8) Didnt need treatment'
                  10='(10) Successful because of own efforts, not t'
                  11='(11) Use to a lesser extent' 12='(12) Kicked out of program'
                  13='(13) Moved' 14='(14) Successful because of religious reasons'
                  15='(15) Discontinued treatment, success unknown'
                  16='(16) Completed treatment, outcome unknown'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txtime    0='(0) None' 9975='(9975) Indicated treatment received at least on'
                  9989='(9989) LEGITIMATE SKIP Logically assigned (TXE'
                  9994='(9994) DON''T KNOW' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdins   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXYRINS'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdcare  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXYRCARE'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdcaid  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXYRCAID'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdpubp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXYRPUBP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsave  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXYRSAVE'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdfmly  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXYRFMLY'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdcort  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXYRCORT'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdmilc  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXYRMILC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdempl  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXYREMPL'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdfree  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXYRFREE'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsos   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXYRSOS'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsp    1='(1) Health Insurance' 2='(2) Own savings or earnings' 6='(6) Free'
                  8='(8) Friend/Sponsor'
                  9='(9) State/city public assistance/welfare/rel' 10='(10) Court'
                  12='(12) School' 14='(14) Veterans administration/military service'
                  15='(15) Treatment program' 16='(16) Indian Health Service'
                  17='(17) Social Security' 18='(18) Government' 22='(22) Research Facility'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (TXEVER=2)' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txenroll  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned (TXE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE skpdexrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dexread   1='(1) Wants interviewer to continue reading'
                  2='(2) Wants to do it himself/herself' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxmjret   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dxccret   1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dxcgrlf   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dxcg50lf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE dxcg30us  0='(0) None' 83='(83) SMOKED CIGAR BUT NOT IN PAST 30 DAYS Log'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) SMOKED CIGAR BUT NOT IN PAST 30 DAYS' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skpyeans  1='(1) Respondent is 12-17 years old'
                  2='(2) Respondent is 18 years or older - SKIP'
                  3='(3) Respondent is 12-17 years old LOG ASSN'
                  4='(4) Respondent is 18 years or older LOG ASSN' ;
  VALUE skpyexrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yexread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yelivnbr  1='(1) Less than one year'
                  2='(2) At least 1 year but less than 3 years'
                  3='(3) At least 3 years but less than 5 years'
                  4='(4) At least 5 years but less than 10 years'
                  5='(5) 10 or more years'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yecrime   1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeselldg  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepphlp   1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefmviol  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yesmrace  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeconflt  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yestfgt   1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeemtbld  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeppvsit  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yegrafti  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yesafe    1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeppmove  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeapkcig  1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeamjevr  1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeamjmo   1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeaaldly  1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yemv5yrf  0='(0) None' 1='(1) Moved once' 2='(2) Moved twice'
                  3='(3) Moved 3 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeadocig  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeadomrj  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeadoalc  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeadodnk  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepchkhw  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yephlphw  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepchore  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeplmttv  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeplmtsn  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepgdjob  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepproud  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeppkcig  1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepmjevr  1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepmjmo   1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepaldly  1='(1) Neither approve or disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yepar98f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeenrlyr  1='(1) Yes' 2='(2) No' 3='(3) Yes, LOG ASSN (from YE10 through YE14)'
                  5='(5) Yes, LOG ASSN(relevant yes from both YE2'
                  7='(7) Yes, LOG ASSN(relevant yes from YE24 or'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeschflt  1='(1) I liked going to school a lot'
                  2='(2) I kind of liked going to school'
                  3='(3) I didnt like going to school very much'
                  4='(4) I hated going to school'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeschwrk  1='(1) I always felt this way' 2='(2) I sometimes felt this way'
                  3='(3) I seldom felt this way' 4='(4) I never felt this way'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeschimp  1='(1) Very important' 2='(2) Somewhat important'
                  3='(3) Somewhat unimportant' 4='(4) Very unimportant'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeschint  1='(1) Very interesting' 2='(2) Somewhat interesting'
                  3='(3) Somewhat boring' 4='(4) Very boring'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetcgjob  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yelstgrd  1='(1) An A+, Aor A-minus average'
                  2='(2) A B+, Bor B-minus average' 3='(3) A C+, Cor C-minus average'
                  4='(4) A D or less than a D average'
                  5='(5) My school does not give these grades'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yestscig  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yestsmj   1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yestsalc  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yestsdnk  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetrpcig  1='(1) A lot of trouble' 2='(2) A little trouble'
                  3='(3) No trouble at all'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetrscig  1='(1) A lot of trouble' 2='(2) A little trouble'
                  3='(3) No trouble at all'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetrpalc  1='(1) A lot of trouble' 2='(2) A little trouble'
                  3='(3) No trouble at all'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetrdalc  1='(1) A lot of trouble' 2='(2) A little trouble'
                  3='(3) No trouble at all'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetrpidg  1='(1) A lot of trouble' 2='(2) A little trouble'
                  3='(3) No trouble at all'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetruidg  1='(1) A lot of trouble' 2='(2) A little trouble'
                  3='(3) No trouble at all'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeyargup  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeyfgtsw  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeyfgtgp  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeyhgun   1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeysell   1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeystole  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeyattak  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yegpkcig  1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yegmjevr  1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yegmjmo   1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yegaldly  1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefpkcig  1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefmjevr  1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefmjmo   1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefaldly  1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefdcig   1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yefdmj    1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yefdalc   1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yefddnk   1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlknon  1='(1) Response marked' 6='(6) Response not marked'
                  11='(11) Response marked (and other responses in'
                  13='(13) Resp markd LOG ASSN (>1 ans in Y-22 & Y'
                  15='(15) Resp markd LOG ASSN (>1 ans in Y-22& YEM'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkmom  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSMOM=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSMOM=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON markd & Y'
                  15='(15) Response marked LOG ASSN (YEMOSMOM=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkdad  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSDAD=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSDAD=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON markd & Y'
                  15='(15) Response marked LOG ASSN (YEMOSDAD=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkgpr  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSGPR=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSGPR=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  15='(15) Response marked LOG ASSN (YEMOSGPR=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkbgf  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSBGF=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSBGF=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON markd & Y'
                  15='(15) Response marked LOG ASSN (YEMOSBGF=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksib  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSSIB=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSSIB=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSSIB=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksor  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSSOR=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSSOR=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  15='(15) Response marked LOG ASSN (YEMOSSOR=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkfrn  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSFRN=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSFRN=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON markd & Y'
                  15='(15) Response marked LOG ASSN (YEMOSFRN=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlknbr  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSNBR=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSNBR=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON markd & Y'
                  15='(15) Response marked LOG ASSN (YEMOSNBR=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlktch  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSTCH=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSTCH=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkpsy  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSPSY=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSPSY=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlkclg  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSCLG=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSCLG=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  15='(15) Response marked LOG ASSN (YEMOSCLG=5 or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksop  1='(1) Response marked'
                  3='(3) Response marked, LOG ASSN (YEMOSSOP=1)'
                  5='(5) Response marked, LOG ASSN (YEMOSSOP=5)'
                  6='(6) Response not marked'
                  11='(11) Response marked (and YETLKNON=11)'
                  13='(13) Resp markd LOG ASSN (YETLKNON marked &'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yetlksp   20='(20) Parent/Guardian'
                  84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  181='(181) Other Male God Relative' 191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified'
                  281='(281) Other Female God Relative'
                  282='(282) Female Housekeeper/Maid/Caretaker/Butler'
                  291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified'
                  381='(381) Other God Relatives'
                  384='(384) Neighbors/Co-Workers/Visitors/Employees/'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified'
                  605='(605) Police/law enforcement'
                  607='(607) Other church worker(s)/member(s)'
                  608='(608) Teacher(s), non-school'
                  610='(610) Doctor(s)/nurse(s)/health care professio'
                  611='(611) Hotline' 900='(900) NOT A PERSON'
                  901='(901) God/Heavenly Father/Jesus/Higher Power/M'
                  902='(902) Spirit/dead relative(s) or friend(s)'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE yetlknr   10='(10) BOY/GIRLFRIEND OF PARENT'
                  11='(11) OTHER FRIEND(S) OF PARENT(S)'
                  13='(13) OTHER FRIEND(S) OF SIBLING(S)' 15='(15) FRIEND(S) OF FAMILY'
                  23='(23) PARENT OF BOY/GIRLFRIEND' 30='(30) PARENT(S) OF FRIEND(S)'
                  40='(40) MANAGER/BOSS/EMPLOYER'
                  42='(42) CO-WORKER(S), RELATIONSHIP UNSPECIFIED'
                  62='(62) IN THE MILITARY' 70='(70) BABYSITTER'
                  71='(71) CASUAL ACQUAINTANCE(S)' 73='(73) SELF-HELP GROUP MEMBER(S)'
                  76='(76) MENTOR/PERSON BEING MENTORED'
                  77='(77) ANOTHER ADULT/OLDER PERSON'
                  78='(78) SOMEONE KNOWN TO R, RELATIONSHIP UNSPEC'
                  79='(79) FELLOW VOLUNTEER(S)'
                  81='(81) PERSON(S) W/DESIRED CHARACTERISTICS/EXPE'
                  90='(90) SPECIFIC NAME MENTIONED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE yemosnon  1='(1) Response marked (only response marked in'
                  6='(6) Response not marked'
                  15='(15) Response marked (and other responses in'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosmom  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosdad  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosgpr  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosbgf  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossib  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossor  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosfrn  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosnbr  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemostch  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemospsy  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemosclg  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossop  1='(1) Response marked (only response marked in'
                  5='(5) Response marked (>1 relationship marked'
                  6='(6) Response not marked'
                  15='(15) Response marked (and YEMOSNON=15)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yemossp   20='(20) Parent/Guardian'
                  84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  181='(181) Other Male God Relative'
                  281='(281) Other Female God Relative'
                  291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified'
                  605='(605) Police/law enforcement'
                  607='(607) Other church worker(s)/member(s)'
                  610='(610) Doctor(s)/nurse(s)/health care professio'
                  900='(900) NOT A PERSON'
                  901='(901) God/Heavenly Father/Jesus/Higher Power/M'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE yemosnr   10='(10) BOY/GIRLFRIEND OF PARENT' 23='(23) PARENT OF BOY/GIRLFRIEND'
                  30='(30) PARENT(S) OF FRIEND(S)' 40='(40) MANAGER/BOSS/EMPLOYER'
                  42='(42) CO-WORKER(S), RELATIONSHIP UNSPECIFIED'
                  76='(76) MENTOR/PERSON BEING MENTORED'
                  90='(90) SPECIFIC NAME MENTIONED' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE yebigbro  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeprbslv  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yevioprv  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeymca    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yescouts  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeprvles  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yedgprgp  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yetemspt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ye4hclub  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yeslfhlp  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeband    1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeschclb  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yevolunt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yestgovt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeprgstd  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yejbskil  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yechoir   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yedeclas  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yederglr  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yedespcl  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yemsgyr   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yeystres  1='(1) Very stressful' 2='(2) Somewhat stressful'
                  3='(3) Not very stressful' 4='(4) Not at all stressful'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE yefmstrs  1='(1) Very stressful' 2='(2) Somewhat stressful'
                  3='(3) Not very stressful' 4='(4) Not at all stressful'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skpsenan  1='(1) Respondent is 12-17 years old - SKIP'
                  2='(2) Respondent is 18 years or older'
                  3='(3) Resp is 12-17 years old LOG ASSN - SKIP'
                  4='(4) Resp is 18 years or older LOG ASSN' ;
  VALUE skpsenrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE senread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snlivnbr  1='(1) Less than one year'
                  2='(2) At least 1 year but less than 3 years'
                  3='(3) At least 3 years but less than 5 years'
                  4='(4) At least 5 years but less than 10 years'
                  5='(5) 10 or more years' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE sncrime   1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snselldg  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snppval   1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfmviol  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snsmrace  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snconflt  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snstfgt   1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snemtbld  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snpphlp   1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE sngrafti  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snppvsit  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snsafe    1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snppmove  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snapkcig  1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snamjevr  1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snamjmo   1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snaaldly  1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snaaldrv  1='(1) Neither approve nor disapprove' 2='(2) Somewhat disapprove'
                  3='(3) Strongly disapprove' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snmv5yrf  0='(0) None' 1='(1) Moved once' 2='(2) Moved twice'
                  3='(3) Moved 3 or more times' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snpphhld  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE sninsult  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snsrargu  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snsmargu  1='(1) Strongly agree' 2='(2) Somewhat agree' 3='(3) Somewhat disagree'
                  4='(4) Strongly disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snspouse  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snspactv  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) A few times' 4='(4) Many times'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snspangr  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) A few times' 4='(4) Many times'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snsphitu  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) A few times' 4='(4) Many times'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snyhitsp  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) A few times' 4='(4) Many times'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snspcrit  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snspconc  1='(1) Always' 2='(2) Sometimes' 3='(3) Seldom' 4='(4) Never'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snystres  1='(1) Very stressful' 2='(2) Somewhat stressful'
                  3='(3) Not very stressful' 4='(4) Not at all stressful'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfmstrs  1='(1) Very stressful' 2='(2) Somewhat stressful'
                  3='(3) Not very stressful' 4='(4) Not at all stressful'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfrconc  1='(1) None' 2='(2) One' 3='(3) 2 or 3' 4='(4) 4 or 5' 5='(5) More than 5'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfractv  1='(1) None' 2='(2) One' 3='(3) 2 or 3' 4='(4) 4 or 5' 5='(5) More than 5'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfrcare  1='(1) None' 2='(2) One' 3='(3) 2 or 3' 4='(4) 4 or 5' 5='(5) More than 5'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snyhgun   1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snysell   1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snystole  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snyattak  1='(1) 0 times' 2='(2) 1 or 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 9 times' 5='(5) 10 or more times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfacig   1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfamjev  1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfamjmo  1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfaaldy  1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfaaldv  1='(1) I neither approve nor disapprove'
                  2='(2) I somewhat disapprove' 3='(3) I strongly disapprove'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE snfdcig   1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snfdmj    1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snfdalc   1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE snfddrnk  1='(1) None of them' 2='(2) A few of them' 3='(3) Most of them'
                  4='(4) All of them' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE movespyf  0='(0) None' 1='(1) Moved once' 2='(2) Moved twice'
                  3='(3) Moved 3 or more times' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE edu2ndqf  5='(5) Fifth grade or less' 6='(6) Sixth grade' 7='(7) Seventh grade'
                  8='(8) Eighth grade' 9='(9) Ninth grade' 10='(10) Tenth grade'
                  11='(11) Eleventh grade' 12='(12) Twelfth grade'
                  13='(13) Freshman/13th year' 14='(14) Sophomore/14th year'
                  15='(15) Junior/15th year' 16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE studnt9f  1='(1) A full-time student' 2='(2) A part-time student'
                  3='(3) Not now enrolled in any school'
                  4='(4) A full-time/part-time student LOG ASSN'
                  6='(6) Not now enrolled in any school LOG ASSN'
                  51='(51) School not in session (RAW QD16 = 1)'
                  52='(52) School not in session (RAW QD16 = 2)'
                  53='(53) School not in session (RAW QD16 = 3)'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE stdt949f  1='(1) A full-time student' 2='(2) A part-time student'
                  3='(3) Not now enrolled in any school'
                  5='(5) School not in session (RAW QD16 NOT 3)'
                  6='(6) Not now enrolled in any school LOG ASSN'
                  13='(13) QD16 marked not enrld, but QD12 marked'
                  15='(15) School not in session (RAW QD16 = 3)'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skpschgr  1='(1) EDU2NDQ2 = 5 THROUGH 11 AND STUDNT97 ='
                  2='(2) EDU2NDQ2 = 12 THROUGH 17 AND STUDNT97 ='
                  3='(3) EDU2NDQ2 = 5 THROUGH 11 AND STUDNT97 ='
                  4='(4) EDU2NDQ2 = 12 THROUGH 17 AND STUDNT97 ='
                  51='(51) School not in session (EDU2NDQ2 = 5-11)'
                  52='(52) School not in session (EDU2NDQ2 = 12-17'
                  53='(53) School not in session (EDU2NDQ2 undefine'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpschag  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSINGED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lftschrs  1='(1) I was getting bad grades' 2='(2) School was boring'
                  3='(3) I got expelled for selling drugs'
                  4='(4) I got expelled for using drugs'
                  5='(5) I got expelled for some other reason' 6='(6) I got pregnant'
                  7='(7) I had to get a job because I needed the'
                  8='(8) I wasnt learning anything' 9='(9) I went to jail/prison'
                  10='(10) I quit school for some other reason'
                  11='(11) I was getting bad grades'
                  14='(14) I got expelled for using drugs' 16='(16) I got pregnant'
                  17='(17) I had to get a job because I needed the'
                  18='(18) I wasnt learning anything'
                  20='(20) I was ill/sick/injured/needed medical ca'
                  21='(21) Family member became ill/sick/died'
                  22='(22) Responsibilities at home/family/personal'
                  23='(23) Parents/guardian/ptnr wouldnt allow me'
                  24='(24) Ran away from/put out of/placed out of h'
                  25='(25) Too stressful/couldnt adjust' 26='(26) Learning disabled'
                  27='(27) Couldnt get along with students/teacher'
                  28='(28) Race-related problems'
                  30='(30) Running with the wrong crowd/getting in'
                  31='(31) Afraid of gangs/fear of violence/crime'
                  32='(32) Abusing drugs/alcohol'
                  33='(33) Skipping school/excessive absenteeism'
                  34='(34) Too expensive/couldnt afford'
                  35='(35) Didnt like it/didnt want to go/not int'
                  36='(36) No transportation/school too far away'
                  38='(38) Grade or credit discrepancies/lacked cre'
                  40='(40) All the schooling/preferred schooling av'
                  41='(41) Wasnt required/didnt have to go/not ne'
                  44='(44) War/political problems in my country'
                  45='(45) I was stupid/foolish' 46='(46) Needed a break'
                  47='(47) Got married/moved in with boyfriend/girl'
                  48='(48) Joined military' 49='(49) Too old'
                  50='(50) Wanted to work/do apprenticeship instead'
                  51='(51) Moved away/didnt re-enroll'
                  52='(52) Just quit; reason unspecified'
                  53='(53) I got suspended/expelled for fighting'
                  54='(54) I got suspended, reason unspecified'
                  55='(55) Did not register/documents incomplete'
                  56='(56) Home schooling/private tutoring'
                  57='(57) Went to technical school'
                  58='(58) In love/wanted to be with girlfriend/boy'
                  59='(59) School was over-capacity, couldnt take'
                  60='(60) Bussing issues'
                  61='(61) I got suspended/expelled for gang-relate'
                  68='(68) Completed high school/ged/certificate or'
                  69='(69) Never went to school/no school available'
                  77='(77) Summer/school not in session' 78='(78) I am still in school'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 92='(92) ILLEGIBLE'
                  94='(94) DON''T KNOW' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lftschaf  10='(10) 10 years old or less' 19='(19) 19 years or older'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  996='(996) MULTIPLE RESPONSE' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE schdys9f  0='(0) None' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) SCHOOL NOT IN SESSION' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE schd949f  0='(0) None' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) School was not in session' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skippd9f  0='(0) None' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) SCHOOL NOT IN SESSION' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skip949f  0='(0) None' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) School was not in session' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skwrkage  1='(1) Respondent is 18 years old or older'
                  2='(2) Respondent is less than 18 years old'
                  3='(3) Resp 18 years old or older - LOG ASSN'
                  4='(4) Resp less than 18 years old - LOG ASSN' ;
  VALUE njobspyf  0='(0) None' 1='(1) One' 2='(2) Two' 3='(3) 3 or more' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wrkstatf  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job but out: illness/leave/furlou'
                  4='(4) Have a job, but it is seasonal'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed and not looking for work'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled, not able to work' 11='(11) Other, not specified'
                  21='(21) Working full-time, 35 hours or more a we'
                  22='(22) Working part-time, less than 35 hours a'
                  23='(23) Have a job but out: illness/leave/furlou'
                  26='(26) Unemployed and not looking for work'
                  27='(27) Full-time homemaker' 28='(28) In school only' 29='(29) Retired'
                  30='(30) Disabled, not able to work' 31='(31) Other, in labor force'
                  32='(32) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wkst2ndq  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job but out: illness/leave/furlou'
                  4='(4) Have a job, but it is seasonal'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed and not looking for work'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled, not able to work' 11='(11) Other, not specified'
                  21='(21) Working full-time, 35 hours or more a we'
                  22='(22) Working part-time, less than 35 hours a'
                  23='(23) Have a job but out: illness/leave/furlou'
                  26='(26) Unemployed and not looking for work'
                  27='(27) Full-time homemaker' 28='(28) In school only' 29='(29) Retired'
                  30='(30) Disabled, not able to work' 31='(31) Other, in labor force'
                  32='(32) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wkswkst   0='(0) None' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpwkstf  1='(1) WORK STATUS = 1,2,3, or 4'
                  2='(2) WORK STATUS = 5,6,7,8,9,10, or 11'
                  3='(3) WORK STATUS = 1,2,3, or 4 LOG ASSN'
                  4='(4) WORK STATUS = 5,6,7,8,9,10, or 11 LOG A'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE bussize   1='(1) Less than 10 people' 2='(2) 10-24 people' 3='(3) 25-99 people'
                  4='(4) 100-499 people' 5='(5) 500 people or more'
                  12='(12) 10-24 people LOGICALLY ASSIGNED'
                  13='(13) 25-99 people LOGICALLY ASSIGNED'
                  14='(14) 100-499 people LOGICALLY ASSIGNED'
                  15='(15) 500 people or more LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE locsize   1='(1) Less than 10 people' 2='(2) 10-24 people' 3='(3) 25-99 people'
                  4='(4) 100-499 people' 5='(5) 500 people or more'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE drginfo   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T REMEMBER' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE drgplcy   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE plcycov   1='(1) Only alcohol' 2='(2) Only drugs' 3='(3) Both alcohol and drugs'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE drgprgm   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE usalctst  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE usdrgtst  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skpwktst  1='(1) USALCTST = No or DK and USDRGTST = No'
                  2='(2) USALCTST or USDRGTST = Yes'
                  3='(3) USALCTST = No or DK and USDRGTST = No/'
                  4='(4) USALCTST or USDRGTST = Yes LOG ASSN'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tsthire   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tstrand   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tstsusp   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tstaccd   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tsttrmt   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wrkhire   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wrkrand   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wrksusp   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wrkaccd   1='(1) More likely' 2='(2) Less likely'
                  3='(3) Would it make no difference to you'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE paymo     89='(89) LEGITIMATE SKIP Logically assigned'
                  91='(91) NEVER WORKED FOR PAY' 94='(94) DON''T KNOW' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE payyr2ff  60='(60) 1960 or earlier' 985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned'
                  991='(991) NEVER WORKED FOR PAY' 994='(994) DON''T KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE roccup2f  1='(1) Executive/Administrative/Managerial Occu'
                  2='(2) Professional Specialty Occupations'
                  3='(3) Technicians and Related Support Occupati'
                  4='(4) Sales Occupations'
                  5='(5) Administrative Support Occupations, Inc'
                  6='(6) Private Household Occupations'
                  7='(7) Protective Service Occupations'
                  8='(8) Service Occups, Except Protective/Privat'
                  9='(9) Farming, Forestry, and Fishing occupatio'
                  10='(10) Mechanics and repairers' 11='(11) Construction trades'
                  12='(12) Extractive Occupations'
                  13='(13) Machine Operators, Assemblers, and Inspe'
                  14='(14) Transportation and Material Moving Occup'
                  15='(15) Handlers/Equipment Cleaners/Helpers/Labo' 16='(16) Military'
                  989='(989) LEGITIMATE SKIP Logically assigned' 995='(995) BAD DATA'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE businesf  1='(1) Agriculture, Forestry, and Fisheries' 2='(2) Mining'
                  3='(3) Construction' 4='(4) Manufacturing - Nondurable Goods'
                  5='(5) Manufacturing - Durable Goods'
                  6='(6) Trans/Commun/and Other Public Utilities'
                  7='(7) Wholesale Trade - Durable Goods'
                  8='(8) Wholesale Trade - Nondurable Goods' 9='(9) Retail Trade'
                  10='(10) Finance, Insurance, and Real Estate'
                  11='(11) Business and Repair Services' 12='(12) Personal Services'
                  13='(13) Entertainment and Recreation Services'
                  14='(14) Professional and Related Services'
                  15='(15) Public Administration' 16='(16) Military Duty'
                  989='(989) LEGITIMATE SKIP Logically assigned' 992='(992) ILLEGIBLE'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE skpwks0f  1='(1) Work stat=Now in labor force (codes 1-4,'
                  2='(2) Work stat=Not in labor frc (5-11,25-32)'
                  3='(3) Work stat=Now in labor force LOGICALLY A'
                  4='(4) Work stat=Not in labor frc LOG ASSN - SK'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workdays  0='(0) None' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  0='(0) None' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE jbloseyr  1='(1) Very likely' 2='(2) Very unlikely' 3='(3) Somewhat likely'
                  4='(4) Somewhat unlikely'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE jbfndnew  1='(1) Very easy' 2='(2) Somewhat easy' 3='(3) Somewhat difficult'
                  4='(4) Very difficult' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE jbsatis   1='(1) Very satisfied' 2='(2) Somewhat satisfied'
                  3='(3) Somewhat dissatisfied' 4='(4) Very dissatisfied'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE qd46_2ff  0='(0) None' 1='(1) One person' 2='(2) Two people' 3='(3) Three people'
                  4='(4) Four people' 5='(5) Five people' 6='(6) Six or more people'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skppreg   1='(1) Respondent is female less than 45 years'
                  2='(2) Respondent is female 45 years or older -'
                  3='(3) Respondent is male - SKIP'
                  4='(4) Female less than 45 LOGICALLY ASSIGNED'
                  5='(5) Female 45 years or older LOGICALLY ASSIG'
                  6='(6) Male LOGICALLY ASSIGNED - SKIP' ;
  VALUE pregnant  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pregmos   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpcwe    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE cwe       1='(1) Respondent' 2='(2) Someone else (specify)'
                  3='(3) Income equally by resp and someone else' 4='(4) No one'
                  6='(6) Someone else LOGICALLY ASSIGNED'
                  7='(7) Income eql by resp and someone else LOG'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cwesc1ff  8='(8) Respondent' 9='(9) Head of Household' 10='(10) Spouse'
                  11='(11) Ex-Spouse' 20='(20) Parent/Guardian'
                  21='(21) Step/Adopted/Foster Parent/Future Step P'
                  60='(60) Live-In Partner' 61='(61) Friend/Roommate/Companion'
                  71='(71) Cousin/Cousins Spouse'
                  84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  85='(85) Landlord/Home Owner'
                  90='(90) Other Relative, Gender not specified'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  109='(109) Male Head of Household' 110='(110) Husband'
                  113='(113) Childs Father' 120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F'
                  122='(122) Father/Step Father/Future Father In-Law' 130='(130) Son'
                  132='(132) Son In-Law' 133='(133) Grandson' 140='(140) Brother/Half Brother'
                  141='(141) Step/Adopted/Foster Brother/Future Step'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  151='(151) Step/Adopted/Foster/Great+ Grandfather'
                  160='(160) Male Live-In Partner'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 171='(171) Male Cousin'
                  172='(172) Nephew' 190='(190) Other Male Relative'
                  191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  211='(211) Ex-Wife' 215='(215) Female In-Law'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 231='(231) Step/Adopted/Foster Daughter'
                  232='(232) Daughter In-Law' 233='(233) Granddaughter'
                  240='(240) Sister/Half Sister'
                  241='(241) Step/Adopted/Foster Sister/Future Step S'
                  242='(242) Sister In-Law' 250='(250) Grandmother/Great+ Grandmother'
                  260='(260) Female Live-In Partner'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  271='(271) Female Cousin/Cousins Wife' 272='(272) Niece'
                  285='(285) Female Landlord/Home Owner'
                  290='(290) Other Female Relative' 291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified'
                  320='(320) Parents/Guardians'
                  321='(321) Step/Adopted/Foster Parents/Future Step'
                  340='(340) Siblings' 350='(350) Grandparents/Great+ Grandparents'
                  360='(360) Live-In Partners' 361='(361) Friends/Roommates/Companions'
                  371='(371) Cousins/Cousins Spouses' 381='(381) Other God Relatives'
                  390='(390) Other Relatives, Gender not specified'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified' 430='(430) Sons'
                  440='(440) Brothers/Half Brothers' 442='(442) Brothers In-Law'
                  470='(470) Uncles' 492='(492) Other Males, Relation Unspecified'
                  520='(520) Mothers/Female Guardians' 530='(530) Daughters'
                  533='(533) Granddaughters' 540='(540) Sisters/Half Sisters'
                  572='(572) Nieces' 902='(902) Spirit/dead relative(s) or friend(s)'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE cwesc2ff  8='(8) Respondent' 9='(9) Head of Household' 20='(20) Parent/Guardian'
                  21='(21) Step/Adopted/Foster Parent/Future Step P'
                  50='(50) Grandparent/Great+ Grandparent' 60='(60) Live-In Partner'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin/Cousins Spouse'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  109='(109) Male Head of Household' 110='(110) Husband' 111='(111) Ex-Husband'
                  120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F'
                  122='(122) Father/Step Father/Future Father In-Law' 130='(130) Son'
                  132='(132) Son In-Law' 133='(133) Grandson' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 172='(172) Nephew'
                  191='(191) Other Male Non-Relative'
                  209='(209) Female Head of Household' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 231='(231) Step/Adopted/Foster Daughter'
                  232='(232) Daughter In-Law' 233='(233) Granddaughter'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  291='(291) Other Female Non-Relative' 315='(315) In-Laws'
                  320='(320) Parents/Guardians'
                  337='(337) Children, Relation Unspecified'
                  361='(361) Friends/Roommates/Companions'
                  371='(371) Cousins/Cousins Spouses'
                  390='(390) Other Relatives, Gender not specified' 410='(410) Husbands'
                  430='(430) Sons' 440='(440) Brothers/Half Brothers' 470='(470) Uncles'
                  530='(530) Daughters' 985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE fullpart  1='(1) Full time' 2='(2) Part time'
                  3='(3) Chief wage earner does not work'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE rlgsvc9f  1='(1) 0 times' 2='(2) 1 to 2 times' 3='(3) 3 to 5 times'
                  4='(4) 6 to 24 times' 5='(5) 25 to 52 times' 6='(6) More than 52 times'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rlgimprt  1='(1) Strongly Disagree' 2='(2) Disagree' 3='(3) Agree'
                  4='(4) Strongly Agree' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rlgdecsn  1='(1) Strongly Disagree' 2='(2) Disagree' 3='(3) Agree'
                  4='(4) Strongly Agree' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rlgfrnds  1='(1) Strongly Disagree' 2='(2) Disagree' 3='(3) Agree'
                  4='(4) Strongly Agree' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nuertmtf  0='(0) None' 1='(1) Once' 2='(2) Twice' 3='(3) 3 times' 4='(4) 4 or more times'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nuhspovf  0='(0) None' 1='(1) One night' 2='(2) 2 nights' 3='(3) 3 or more nights'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nuhsppef  0='(0) None' 1='(1) One night' 2='(2) 2 or more nights'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE outptpe   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE proxable  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxyrel  1='(1) Respondents spouse/live-in partner'
                  2='(2) Respondents father' 3='(3) Respondents mother'
                  4='(4) Respondents brother' 5='(5) Respondents sister'
                  6='(6) Other family member (specify relation to'
                  20='(20) Parent/Guardian' 50='(50) Grandparent/Great+ Grandparent'
                  60='(60) Live-In Partner' 61='(61) Friend/Roommate/Companion'
                  71='(71) Cousin/Cousins Spouse'
                  83='(83) Nurse/Health Care Aide/Home Care Worker'
                  90='(90) Other Relative, Gender not specified'
                  91='(91) Other Non-Relative, Gender not specified' 110='(110) Husband'
                  120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F' 130='(130) Son'
                  133='(133) Grandson' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 172='(172) Nephew'
                  191='(191) Other Male Non-Relative' 220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 232='(232) Daughter In-Law' 233='(233) Granddaughter'
                  242='(242) Sister In-Law' 250='(250) Grandmother/Great+ Grandmother'
                  251='(251) Step/Adopted/Foster/Great+ Grandmother' 270='(270) Aunt'
                  350='(350) Grandparents/Great+ Grandparents'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DON''T KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE proxhome  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxjoin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE careusu   1='(1) Yes' 2='(2) No' 3='(3) Dont know'
                  4='(4) There is more than one place' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ncarersn  1='(1) Two or more usual doctors/places' 2='(2) Dont need a doctor'
                  3='(3) Dont like/trust/believe in doctors'
                  4='(4) Dont know where to go'
                  5='(5) Previous doctor is not available/moved'
                  6='(6) No insurance/cant afford it'
                  7='(7) Speak a different language'
                  8='(8) No care available/care too far away/inco'
                  9='(9) Other specify (see NCRRSNSP & NCRRSNSC)'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ncrrsnsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ncrrsnsc  1='(1) Two or more usual doctors/places' 2='(2) Dont need a doctor'
                  3='(3) Dont like/trust/believe in doctors'
                  5='(5) Previous doctor is not available/moved'
                  6='(6) No insurance/cant afford it'
                  8='(8) No care available/care too far away/inco'
                  10='(10) New to area/recently moved'
                  11='(11) Do not have a regular doctor'
                  12='(12) Self treatment/treatment by family membe'
                  13='(13) Religious reasons'
                  14='(14) Health care plan determines source'
                  15='(15) Hospital/urgent care/clinic' 18='(18) Alternative medicine'
                  19='(19) Difficulty getting to med care bc of dis'
                  85='(85) BAD DATA Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE careoft   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcare   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtyp  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room' 7='(7) HMO'
                  8='(8) Psychiatric hosptial or clinic'
                  9='(9) VA hospital or clinic'
                  10='(10) Military health care facility'
                  11='(11) Some other place specified (see PYRCRTSP'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtsc  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room'
                  7='(7) HMO (Health maintenance organization/pre'
                  12='(12) Self treatment/family member'
                  14='(14) Urgent care/walk-in medical facility'
                  16='(16) Alternative medicine'
                  17='(17) Non-physician health care professional'
                  19='(19) Indian clinic or hospital'
                  20='(20) Drug treatment/rehab center'
                  23='(23) Prison/correctional facility'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE carenow   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnncr  1='(1) Respondent changed residence/moved'
                  2='(2) Respondent changed jobs'
                  3='(3) Employer changed insurance companies'
                  4='(4) Former usual source left area'
                  5='(5) Owed money to former usual source'
                  6='(6) Dissatsfd with frmr source/like new sour'
                  7='(7) Medical care needs changed'
                  8='(8) Frmr usual source stopped taking ins/cov'
                  9='(9) Other reason specified (see MNRSNNSP/SC)'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnnsp  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnnsc  1='(1) Respondent changed residence/moved'
                  2='(2) Respondent changed jobs'
                  4='(4) Former usual source left area'
                  6='(6) Dissatsfd with frmr source/liked new sou'
                  7='(7) Medical care needs changed'
                  10='(10) Gynecological/obstetric care only'
                  11='(11) Medical care received through workmans'
                  12='(12) Do not need/like doctors'
                  13='(13) Cannot afford it/no insurance' 15='(15) Military'
                  16='(16) Former student' 19='(19) Different insurance coverage now'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ucaretyp  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room' 7='(7) HMO'
                  8='(8) Psychiatric hospital or clinic'
                  9='(9) VA hospital or clinic'
                  10='(10) Military health care facility'
                  11='(11) Some other place specified (see UCRTYPSP'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ucrtypsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ucrtypsc  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  7='(7) HMO (Health maintenance organization/pre'
                  10='(10) Military health care facility'
                  12='(12) Self treatment/family member' 13='(13) Friend'
                  14='(14) Urgent care/walk-in medical facility'
                  15='(15) Religion/church' 16='(16) Alternative medicine'
                  17='(17) Non-physician health care professional'
                  18='(18) Family planning clinic' 19='(19) Indian clinic or hospital'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE medicare  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE medicaid  1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE champus   1='(1) Yes' 2='(2) No' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE prvhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE grphltin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hltinalc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltindrg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinmnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skhlccov  1='(1) ANY YES IN MEDICAID THRU PRVHLTIN'
                  2='(2) MEDICAID THRU PRVHLTIN ALL NO'
                  3='(3) MEDICAID THRU PRVHLTIN ALL DK/REF'
                  4='(4) ANY YES IN MEDICAID THRU PRVHLTIN, Log a'
                  5='(5) MEDICAID THRU PRVHLTIN ALL NO, Log assn'
                  6='(6) MEDICAID THRU PRVHLTIN ALL DK/REF, Log a'
                  7='(7) OTHER COMBINATION (EXCEPT FOR ALL BLANK)'
                  85='(85) BAD DATA Logically assigned' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hlcnotyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hlcnotmo  0='(0) None' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlclast   1='(1) Within the past 6 months'
                  2='(2) More than 6 months ago but within the pa'
                  3='(3) More than 12 mos ago but within the past'
                  4='(4) More than 3 years ago' 5='(5) Never had any coverage'
                  15='(15) Never had coverage (but QHI-11 suggests'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hlcprivt  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlcmcaid  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlcmilt   1='(1) Response marked' 6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlcmcare  1='(1) Response marked' 6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlcogovt  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlcother  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlcothsp  1='(1) PRIVATE HEALTH INSURANCE'
                  2='(2) MEDICAID OR MEDICAL ASSISTANCE'
                  5='(5) SOME OTHER GOVERNMENT PROGRAM'
                  7='(7) PUBLIC HEALTH SERVICE/INDIAN HLTH HOSPIT'
                  8='(8) HEALTH CARE COVERAGE OUTSIDE OF USA'
                  9='(9) SCHOOL/SPORT-RELATED HEALTH CARE COVERAG'
                  10='(10) NON-GOVERNMENT MEDICAL ASSISTANCE'
                  11='(11) MEDICAL, TYPE UNSPECIFIED'
                  12='(12) TRUST PAYS MEDICAL BILLS' 13='(13) DENTAL INSURANCE'
                  14='(14) WORKMANS COMPENSATION'
                  15='(15) INSURANCE AS CIVILIAN GOVT EMPLOYEE'
                  60='(60) PAID OUT OF POCKET'
                  61='(61) DOES NOT HAVE MEDICAL INSURANCE'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnlosjb  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnmajob  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnmasor  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlncost   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlninelg  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnnoffr  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlndivor  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlndeath  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnrefus  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnnoned  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnsor    1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hlnsorsp  1='(1) PERSON IN FAMILY W/ INS LOST JOB/CHNGD E'
                  2='(2) LOST MEDICAID OR MED ASSIST COV B/C NEW'
                  3='(3) LOST MEDICAID OR MED ASSIST COV FOR OTHE'
                  4='(4) COST IS TOO HIGH/CANT AFFORD PREMIUMS'
                  5='(5) BECAME INELIGIBLE B/C OF AGE OR LEAVING'
                  6='(6) EMPLOYER DOESNT OFFER COV/NOT ELIGIBLE'
                  7='(7) GOT DIVORCED OR SEPARATED FROM PERSON W/'
                  8='(8) DEATH OF SPOUSE OR PARENT'
                  9='(9) INSURANCE COMPANY REFUSED COVERAGE' 10='(10) DON''T NEED IT'
                  12='(12) HAVE NOT APPLIED OR REAPPLIED FOR INS CO'
                  13='(13) APPLIED INS/MEDICAID,WAITING FOR ACTIVAT'
                  14='(14) INELIGIBLE BC MOVED OUT OF PARENTS/GUARD'
                  15='(15) DON''T KNOW HOW TO OBTAIN/TRYING TO OBTAI'
                  16='(16) NON-US CITIZEN'
                  17='(17) NEVER HAVE HAD COVERAGE/PAY OUT OF POCKE'
                  18='(18) DON''T KNOW IF CURRENTLY COVERED'
                  19='(19) SELF-EMPLOYED/PARENTS SELF-EMPLOYED'
                  20='(20) DISSATISFIED WITH PREVIOUS/AVAILABLE COV'
                  21='(21) DON''T BELIEVE IN/TRUST MEDICAL PROFESSIO'
                  22='(22) HAD INS IN ANOTHER COUNTRY BEFORE MOVING'
                  23='(23) MOVED/DON''T HAVE SAME COVERAGE'
                  24='(24) PARENTS/GUARDIANS GOT DIVORCED/SEPARATED'
                  25='(25) DON''T QUALIFY, NO REASON SPECIFIED'
                  26='(26) DROPPED COVERAGE, NO REASON SPECIFIED'
                  27='(27) HAVENT THOUGHT ABOUT GETTING COVERAGE'
                  28='(28) DON''T QUALIFY FOR PARTNERS/FAMILY MEMBE'
                  29='(29) HAVE BEEN IN JAIL/PRISON'
                  30='(30) WANT TO BE INDEPENDENT, DO IT ON MY OWN'
                  31='(31) DO NOT HAVE PROPER DOCUMENTS'
                  32='(32) INELIGIBLE B/C NO LONGER PLAY SPORTS/MEM'
                  33='(33) HAVE ONLY EMERGENCY CARE COVERAGE'
                  34='(34) HAVE ONLY WORKMANS COMPENSATION'
                  35='(35) TOO COMPLICATED TO GET HEALTH INSURANCE'
                  36='(36) HAVE NEVER WORKED' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  90='(90) CURRENTLY COVERED BY HEALTH INSURANCE' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE soc1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soc2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ssi1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ssi2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE pmt1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pmt2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE afdc      1='(1) AFDC/ADC' 2='(2) OTHER' 3='(3) BOTH'
                  4='(4) AFDC/ADC Logically assigned'
                  5='(5) OTHER Logically assigned' 6='(6) BOTH Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fstamp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE svc1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE svc2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE welfare   1='(1) Yes' 2='(2) No' ;
  VALUE welmos    89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE int1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE int2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE chd1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chd2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wage1fff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE wage2fff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oth1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DON''T KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE oth2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pinc1fff  1='(1) $20,000 or more' 2='(2) Less than $20,000' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pinc2fff  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more'
                  94='(94) DON''T KNOW' 95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skptfmin  1='(1) Yes' 2='(2) No - SKIP' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE finc1fff  1='(1) $20,000 or more' 2='(2) Less than $20,000'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE finc2fff  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE telno2ff  0='(0) None' 1='(1) One line' 2='(2) 2 or more lines' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE irpinsur  1='(1) Yes, respondent does have private health'
                  2='(2) No, respondent does not have private hea' ;
  VALUE iipinsur  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinsur   1='(1) Yes, respondent does have health insuran'
                  2='(2) No, respondent does not have health insu' ;
  VALUE iiinsur   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsoc1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irssi1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpmt1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iipmt1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irafdc    1='(1) AFDC/ADC' 2='(2) OTHER' 3='(3) BOTH'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iiafdc    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irfstamp  1='(1) Yes' 2='(2) No' ;
  VALUE iifstamp  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsvc1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisvc1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irwelmos  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iiwelmos  1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP' ;
  VALUE irint1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irchd1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irwage1f  1='(1) Yes' 2='(2) No' ;
  VALUE iiwage1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iroth1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpinc1f  1='(1) $20,000 or more' 2='(2) Less than $20,000' ;
  VALUE iipinc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irfinc1f  1='(1) $20,000 or more' 2='(2) Less than $20,000'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iifinc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irsoc2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irssi2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irpmt2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iipmt2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) Legitimate skip' ;
  VALUE irsvc2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisvc2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) Legitimate skip' ;
  VALUE irint2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irchd2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irwage2f  1='(1) Yes' 2='(2) No' ;
  VALUE iiwage2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) Legitimate skip' ;
  VALUE iroth2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irpinc2f  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more' ;
  VALUE iipinc2f  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irfinc2f  1='(1) Less than $1,000 (including loss)' 2='(2) $1,000 - $1,999'
                  3='(3) $2,000 - $2,999' 4='(4) $3,000 - $3,999' 5='(5) $4,000 - $4,999'
                  6='(6) $5,000 - $5,999' 7='(7) $6,000 - $6,999' 8='(8) $7,000 - $7,999'
                  9='(9) $8,000 - $8,999' 10='(10) $9,000 - $9,999'
                  11='(11) $10,000 - $10,999' 12='(12) $11,000 - $11,999'
                  13='(13) $12,000 - $12,999' 14='(14) $13,000 - $13,999'
                  15='(15) $14,000 - $14,999' 16='(16) $15,000 - $15,999'
                  17='(17) $16,000 - $16,999' 18='(18) $17,000 - $17,999'
                  19='(19) $18,000 - $18,999' 20='(20) $19,000 - $19,999'
                  21='(21) $20,000 - $24,999' 22='(22) $25,000 - $29,999'
                  23='(23) $30,000 - $34,999' 24='(24) $35,000 - $39,999'
                  25='(25) $40,000 - $44,999' 26='(26) $45,000 - $49,999'
                  27='(27) $50,000 - $74,999' 28='(28) $75,000 or more'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iifinc2f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE f15_44ff  0='(0) Otherwise' 1='(1) Female age 15-44' ;
  VALUE m15_44ff  0='(0) Otherwise' 1='(1) Male age 15-44' ;
  VALUE preg      0='(0) Otherwise' 1='(1) Pregnant female age 12-44' ;
  VALUE preg2fff  1='(1) Pregnant (PREGNANT = 1,3)'
                  2='(2) Not pregnant (PREGNANT = 2)'
                  3='(3) Males/Females not age 12-44 (PREGNANT ='
                  99='(99) Unknown (PREGNANT = 94,97,98)' ;
  VALUE trimest   1='(1) 1st 3 months of pregnancy (PREG=1 & PRE'
                  2='(2) 2nd 3 months of pregnancy (PREG=1 & PRE'
                  3='(3) Last 3 months of pregnancy (PREG=1 & PR'
                  4='(4) Males/Not pregnant females (PREG=0)'
                  99='(99) Unknown (PREG=1 and PREGMOS=85,94,98)' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 12 m'
                  3='(3) 12 or more months ago but less than 3 ye'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE V' ;
  VALUE nedflagf  0='(0) Never used (GNNDLLIF=2,85,97,98)'
                  1='(1) Ever Used (GNNDLLIF=1,3)' ;
  VALUE nedyr4ff  0='(0) Never used (NEEDLREC=3,4,9,91,98)'
                  1='(1) Ever Used (NEEDLREC=1,2)' ;
  VALUE hersmokf  0='(0) No/Unknown (HERSMOKE=2,85,89,97,98,99)'
                  1='(1) Yes (HERSMOKE=1,3)' ;
  VALUE hersni0f  0='(0) No/Unknown (HERSNIFF=2,85,89,97,98,99)'
                  1='(1) Yes (HERSNIFF=1,3)' ;
  VALUE alcdep    0='(0) No' 1='(1) Yes (See comment above)' ;
  VALUE mrjdep    0='(0) No' 1='(1) Yes (See comment above)' ;
  VALUE sumdep    0='(0) No' 1='(1) Yes (See comment above)' ;
  VALUE hltpralc  0='(0) No' 1='(1) Yes (USEDALC=1,3 & ALCYR=1 & HLPBALC=1' ;
  VALUE hltprmrj  0='(0) No' 1='(1) Yes (USEDMRJ=1,3 & MRJYR=1 & HLPBMRJ=1' ;
  VALUE hltprsum  0='(0) No' 1='(1) Yes (See comment above)' ;
  VALUE psypralc  0='(0) No' 1='(1) Yes (USEDALC=1,3 & ALCYR=1 & EMPBALC=1' ;
  VALUE psyprmrj  0='(0) No' 1='(1) Yes (USEDMRJ=1,3 & MRJYR=1 & EMPBMRJ=1' ;
  VALUE psyprsum  0='(0) No' 1='(1) Yes (See comment above)' ;
  VALUE alctrt    0='(0) No' 1='(1) Yes (See comment above)' ;
  VALUE mrjtrt    0='(0) No' 1='(1) Yes (TXADGREC=1,2,8 & MRJYR=1 & TXLTMJ' ;
  VALUE sumtrt    0='(0) No' 1='(1) Yes (See comment above)' ;
  VALUE cigarmon  1='(1) Used in past 30 days' 2='(2) Did not use in past 30 days'
                  4='(4) Did not use in past 30 days LOGICALLY AS'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DON''T KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cigrlife  1='(1) Used in lifetime' 2='(2) Never used cigars'
                  3='(3) Used in lifetime LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ircgrlf   1='(1) Used in lifetime' 9='(9) Never used cigars' ;
  VALUE ircgrmn   1='(1) Used in past 30 days' 2='(2) Did not use in past 30 days'
                  9='(9) Never used cigars' ;
  VALUE iicgrlf   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iicgrmn   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE cgrflag   0='(0) Never used (IRCGRLF = 9)' 1='(1) Ever used (IRCGRLF = 1)' ;
  VALUE cgrmon    0='(0) Did not use in the past month (IRCGRMN'
                  1='(1) Used within the past month (IRCGRMN = 1' ;
  VALUE actall    1='(1) No activity were marked' 2='(2) One activity was marked'
                  3='(3) Two activities were marked'
                  4='(4) Three or more activities were marked' ;
  VALUE actsel    1='(1) No selected activities were marked'
                  2='(2) One selected activity was marked'
                  3='(3) Two selected activities were marked'
                  4='(4) Three or more selected activities were m' ;
  VALUE adflaldy  1='(1) Neither Approve or Disapprove (YEAALDLY'
                  2='(2) Somewhat Disapprove (YEAALDLY = 2)'
                  3='(3) Strongly Disapprove (YEAALDLY = 3)' 99='(99) Otherwise' ;
  VALUE adflpkcg  1='(1) Neither Approve or Disapprove (YEAPKCIG'
                  2='(2) Somewhat Disapprove (YEAPKCIG = 2)'
                  3='(3) Strongly Disapprove (YEAPKCIG = 3)' 99='(99) Otherwise' ;
  VALUE adfltmrj  1='(1) Neither Approve or Disapprove (YEAMJEVR'
                  2='(2) Somewhat Disapprove (YEAMJEVR = 2)'
                  3='(3) Strongly Disapprove (YEAMJEVR = 3)' 99='(99) Otherwise' ;
  VALUE adflumrj  1='(1) Neither Approve or Disapprove (YEAMJMO ='
                  2='(2) Somewhat Disapprove (YEAMJMO = 2)'
                  3='(3) Strongly Disapprove (YEAMJMO = 3)' 99='(99) Otherwise' ;
  VALUE adultalc  1='(1) None of Them (YEADOALC = 1)'
                  2='(2) A few of Them (YEADOALC = 2)'
                  3='(3) Most of Them (YEADOALC = 3)'
                  4='(4) All of Them (YEADOALC = 4)' 99='(99) Otherwise' ;
  VALUE adultcig  1='(1) None of Them (YEADOCIG = 1)'
                  2='(2) A few of Them (YEADOCIG = 2)'
                  3='(3) Most of Them (YEADOCIG = 3)'
                  4='(4) All of Them (YEADOCIG = 4)' 99='(99) Otherwise' ;
  VALUE adultdrk  1='(1) None of Them (YEADODNK = 1)'
                  2='(2) A few of Them (YEADODNK = 2)'
                  3='(3) Most of Them (YEADODNK = 3)'
                  4='(4) All of Them (YEADODNK = 4)' 99='(99) Otherwise' ;
  VALUE adultmrj  1='(1) None of Them (YEADOMRJ = 1)'
                  2='(2) A few of Them (YEADOMRJ = 2)'
                  3='(3) Most of Them (YEADOMRJ = 3)'
                  4='(4) All of Them (YEADOMRJ = 4)' 99='(99) Otherwise' ;
  VALUE anyeduc   0='(0) Otherwise' 1='(1) Yes (DRGSPCLS = 1 or DRGRGCLS = 1 or DRU' ;
  VALUE drgrgcls  0='(0) Otherwise' 1='(1) Yes (YEDERGLR = 1)' ;
  VALUE drgspcls  0='(0) Otherwise' 1='(1) Yes (YEDECLAS = 1)' ;
  VALUE drprvmes  0='(0) Otherwise' 1='(1) Yes (YEMSGYR = 1)' ;
  VALUE druglect  0='(0) Otherwise' 1='(1) Yes (YEDESPCL =1)' ;
  VALUE enrollyr  0='(0) Otherwise' 1='(1) Yes (YEENRLYR = 1, 3, 5, 7)' ;
  VALUE famstres  1='(1) Very stressful (YEFMSTRS = 1)'
                  2='(2) Somewhat stressful (YEFMSTRS = 2)'
                  3='(3) Not very stressful (YEFMSTRS = 3)'
                  4='(4) Not at all stressful (YEFMSTRS = 4)' 99='(99) Otherwise' ;
  VALUE frdaldly  1='(1) Neither Approve or Disapprove (YEFALDL'
                  2='(2) Somewhat Disapprove (YEFALDLY = 2)'
                  3='(3) Strongly Disapprove (YEFALDLY = 3)' 99='(99) Otherwise' ;
  VALUE frdmjevr  1='(1) Neither Approve or Disapprove (YEFMJEV'
                  2='(2) Somewhat Disapprove (YEFMJEVR = 2)'
                  3='(3) Strongly Disapprove (YEFMJEVR = 3)' 99='(99) Otherwise' ;
  VALUE frdmjmo   1='(1) Neither Approve or Disapprove (YEFMJMO'
                  2='(2) Somewhat Disapprove (YEFMJMO = 2)'
                  3='(3) Strongly Disapprove (YEFMJMO = 3)' 99='(99) Otherwise' ;
  VALUE frdpkcig  1='(1) Neither Approve or Disapprove (YEFPKCI'
                  2='(2) Somewhat Disapprove (YEFPKCIG = 2)'
                  3='(3) Strongly Disapprove (YEFPKCIG = 3)' 99='(99) Otherwise' ;
  VALUE frndalc   1='(1) None of Them (YEFDALC = 1)'
                  2='(2) A few of Them (YEFDALC = 2)'
                  3='(3) Most of Them (YEFDALC = 3)'
                  4='(4) All of Them (YEFDALC = 4)' 99='(99) Otherwise' ;
  VALUE frndcig   1='(1) None of Them (YEFDCIG = 1)'
                  2='(2) A few of Them (YEFDCIG = 2)'
                  3='(3) Most of Them (YEFDCIG = 3)'
                  4='(4) All of Them (YEFDCIG = 4)' 99='(99) Otherwise' ;
  VALUE frnddnk   1='(1) None of Them (YEFDDNK = 1)'
                  2='(2) A few of Them (YEFDDNK = 2)'
                  3='(3) Most of Them (YEFDDNK = 3)'
                  4='(4) All of Them (YEFDDNK = 4)' 99='(99) Otherwise' ;
  VALUE frndmj    1='(1) None of Them (YEFDMJ = 1)'
                  2='(2) A few of Them (YEFDMJ = 2)'
                  3='(3) Most of Them (YEFDMJ = 3)' 4='(4) All of Them (YEFDMJ = 4)'
                  99='(99) Otherwise' ;
  VALUE livnbrhd  1='(1) Less Than One Year (YELIVNBR = 1)'
                  2='(2) Least 1 yr but less than 3 years (YELIVN'
                  3='(3) Least 3 yr but less than 5 years (YELIV'
                  4='(4) Least 5 yr but less than 10 years (YELI'
                  5='(5) 10 or More Years (YELIVNBR =5)' 99='(99) Otherwise' ;
  VALUE mosfrn    1='(1) Only One Response (YEMOSFRN = 1 and MOSC'
                  2='(2) No Response Marked (YEMOSFRN=6)'
                  3='(3) Unknown (YEMOSFRN = 85,95,97,98)'
                  4='(4) Multiple Answers (MOSCOUNT > 1)'
                  5='(5) Respondent aged 18 + (YEMOSFRN = 89,99)' ;
  VALUE mosnon    1='(1) Only One Response (YEMOSNON = 1 and MOSC'
                  2='(2) No Response Marked (YEMOSNON=6)'
                  3='(3) Unknown (YEMOSNON = 85,95,97,98)'
                  4='(4) Multiple Answers (MOSCOUNT > 1)'
                  5='(5) Respondent aged 18 + (YEMOSNON = 89,99)' ;
  VALUE mosother  1='(1) Only One Response (Any Source= 1 and MOS'
                  2='(2) No Response Marked (All Source=6)'
                  3='(3) Unknown (All Source = 85,95,97,98)'
                  4='(4) Multiple Answers (MOSCOUNT > 1)'
                  5='(5) Respondent aged 18 + (All Source = 89,9' ;
  VALUE mosparnt  1='(1) Only One Response (Any Source= 1 and MOS'
                  2='(2) No Response Marked (All Source=6)'
                  3='(3) Unknown (All Source = 85,95,97,98)'
                  4='(4) Multiple Answers (MOSCOUNT > 1)'
                  5='(5) Respondent aged 18 + (All Source = 89,9' ;
  VALUE nghdbldg  1='(1) Strongly Agree (YEEMTBLD = 1)'
                  2='(2) Somewhat Agree (YEEMTBLD = 2)'
                  3='(3) Somewhat Disagree (YEEMTBLD = 3)'
                  4='(4) Strongly Disagree (YEEMTBLD = 4)' 99='(99) Otherwise' ;
  VALUE nghdcnft  1='(1) Strongly Agree (YECONFLT = 1)'
                  2='(2) Somewhat Agree (YECONFLT = 2)'
                  3='(3) Somewhat Disagree (YECONFLT = 3)'
                  4='(4) Strongly Disagree (YECONFLT = 4)' 99='(99) Otherwise' ;
  VALUE nghdcrim  1='(1) Strongly Agree (YECRIME = 1)'
                  2='(2) Somewhat Agree (YECRIME = 2)'
                  3='(3) Somewhat Disagree (YECRIME = 3)'
                  4='(4) Strongly Disagree (YECRIME = 4)' 99='(99) Otherwise' ;
  VALUE nghdfght  1='(1) Strongly Agree (YESTFGT = 1)'
                  2='(2) Somewhat Agree (YESTFGT = 2)'
                  3='(3) Somewhat Disagree (YESTFGT = 3)'
                  4='(4) Strongly Disagree (YESTFGT = 4)' 99='(99) Otherwise' ;
  VALUE nghdgraf  1='(1) Strongly Agree (YEGRAFTI = 1)'
                  2='(2) Somewhat Agree (YEGRAFTI = 2)'
                  3='(3) Somewhat Disagree (YEGRAFTI = 3)'
                  4='(4) Strongly Disagree (YEGRAFTI = 4)' 99='(99) Otherwise' ;
  VALUE nghdhelp  1='(1) Strongly Agree (YEPPHLP = 1)'
                  2='(2) Somewhat Agree (YEPPHLP = 2)'
                  3='(3) Somewhat Disagree (YEPPHLP = 3)'
                  4='(4) Strongly Disagree (YEPPHLP = 4)' 99='(99) Otherwise' ;
  VALUE nghdmove  1='(1) Strongly Agree (YEPPMOVE = 1)'
                  2='(2) Somewhat Agree (YEPPMOVE = 2)'
                  3='(3) Somewhat Disagree (YEPPMOVE = 3)'
                  4='(4) Strongly Disagree (YEPPMOVE = 4)' 99='(99) Otherwise' ;
  VALUE nghdrace  1='(1) Strongly Agree (YESMRACE = 1)'
                  2='(2) Somewhat Agree (YESMRACE = 2)'
                  3='(3) Somewhat Disagree (YESMRACE = 3)'
                  4='(4) Strongly Disagree (YESMRACE = 4)' 99='(99) Otherwise' ;
  VALUE nghdsafe  1='(1) Strongly Agree (YESAFE = 1)'
                  2='(2) Somewhat Agree (YESAFE= 2)'
                  3='(3) Somewhat Disagree (YESAFE = 3)'
                  4='(4) Strongly Disagree (YESAFE = 4)' 99='(99) Otherwise' ;
  VALUE nghdsell  1='(1) Strongly Agree (YESLLDG = 1)'
                  2='(2) Somewhat Agree (YESLLDG = 2)'
                  3='(3) Somewhat Disagree (YESLLDG = 3)'
                  4='(4) Strongly Disagree (YESLLDG = 4)' 99='(99) Otherwise' ;
  VALUE nghdviol  1='(1) Strongly Agree (YEFMVIOL = 1)'
                  2='(2) Somewhat Agree (YEFMVIOL = 2)'
                  3='(3) Somewhat Disagree (YEFMVIOL = 3)'
                  4='(4) Strongly Disagree (YEFMVIOL = 4)' 99='(99) Otherwise' ;
  VALUE nghdvsit  1='(1) Strongly Agree (YEPPVSIT = 1)'
                  2='(2) Somewhat Agree (YEPPVSIT = 2)'
                  3='(3) Somewhat Disagree (YEPPVSIT = 3)'
                  4='(4) Strongly Disagree (YEPPVSIT = 4)' 99='(99) Otherwise' ;
  VALUE paraldly  1='(1) Neither Approve or Disapprove (YEPALDLY'
                  2='(2) Somewhat Disapprove (YEPALDLY = 2)'
                  3='(3) Strongly Disapprove (YEPALDLY = 3)' 99='(99) Otherwise' ;
  VALUE parchkhw  1='(1) Always (YEPCHKHW = 1)' 2='(2) Sometimes (YEPCHKHW = 2)'
                  3='(3) Seldom (YEPCHKHW = 3)' 4='(4) Never (YEPCHKHW = 4)'
                  99='(99) Otherwise' ;
  VALUE parchore  1='(1) Always (YEPCHORE = 1)' 2='(2) Sometimes (YEPCHORE = 2)'
                  3='(3) Seldom (YEPCHORE = 3)' 4='(4) Never (YEPCHORE = 4)'
                  99='(99) Otherwise' ;
  VALUE pargdjob  1='(1) Always (YEPGDJOB = 1)' 2='(2) Sometimes (YEPGDJOB = 2)'
                  3='(3) Seldom (YEPGDJOB = 3)' 4='(4) Never (YEPGDJOB = 4)'
                  99='(99) Otherwise' ;
  VALUE parhlphw  1='(1) Always (YEPHLPHW = 1)' 2='(2) Sometimes (YEPHLPHW = 2)'
                  3='(3) Seldom (YEPHLPHW = 3)' 4='(4) Never (YEPHLPHW = 4)'
                  99='(99) Otherwise' ;
  VALUE parlmtsn  1='(1) Always (YEPLMTSN = 1)' 2='(2) Sometimes (YEPLMTSN = 2)'
                  3='(3) Seldom (YEPLMTSN = 3)' 4='(4) Never (YEPLMTSN = 4)'
                  99='(99) Otherwise' ;
  VALUE parlmttv  1='(1) Always (YEPLMTTV = 1)' 2='(2) Sometimes (YEPLMTTV = 2)'
                  3='(3) Seldom (YEPLMTTV = 3)' 4='(4) Never YEPLMTTV = 4)'
                  99='(99) Otherwise' ;
  VALUE parmjevr  1='(1) Neither Approve or Disapprove (YEPMJEVR'
                  2='(2) Somewhat Disapprove (YEPMJEVR = 2)'
                  3='(3) Strongly Disapprove (YEPMJEVR = 3)' 99='(99) Otherwise' ;
  VALUE parmjmo   1='(1) Neither Approve or Disapprove (YEPMJMO ='
                  2='(2) Somewhat Disapprove (YEPMJMO = 2)'
                  3='(3) Strongly Disapprove (YEPMJMO = 3)' 99='(99) Otherwise' ;
  VALUE parpkcig  1='(1) Neither Approve or Disapprove (YEPPKCIG'
                  2='(2) Somewhat Disapprove (YEPPKCIG = 2)'
                  3='(3) Strongly Disapprove (YEPPKCIG = 3)' 99='(99) Otherwise' ;
  VALUE parproud  1='(1) Always (YEPPROUD = 1)' 2='(2) Sometimes (YEPPROUD = 2)'
                  3='(3) Seldom (YEPPROUD = 3)' 4='(4) Never (YEPPROUD = 4)'
                  99='(99) Otherwise' ;
  VALUE prtalk9f  0='(0) Otherwise' 1='(1) Yes (YEPAR98 = 1)' ;
  VALUE schfelt   1='(1) I liked going to School a Lot (YESCHFLT'
                  2='(2) I kind of liked going to school (YESCHFL'
                  3='(3) I did not like going to school (YESCHFL'
                  4='(4) I hated going to school (YESCHFLT = 4)' 99='(99) Otherwise' ;
  VALUE schgdjob  1='(1) Always (YETCGJOB = 1)' 2='(2) Sometimes (YETCGJOB = 2)'
                  3='(3) Seldom (YETCGJOB = 3)' 4='(4) Never (YETCGJOB = 4)'
                  99='(99) Otherwise' ;
  VALUE schgrade  1='(1) A Average (YELSTGRD = 1)' 2='(2) B Average (YELSTGRD = 2)'
                  3='(3) C Average (YELSTGRD = 3)'
                  4='(4) D Average or Less (YELSTGRD = 4)' 99='(99) Otherwise' ;
  VALUE schimprt  1='(1) Very Important (YESCHIMP = 1)'
                  2='(2) Somewhat Important (YESCHIMP = 2)'
                  3='(3) Somewhat Unimportant (YESCHIMP = 3)'
                  4='(4) Very Unimportant (YESCHIMP = 4)' 99='(99) Otherwise' ;
  VALUE schintrt  1='(1) Very Important (YESCHINT = 1)'
                  2='(2) Somewhat Important (YESCHINT = 2)'
                  3='(3) Somewhat Unimportant (YESCHINT = 3)'
                  4='(4) Very Unimportant (YESCHINT = 4)' 99='(99) Otherwise' ;
  VALUE schwork   1='(1) I always felt this way (YESCHWRK = 1)'
                  2='(2) I sometimes felt this way (YESCHWRK = 2)'
                  3='(3) I seldom felt this way (YESCHWRK = 3)'
                  4='(4) I never felt this way (YESCHWRK = 4)' 99='(99) Otherwise' ;
  VALUE stdndalc  1='(1) A Lot of Trouble (YETRDALC = 1)'
                  2='(2) A Little Trouble (YETRDALC = 2)'
                  3='(3) No Trouble (YETRDALC = 3)' 99='(99) Otherwise' ;
  VALUE stdnpalc  1='(1) A Lot of Trouble (YETRPALC = 1)'
                  2='(2) A Little Trouble (YETRPALC = 2)'
                  3='(3) No Trouble (YETRPALC = 3)' 99='(99) Otherwise' ;
  VALUE stdnpcig  1='(1) A Lot of Trouble (YETRPCIG = 1)'
                  2='(2) A Little Trouble (YETRPCIG = 2)'
                  3='(3) No Trouble (YETRPCIG = 3)' 99='(99) Otherwise' ;
  VALUE stdnpidg  1='(1) A Lot of Trouble (YETRPIDG = 1)'
                  2='(2) A Little Trouble (YETRPIDG = 2)'
                  3='(3) No Trouble (YETRPIDG = 3)' 99='(99) Otherwise' ;
  VALUE stdnscig  1='(1) A Lot of Trouble (YETRSCIG = 1)'
                  2='(2) A Little Trouble (YETRSCIG = 2)'
                  3='(3) No Trouble (YETRSCIG = 3)' 99='(99) Otherwise' ;
  VALUE stdnuidg  1='(1) A Lot of Trouble (YETRUIDG = 1)'
                  2='(2) A Little Trouble (YETRUIDG = 2)'
                  3='(3) No Trouble (YETRUIDG = 3)' 99='(99) Otherwise' ;
  VALUE stdntalc  1='(1) None of Them (YESTSALC = 1)'
                  2='(2) A few of Them (YESTSALC = 2)'
                  3='(3) Most of Them (YESTSALC = 3)'
                  4='(4) All of Them (YESTSALC = 4)' 99='(99) Otherwise' ;
  VALUE stdntcig  1='(1) None of Them (YESTSCIG = 1)'
                  2='(2) A few of Them (YESTSCIG = 2)'
                  3='(3) Most of Them (YESTSCIG = 3)'
                  4='(4) All of Them (YESTSCIG = 4)' 99='(99) Otherwise' ;
  VALUE stdntdnk  1='(1) None of Them (YESTSDNK = 1)'
                  2='(2) A few of Them (YESTSDNK = 2)'
                  3='(3) Most of Them (YESTSDNK = 3)'
                  4='(4) All of Them (YESTSDNK = 4)' 99='(99) Otherwise' ;
  VALUE stdntmj   1='(1) None of Them (YESTSMJ = 1)'
                  2='(2) A few of Them (YESTSMJ = 2)'
                  3='(3) Most of Them (YESTSMJ = 3)'
                  4='(4) All of Them (YESTSMJ = 4)' 99='(99) Otherwise' ;
  VALUE strespyr  1='(1) Very stressful (YEYSTRES=1)'
                  2='(2) Somewhat stressful (YEYSTRES=2)'
                  3='(3) Not very stressful (YEYSTRES=3)'
                  4='(4) Not at all stressful (YEYSTRES=4)' 99='(99) Otherwise' ;
  VALUE tlkadult  1='(1) RESPONSE MARKED (Any Source = 1,3,5,11,1'
                  2='(2) RESPONSE NOT MARKED (All Source = 6)'
                  3='(3) UNKNOWN (All Source = 85,95,97,98)'
                  4='(4) RESPONDENTS AGED 18 + (All Source = 89,' ;
  VALUE tlkbgf    1='(1) RESPONSE MARKED (YETLBGF = 1,3,5,11,13,1'
                  2='(2) RESPONSE NOT MARKED (YETLKBGF = 6)'
                  3='(3) UNKNOWN (YETLKBGF = 85,95,97,98)'
                  4='(4) RESPONDENTS AGED 18 + (YETLKBGF = 89,99)' ;
  VALUE tlkdad    1='(1) RESPONSE MARKED (YETLKDAD = 1,3,5,11,13,'
                  2='(2) RESPONSE NOT MARKED (YETLKDAD = 6)'
                  3='(3) UNKNOWN (YETLKDAD = 85,95,97,98)'
                  4='(4) RESPONDENTS AGED 18 + (YETLKDAD = 89,99)' ;
  VALUE tlkmom    1='(1) RESPONSE MARKED (YETLKMOM = 1,3,5,11,13,'
                  2='(2) RESPONSE NOT MARKED (YETLKMOM = 6)'
                  3='(3) UNKNOWN (YETLKMOM = 85,95,97,98)'
                  4='(4) RESPONDENTS AGED 18 + (YETLKMOM = 89,99)' ;
  VALUE tlknon    1='(1) RESPONSE MARKED (YETLKNON = 1,11,13,15)'
                  2='(2) RESPONSE NOT MARKED (YETLKNON = 6)'
                  3='(3) UNKNOWN (YETLKNON = 85,95,97,98)'
                  4='(4) RESPONDENTS AGED 18 + (YETLKNON = 89,99)' ;
  VALUE tlknonad  1='(1) RESPONSE MARKED (Any Source = 1,3,5,11,1'
                  2='(2) RESPONSE NOT MARKED (All Source = 6)'
                  3='(3) UNKNOWN (All Source = 85,95,97,98)'
                  4='(4) RESPONDENTS AGED 18 + (All Source = 89,' ;
  VALUE tlkother  1='(1) RESPONSE MARKED (Any Source = 1,3,5,11,1'
                  2='(2) RESPONSE NOT MARKED (All Source = 6)'
                  3='(3) UNKNOWN (All Source = 85,95,97,98)'
                  4='(4) RESPONDENTS AGED 18 + (All Source = 89,' ;
  VALUE ytfladly  1='(1) Neither Approve or Disapprove (YEGALDL'
                  2='(2) Somewhat Disapprove (YEGALDLY = 2)'
                  3='(3) Strongly Disapprove (YEGALDLY = 3)' 99='(99) Otherwise' ;
  VALUE ytflpkcg  1='(1) Neither Approve or Disapprove (YEGPKCI'
                  2='(2) Somewhat Disapprove (YEGPKCIG = 2)'
                  3='(3) Strongly Disapprove (YEGPKCIG = 3)' 99='(99) Otherwise' ;
  VALUE ytfltmrj  1='(1) Neither Approve or Disapprove (YEGMJEV'
                  2='(2) Somewhat Disapprove (YEGMJEVR = 2)'
                  3='(3) Strongly Disapprove (YEGMJEVR = 3)' 99='(99) Otherwise' ;
  VALUE ytflumrj  1='(1) Neither Approve or Disapprove (YEGMJMO'
                  2='(2) Somewhat Disapprove (YEGMJMO = 2)'
                  3='(3) Strongly Disapprove (YEGMJMO = 3)' 99='(99) Otherwise' ;
  VALUE ythargue  1='(1) None (YEYARGUP = 1)' 2='(2) 1 or 2 Times (YEYARGUP = 2)'
                  3='(3) 3 to 5 Times (YEYARGUP = 3)'
                  4='(4) 6 to 9 Times (YEYARGUP = 4)'
                  5='(5) 10 or More Times (YEYARGUP = 5)' 99='(99) Otherwise' ;
  VALUE ythattak  1='(1) None (YEYATTAK = 1)' 2='(2) 1 or 2 Times (YEYATTAK = 2)'
                  3='(3) 3 to 5 Times (YEYATTAK = 3)'
                  4='(4) 6 to 9 Times (YEYATTAK = 4)'
                  5='(5) 10 or More Times (YEYATTAK = 5)' 99='(99) Otherwise' ;
  VALUE ythfight  1='(1) None (YEYFGTSW = 1)' 2='(2) 1 or 2 Times (YEYFGTSW = 2)'
                  3='(3) 3 to 5 Times (YEYFGTSW = 3)'
                  4='(4) 6 to 9 Times (YEYFGTSW = 4)'
                  5='(5) 10 or More Times (YEYFGTSW = 5)' 99='(99) Otherwise' ;
  VALUE ythgrpft  1='(1) None (YEYFGTGP = 1)' 2='(2) 1 or 2 Times (YEYFGTGP = 2)'
                  3='(3) 3 to 5 Times (YEYFGTGP = 3)'
                  4='(4) 6 to 9 Times (YEYFGTGP = 4)'
                  5='(5) 10 or More Times (YEYFGTGP = 5)' 99='(99) Otherwise' ;
  VALUE ythhgun   1='(1) None (YEYHGUN = 1)' 2='(2) 1 or 2 Times (YEYHGUN = 2)'
                  3='(3) 3 to 5 Times (YEYHGUN = 3)'
                  4='(4) 6 to 9 Times (YEYHGUN = 4)'
                  5='(5) 10 or More Times (YEYHGUN = 5)' 99='(99) Otherwise' ;
  VALUE ythsell   1='(1) None (YEYSELL = 1)' 2='(2) 1 or 2 Times (YEYSELL = 2)'
                  3='(3) 3 to 5 Times (YEYSELL = 3)'
                  4='(4) 6 to 9 Times (YEYSELL = 4)'
                  5='(5) 10 or More Times (YEYSELL = 5)' 99='(99) Otherwise' ;
  VALUE ythstole  1='(1) None (YEYSTOLE = 1)' 2='(2) 1 or 2 Times (YEYSTOLE = 2)'
                  3='(3) 3 to 5 Times (YEYSTOLE = 3)'
                  4='(4) 6 to 9 Times (YEYSTOLE = 4)'
                  5='(5) 10 or More Times (YEYSTOLE = 5)' 99='(99) Otherwise' ;
  VALUE eiidate   1='(1) Interview date established from question'
                  2='(2) Interview date logically imputed' ;
  VALUE bhour     98='(98) BLANK (NO ANSWER)' ;
  VALUE bmin      98='(98) BLANK (NO ANSWER)' ;
  VALUE bap       1='(1) AM' 2='(2) PM' 98='(98) BLANK (NO ANSWER)' ;
  VALUE etimehr   98='(98) BLANK (NO ANSWER)' ;
  VALUE etimemn   98='(98) BLANK (NO ANSWER)' ;
  VALUE eap       1='(1) AM' 2='(2) PM' 96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' ;
  VALUE undint    1='(1) No difficulty--no language or reading pr'
                  2='(2) Just a little difficulty--almost no lang'
                  3='(3) A fair amount of difficulty--some lang/r'
                  4='(4) A lot of difficulty--considerable lang/r'
                  94='(94) DON''T KNOW' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able t'
                  2='(2) Fairly private-prsn in room/lstng less t'
                  3='(3) Somewhat private-prsn in room/lstng less'
                  4='(4) Not very private-serious intrp more than'
                  5='(5) Not private at all-constant presence of'
                  85='(85) BAD DATA Logically assigned' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE spres     2='(2) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE parpres   3='(3) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oarpres   4='(4) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oapres    5='(5) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cpres     6='(6) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresnsp  7='(7) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresspa  11='(11) Ex-Spouse' 20='(20) Parent/Guardian'
                  37='(37) Child, Relation Unspecified' 40='(40) Sibling'
                  50='(50) Grandparent/Great+ Grandparent'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin/Cousins Spouse'
                  82='(82) Housekeeper/Maid/Caretaker/Butler'
                  83='(83) Nurse/Health Care Aide/Home Care Worker'
                  84='(84) Neighbor/Co-Worker/Visitor/Employee/Empl'
                  85='(85) Landlord/Home Owner'
                  90='(90) Other Relative, Gender not specified'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified' 110='(110) Husband'
                  120='(120) Father/Male Guardian'
                  121='(121) Step/Adopted/Foster Father/Future Step F' 130='(130) Son'
                  131='(131) Step/Adopted/Foster Son' 132='(132) Son In-Law'
                  133='(133) Grandson' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 172='(172) Nephew'
                  191='(191) Other Male Non-Relative' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  230='(230) Daughter' 231='(231) Step/Adopted/Foster Daughter'
                  233='(233) Granddaughter' 240='(240) Sister/Half Sister'
                  250='(250) Grandmother/Great+ Grandmother'
                  260='(260) Female Live-In Partner'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  272='(272) Niece' 291='(291) Other Female Non-Relative'
                  292='(292) Other Female, Relation Unspecified'
                  321='(321) Step/Adopted/Foster Parents/Future Step'
                  330='(330) Own Children/Own Half Children'
                  337='(337) Children, Relation Unspecified'
                  350='(350) Grandparents/Great+ Grandparents'
                  361='(361) Friends/Roommates/Companions'
                  371='(371) Cousins/Cousins Spouses'
                  384='(384) Neighbors/Co-Workers/Visitors/Employees/'
                  390='(390) Other Relatives, Gender not specified'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified'
                  437='(437) Male children, Relation Unspecified'
                  440='(440) Brothers/Half Brothers' 540='(540) Sisters/Half Sisters'
                  900='(900) NOT A PERSON' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE opresspb  37='(37) Child, Relation Unspecified'
                  61='(61) Friend/Roommate/Companion'
                  91='(91) Other Non-Relative, Gender not specified' 130='(130) Son'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  237='(237) Female child, Relation Unspecified'
                  240='(240) Sister/Half Sister' 242='(242) Sister In-Law'
                  283='(283) Female Nurse/Health Care Aide/Home Care'
                  337='(337) Children, Relation Unspecified'
                  361='(361) Friends/Roommates/Companions' 900='(900) NOT A PERSON'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE whomarkd  1='(1) Respondent marked all the Answer Sheet r'
                  2='(2) Interviewer marked some or all of Ans Sh'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE quarter   1='(1) Quarter 1' 2='(2) Quarter 2' 3='(3) Quarter 3' 4='(4) Quarter 4' ;
  VALUE gqtype    1='(1) Halfway House' 2='(2) Boarding House' 3='(3) College Dorm'
                  4='(4) Shelter' 5='(5) Other' 9='(9) Not Group Quarters' ;
  VALUE pden      1='(1) Segment in a MSA with 1 million or more'
                  2='(2) Segment in a MSA with fewer than 1 milli'
                  3='(3) Segment not in MSA' ;
  VALUE pden2fff  1='(1) Segment in MSA with 1 million or more pe'
                  2='(2) Segm. in a MSA from 250000 to 999999 per'
                  3='(3) Segment in a MSA with fewer than 250000'
                  4='(4) Segment not in a MSA and not in a rural'
                  5='(5) Segment not in a MSA and in a rural area' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE divis2ff  1='(1) New England and Middle Atlantic'
                  2='(2) North Central (East and West)' 3='(3) South Atlantic'
                  4='(4) South Central (East and West)' 5='(5) Mountain' 6='(6) Pacific' ;
  VALUE bpconc    1='(1) 0 TO < 10%' 2='(2) 10 TO < 50 %' 3='(3) 50% and over' ;
  VALUE nhnbpcon  1='(1) 0 TO < 10%' 2='(2) 10 TO < 50 %' 3='(3) 50% and over' ;
  VALUE nhnbhcon  1='(1) 0 TO < 10%' 2='(2) 10 TO < 50 %' 3='(3) 50% and over' ;
  VALUE hsphconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE hsppconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE nhbhconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE nhbpconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 percent' ;
  VALUE ownoconc  1='(1) Greater than or equaled 50 percent'
                  2='(2) Greater than or equaled 10 pcnt, less th'
                  3='(3) Less than 10 pcnt' ;
  VALUE rurorurb  1='(1) Rural' 2='(2) Urban' ;
  VALUE urbpct2f  1='(1) 0 TO < 10%' 2='(2) 10 TO < 50 %' 3='(3) 50% and over' ;
  VALUE alcdaysf  1='(1) None or never used alcohol (ALCDAYS=81,8'
                  2='(2) 1-2 days (ALCDAYS = 1-2,35)'
                  3='(3) 3-4 days (ALCDAYS = 3-4)' 4='(4) 5-19 days (ALCDAYS = 5-19)'
                  5='(5) 20-30 days (ALCDAYS = 20-30)'
                  6='(6) UNKNOWN (ALCDAYS = 85,94,95,97,98)' ;
  VALUE alcday0f  1='(1) 0 (ALCDAYS2 = 1)' 2='(2) 1-4 (ALCDAYS2 = 2,3)'
                  3='(3) 5-19 (ALCDAYS2 = 4)' 4='(4) 20-30 (ALCDAYS2 = 5)'
                  6='(6) UNKNOWN (ALCDAYS2 = 6)' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes (ALCFLAG = 1 AND SUMFLAG = 1)' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes (ALCMON = 1 AND SUMMON = 1)' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes (ALCYR = 1 AND SUMYR = 1)' ;
  VALUE alcmrjl   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alcmrjm   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alcmrjy   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes (ALCFLAG=1 AND SUMFLAG=0)' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes (ALCMON=1 AND SUMMON=0)' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes (ALCYR=1 AND SUMYR=0)' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alcprbsf  0='(0) No' 1='(1) Yes (ANY SOURCE VARIABLE = 1)' ;
  VALUE alc2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE alc3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE alcpsyl   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alcpsym   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alcpsyy   0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE alctry2f  99='(99) NEVER USED/UNKNOWN (ALCTRY = 981-998)' ;
  VALUE alcuse    1='(1) Less than 12 days (IRALCFQ=7-9)'
                  2='(2) 12-50 days (1-4 days/month) (IRALCFQ=5-6'
                  3='(3) 51-300 days (1-7 days/week) (IRALCFQ=2-4'
                  4='(4) More than 300 days (daily or almost) (IR'
                  5='(5) HAS NOT USED IN PAST YEAR (IRALCFQ=10)' ;
  VALUE analagef  99='(99) NEVER USED/UNKNOWN (ANALAGE = 981-998)' ;
  VALUE avcig2ff  1='(1) 0 (AVCIG = 81,83,91,93)'
                  2='(2) 15 cigarettes or less (AVCIG = 1-3)'
                  3='(3) 16 cigarettes or more (AVCIG = 4-6)'
                  4='(4) UNKNOWN (AVCIG = 85,94,95,98)' ;
  VALUE avcig3ff  0='(0) No (AVCIG = 1-3,81,83,85,91,93,94,98)'
                  1='(1) Yes (AVCIG = 4-6)' ;
  VALUE bingdrkf  0='(0) No (BINGEDRK = . OR BINGEDRK = 0)'
                  1='(1) Yes (BINGEDRK = 1)' ;
  VALUE bkagaslf  0='(0) No (BKAGASLT = 2,89,97,98,99)' 1='(1) Yes (BKAGASLT = 1,3)' ;
  VALUE bkanylaw  0='(0) No' 1='(1) Yes (Any source variable = 1)' ;
  VALUE bkarsonf  0='(0) No (BKARSON = 2,89,97,98,99)' 1='(1) Yes (BKARSON = 1)' ;
  VALUE bkburglf  0='(0) No (BKBURGL = 2,89,97,98,99)' 1='(1) Yes (BKBURGL = 1,3)' ;
  VALUE bkdrug2f  0='(0) No (BKDRUG = 2,89,97,98,99)' 1='(1) Yes (BKDRUG = 1)' ;
  VALUE bkdrunkf  0='(0) No (BKDRUNK = 2,89,97,98,99)' 1='(1) Yes (BKRUNK = 1,3)' ;
  VALUE bkdrvi0f  0='(0) No (BKDRVINF = 2,89,97,98,99)' 1='(1) Yes (BKDRVINF = 1,3)' ;
  VALUE bklarcnf  0='(0) No (BKLARCNY = 2,89,97,98,99)' 1='(1) Yes (BKLARCNY = 1,3)' ;
  VALUE bkmvthff  0='(0) No (BKMVTHFT = 2,89,97,98,99)' 1='(1) Yes (BKMVTHFT = 1,3)' ;
  VALUE bkrob2ff  0='(0) No (BKROB = 2,89,97,98,99)' 1='(1) Yes (BKROB = 1)' ;
  VALUE bksmaslf  0='(0) No (BKSMASLT = 2,89,97,98,99)' 1='(1) Yes (BKMASLT = 1,3)' ;
  VALUE cigprbsf  0='(0) No' 1='(1) Yes (ANY SOURCE VARIABLE = 1)' ;
  VALUE cig2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE cig3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE cigtry2f  99='(99) NEVER USED/UNKNOWN (CIGTRY = 981-998)' ;
  VALUE cocprbsf  0='(0) No' 1='(1) Yes (ANY SOURCE VARIABLE = 1)' ;
  VALUE coc2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE coc3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE cocage2f  99='(99) NEVER USED/UNKNOWN (COCAGE = 981-998)' ;
  VALUE coctot3f  1='(1) 1-2 days (COCTOT = 5)' 2='(2) 3-11 days (COCTOT = 4)'
                  3='(3) 12-100 days (COCTOT = 3)' 4='(4) 101+ days (COCTOT = 1,2)'
                  5='(5) NEVER USED (COCTOT = 81,91)'
                  99='(99) UNKNOWN (COCTOT = 85,94,98)' ;
  VALUE cocuse    1='(1) Less than 12 days (IRCOCFQ=7-9)'
                  2='(2) 12-50 days (1-4 days/month) (IRCOCFQ=5-'
                  3='(3) 51-300 days (1-7 days/week) (IRCOCFQ=2-4'
                  4='(4) More than 300 days (daily or almost) (IR'
                  5='(5) Has not used in past year (IRCOCFQ=10)' ;
  VALUE dralhlpf  0='(0) No (TRMTHLP3=0 and DRNKHLP3=0)'
                  1='(1) Yes (TRMTHLP3=1 or DRNKHLP3=1)' 99='(99) UNKNOWN (Otherwise)' ;
  VALUE drinkerf  0='(0) No' 1='(1) Yes (DR5DAY=1-30,35,90 OR ALCMON=1)' ;
  VALUE drnkhlpf  0='(0) No (Otherwise)'
                  1='(1) Yes (ANY SOURCE VAR=1,3,5 and ALCFLAG=1)'
                  99='(99) NON USER/TRT (ANY SOURCE VAR=1,3,5 and A' ;
  VALUE dropmf    1='(1) School dropout (see above)'
                  2='(2) Not school dropout (Otherwise)'
                  99='(99) Respondents ages 26 and older' ;
  VALUE drunkyrf  1='(1) Yes (DRUNKYR = 1,2,3,4)'
                  2='(2) No (DRUNKYR=5,6,7,8,9,81,83,85,90,91,93,' ;
  VALUE dui       0='(0) No' 1='(1) Yes (ANY SOURCE VAR=1)& (ALCYR=1 or SUMY' ;
  VALUE fertage   1='(1) Women ages 15-25 (CATAG3 = 1,2 AND F15_4'
                  2='(2) Women ages 16-44 (CATAG3 = 3,4 AND F15_4'
                  99='(99) MEN/WOMEN AGE 12-14 and 45+ (F15_44=0)' ;
  VALUE hallagef  99='(99) NEVER USED/UNKNOWN (HALLAGE = 981-998)' ;
  VALUE herage2f  99='(99) NEVER USED/UNKNOWN (HERAGE = 981-998)' ;
  VALUE herneedf  0='(0) No (HERNEEDL=81,85,89,91,93,97,98,99)'
                  1='(1) Yes (HERNEEDL=1,3)' ;
  VALUE hvydrk3f  0='(0) No (HVYDRK2 = . OR HVYDRK2 = 0)' 1='(1) Yes (HVYDRK2 = 1)' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes (SUMFLAG=1 AND ALCFLAG=0)' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes (SUMMON=1 AND ALCMON=0)' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes (SUMYR=1 AND ALCYR=0)' ;
  VALUE inhage2f  99='(99) NEVER USED/UNKNOWN (INHAGE = 981-998)' ;
  VALUE iracalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and ACRDALC = 1)' ;
  VALUE iraccigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and ACRDCIG = 1)' ;
  VALUE iraccocf  0='(0) No' 1='(1) Yes (COCYR = 1 and ACRDCOC = 1)' ;
  VALUE iracmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and ACRDMRJ = 1)' ;
  VALUE irbtalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and BTOLALC = 1)' ;
  VALUE irbtcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and BTOLCIG = 1)' ;
  VALUE irbtcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and BTOLCOC = 1)' ;
  VALUE irbtmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and BTOLMRJ = 1)' ;
  VALUE iremalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and EMPBALC = 1)' ;
  VALUE iremcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and EMPBCIG = 1)' ;
  VALUE iremcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and EMPBCOC = 1)' ;
  VALUE iremmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and EMPBMRJ = 1)' ;
  VALUE irgralcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and GRTMALC = 1)' ;
  VALUE irgrcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and GRTMCIG = 1)' ;
  VALUE irgrcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and GRTMCOC = 1)' ;
  VALUE irgrmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and GRTMMRJ = 1)' ;
  VALUE irhlalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and HLPBALC = 1)' ;
  VALUE irhlcigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and HLPBCIG = 1)' ;
  VALUE irhlcocf  0='(0) No' 1='(1) Yes (COCYR = 1 and HLPBCOC = 1)' ;
  VALUE irhlmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and HLPBMRJ = 1)' ;
  VALUE irlaalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and LAMTALC = 1)' ;
  VALUE irlacigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and LAMTCIG = 1)' ;
  VALUE irlacocf  0='(0) No' 1='(1) Yes (COCYR = 1 and LAMTCOC = 1)' ;
  VALUE irlamrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and LAMTMRJ = 1)' ;
  VALUE irucalcf  0='(0) No' 1='(1) Yes (ALCYR = 1 and UCDALC = 1)' ;
  VALUE iruccigf  0='(0) No' 1='(1) Yes (CIGYR = 1 and UCDCIG = 1)' ;
  VALUE iruccocf  0='(0) No' 1='(1) Yes (COCYR = 1 and UCDCOC = 1)' ;
  VALUE irucmrjf  0='(0) No' 1='(1) Yes (MRJYR = 1 and UCDMRJ = 1)' ;
  VALUE maruse    1='(1) Less than 12 days (IRMJFQ = 7-9)'
                  2='(2) 12-50 days (1-4 days/month) (IRMJFQ = 5-'
                  3='(3) 51-300 days (1-7 days/week) (IRMJFQ = 2-'
                  4='(4) More than 300 days (daily or almost) (IR'
                  5='(5) Did not use in past year (IRMJFQ = 10)' ;
  VALUE mjage2ff  99='(99) NEVER USED/UNKNOWN (MJAGE = 981-998)' ;
  VALUE mjtot3ff  1='(1) 1-2 days (MJTOT = 5)' 2='(2) 3-11 days (MJTOT = 4)'
                  3='(3) 12-100 days (MJTOT = 3)' 4='(4) 101+ days (MJTOT = 1,2)'
                  5='(5) NEVER USED (MJTOT = 81,91)'
                  99='(99) UNKNOWN (MJTOT = 85,94,95,98)' ;
  VALUE mrjprbsf  0='(0) No' 1='(1) (ANY SOURCE VARIABLE = 1)' ;
  VALUE mrj2prbf  0='(0) No' 1='(1) Yes (ANY TWO OR MORE SOURCE VARIABLES =' ;
  VALUE mrj3prbf  0='(0) No' 1='(1) Yes (ANY THREE OR MORE SOURCE VARIABLES' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes (MJOFLAG=1 AND ALCFLAG=0)' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes (MJOMON2=1 AND ALCMON=0)' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes (MJOYR2=1 AND ALCYR=0)' ;
  VALUE notmarj   0='(0) No (All Source Variables = 0)'
                  1='(1) Yes (Any Source Variables = 1)' ;
  VALUE othonlyl  0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE othonlym  0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE othonlyy  0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE preg3fff  1='(1) Pregnant (PREG2 = 1 and F15_44 = 1)'
                  2='(2) Not pregnant (PREG2 = 2 and F15_44 = 1)'
                  99='(99) Men/Women 12-14 and 45+ (F15_44=0)' ;
  VALUE psyage    99='(99) NEVER USED/UNKNOWN (ALL SOURCE VARS = 98' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes (See Comment Above)' ;
  VALUE racesex   1='(1) White male (IRSEX = 1 AND RACE = 1)'
                  2='(2) Black male (IRSEX = 1 AND RACE = 2)'
                  3='(3) Hispanic male (IRSEX = 1 AND RACE = 3)'
                  4='(4) White female (IRSEX = 2 AND RACE = 1)'
                  5='(5) Black female (IRSEX = 2 AND RACE = 2)'
                  6='(6) Hispanic female (IRSEX = 2 AND RACE = 3)'
                  99='(99) Other Males and Females (IRSEX=1,2 and R' ;
  VALUE racesexf  1='(1) White male (IRSEX = 1 AND RACE = 1)'
                  2='(2) Black male (IRSEX = 1 AND RACE = 2)'
                  3='(3) Hispanic male (IRSEX = 1 AND RACE = 3)'
                  4='(4) Other male (IRSEX = 1 AND RACE = 4)'
                  5='(5) White female (IRSEX = 2 AND RACE = 1)'
                  6='(6) Black female (IRSEX = 2 AND RACE = 2)'
                  7='(7) Hispanic female (IRSEX = 2 AND RACE = 3)'
                  8='(8) Other female (IRSEX = 2 AND RACE = 4)' ;
  VALUE rdifcoc   0='(0) Not easy (RKDIFCOC = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFCOC'
                  99='(99) UNKNOWN (RKDIFCOC = 94,95,96,97,98)' ;
  VALUE rdifcrk   0='(0) Not easy (RKDIFCRK = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFCRK'
                  99='(99) UNKNOWN (RKDIFCRK = 94,95,96,97,98)' ;
  VALUE rdifher   0='(0) Not easy (RKDIFHER = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFHER'
                  99='(99) UNKNOWN (RKDIFHER = 94,95,96,97,98)' ;
  VALUE rdiflsd   0='(0) Not easy (RKDIFLSD = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFLSD'
                  99='(99) UNKNOWN (RKDIFLSD = 94,95,96,97,98)' ;
  VALUE rdifmj    0='(0) Not easy (RKDIFMJ = 1,2,3)'
                  1='(1) Fairly or very easy to obtain (RKDIFMJ ='
                  99='(99) UNKNOWN (RKDIFMJ = 94,95,96,97,98)' ;
  VALUE rskalc1f  0='(0) No (RK5DRINK = 1,2,3)' 1='(1) Yes (RK5DRINK = 4)'
                  99='(99) UNKNOWN (RK5DRINK = 94,96,97,98)' ;
  VALUE rskalc2f  0='(0) No (RSKBINGE = 1,2,3)' 1='(1) Yes (RSKBINGE = 4)'
                  99='(99) UNKNOWN (RSKBINGE = 94,96,97,98)' ;
  VALUE rskcig    0='(0) No (RSKPKCIG = 1,2,3)' 1='(1) Yes (RSKPKCIG = 4)'
                  99='(99) UNKNOWN (RSKPKCIG = 94,96,97,98)' ;
  VALUE rskcoc1f  0='(0) No (RKCOCOCC = 1,2,3)' 1='(1) Yes (RKCOCOCC = 4)'
                  99='(99) UNKNOWN (RKCOCOCC = 94,96,97,98)' ;
  VALUE rskcoc2f  0='(0) No (RKCOCREG = 1,2,3)' 1='(1) Yes (RKCOCREG = 4)'
                  99='(99) UNKNOWN (RKCOCREG = 94,96,97,98)' ;
  VALUE rskher1f  0='(0) No (RKHERREG = 1,2,3)' 1='(1) Yes (RKHERREG = 4)'
                  99='(99) UNKNOWN (RKHERREG = 94,96,97,98)' ;
  VALUE rskher2f  0='(0) No (RKTRYHER = 1,2,3)' 1='(1) Yes (RKTRYHER = 4)'
                  99='(99) UNKNOWN (RKTRYHER = 94,96,97,98)' ;
  VALUE rsklsd1f  0='(0) No (RKTRYLSD = 1,2,3)' 1='(1) Yes (RKTRYLSD = 4)'
                  99='(99) UNKNOWN (RKTRYLSD = 94,96,97,98)' ;
  VALUE rskmj1ff  0='(0) No (RSKMJOCC = 1,2,3)' 1='(1) Yes (RSKMJOCC = 4)'
                  99='(99) UNKNOWN (RSKMJOCC = 94,96,97,98)' ;
  VALUE rskmj2ff  0='(0) No (RSKMJREG = 1,2,3)' 1='(1) Yes (RSKMJREG = 4)'
                  99='(99) UNKNOWN (RSKMJREG = 94,96,97,98)' ;
  VALUE rsksellf  0='(0) No (RSKSELL = 2,94,96,97,98)' 1='(1) Yes (RSKSELL = 1)' ;
  VALUE sbeltrsk  0='(0) No' 1='(1) Yes (RKFQPBLT = 1,2 or RKFQDBLT = 1,2)' ;
  VALUE sedage2f  99='(99) NEVER USED/UNKNOWN (SEDAGE = 981-998)' ;
  VALUE stimagef  99='(99) NEVER USED/UNKNOWN (STIMAGE = 981-998)' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes (Only one Source Var=1)' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes (Only one Source Var=1)' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes (Only one Source Var=1)' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes (Only two Source Vars=1)' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes (Only two Source Vars=1)' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes (Only two Source Vars=1)' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes (3 or More Source Vars=1)' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes (3 or More Source Vars=1)' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes (3 or More Source Vars=1)' ;
  VALUE tranagef  99='(99) NEVER USED/UNKNOWN (TRANAGE = 981-998)' ;
  VALUE trimestf  1='(1) 1st 3 mos of pregnancy (TRIMEST=1 AND F1'
                  2='(2) 2nd 3 mos of pregnancy (TRIMEST=2 AND F1'
                  3='(3) Last 3 mos of pregnancy (TRIMEST=3 AND F'
                  99='(99) Otherwise (TRIMEST NE 1,2,3 or F15_44=0)' ;
  VALUE trmthlpf  0='(0) No (Otherwise)'
                  1='(1) Yes (ANY SOURCE VAR=1,3,5 and SUMFLAG=1)'
                  99='(99) NON USER/TRT (ANY SOURCE VAR=1,3,5 and S' ;
RUN;

* SAS DATA STEP;
DATA;
SET SAS-dataset ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (NOMARR2 >= 81) THEN NOMARR2 = .;
   IF (SERVICE >= 81) THEN SERVICE = .;
   IF (MILSTAT >= 81) THEN MILSTAT = .;
   IF (EDUC2 >= 81) THEN EDUC2 = .;
   IF (DIPLOMA >= 81) THEN DIPLOMA = .;
   IF (ENROLL97 >= 81) THEN ENROLL97 = .;
   IF (ENRL9497 >= 81) THEN ENRL9497 = .;
   IF (WORKSTAT >= 81) THEN WORKSTAT = .;
   IF (HEIGHT2 >= 981) THEN HEIGHT2 = .;
   IF (POUNDS2 >= 981) THEN POUNDS2 = .;
   IF (HEALTH >= 81) THEN HEALTH = .;
   IF (CIGEVER >= 81) THEN CIGEVER = .;
   IF (CIGTRY >= 981) THEN CIGTRY = .;
   IF (CIGTOT >= 81) THEN CIGTOT = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (CIG30USE >= 81) THEN CIG30USE = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (CIG30WOK >= 81) THEN CIG30WOK = .;
   IF (CIGEVYDA >= 81) THEN CIGEVYDA = .;
   IF (CIGAGE >= 981) THEN CIGAGE = .;
   IF (CIGYRS = 0) THEN CIGYRS = .;
   IF (CIGYRS >= 981) THEN CIGYRS = .;
   IF (SNUFEVER >= 81) THEN SNUFEVER = .;
   IF (SNUFREC >= 81) THEN SNUFREC = .;
   IF (SKPALCRD >= 81) THEN SKPALCRD = .;
   IF (ALCREAD >= 81) THEN ALCREAD = .;
   IF (ALCTRY >= 981) THEN ALCTRY = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (ALCPAT >= 81) THEN ALCPAT = .;
   IF (DRUNKYR >= 81) THEN DRUNKYR = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (NODR30A >= 81) THEN NODR30A = .;
   IF (DR5DAY >= 81) THEN DR5DAY = .;
   IF (MJAGE >= 981) THEN MJAGE = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (MJYRFREQ >= 81) THEN MJYRFREQ = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (SKPCOCRD >= 81) THEN SKPCOCRD = .;
   IF (COCREAD >= 81) THEN COCREAD = .;
   IF (COCAGE >= 981) THEN COCAGE = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (COCYRFRQ >= 81) THEN COCYRFRQ = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (SKPCRKRD >= 81) THEN SKPCRKRD = .;
   IF (CRKREAD >= 81) THEN CRKREAD = .;
   IF (CRKEVER >= 81) THEN CRKEVER = .;
   IF (CRKAGE >= 981) THEN CRKAGE = .;
   IF (CRKTOT >= 81) THEN CRKTOT = .;
   IF (CRAKREC >= 81) THEN CRAKREC = .;
   IF (CRKYRFRQ >= 81) THEN CRKYRFRQ = .;
   IF (CRKUS30A >= 81) THEN CRKUS30A = .;
   IF (SKPHERRD >= 81) THEN SKPHERRD = .;
   IF (HERREAD >= 81) THEN HERREAD = .;
   IF (HEREVER >= 81) THEN HEREVER = .;
   IF (HERAGE >= 981) THEN HERAGE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HERYRFRQ >= 81) THEN HERYRFRQ = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (SKPHALRD >= 81) THEN SKPHALRD = .;
   IF (HALREAD >= 81) THEN HALREAD = .;
   IF (LSD >= 81) THEN LSD = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (PEYOTE >= 81) THEN PEYOTE = .;
   IF (MESC >= 81) THEN MESC = .;
   IF (PSILCY >= 81) THEN PSILCY = .;
   IF (ECSTASY >= 81) THEN ECSTASY = .;
   IF (HALDKNAM >= 81) THEN HALDKNAM = .;
   IF (HALNOLST >= 81) THEN HALNOLST = .;
   IF (HALNEWA >= 9981) THEN HALNEWA = .;
   IF (HALNEWB >= 9981) THEN HALNEWB = .;
   IF (HALNEWC >= 9981) THEN HALNEWC = .;
   IF (HALNEWD >= 9981) THEN HALNEWD = .;
   IF (HALNEWE >= 9981) THEN HALNEWE = .;
   IF (HALLAGE >= 981) THEN HALLAGE = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HALYRFRQ >= 81) THEN HALYRFRQ = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (LSDREC >= 81) THEN LSDREC = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (SKPINHRD >= 81) THEN SKPINHRD = .;
   IF (INHREAD >= 81) THEN INHREAD = .;
   IF (AMYLNIT >= 81) THEN AMYLNIT = .;
   IF (CLEFLU >= 81) THEN CLEFLU = .;
   IF (GAS >= 81) THEN GAS = .;
   IF (GLUE >= 81) THEN GLUE = .;
   IF (ETHER >= 81) THEN ETHER = .;
   IF (SOLVENT >= 81) THEN SOLVENT = .;
   IF (LGAS >= 81) THEN LGAS = .;
   IF (NITOXID >= 81) THEN NITOXID = .;
   IF (SPPAINT >= 81) THEN SPPAINT = .;
   IF (AEROS >= 81) THEN AEROS = .;
   IF (INHDKNAM >= 81) THEN INHDKNAM = .;
   IF (INHNOLST >= 81) THEN INHNOLST = .;
   IF (INHNEWA >= 9981) THEN INHNEWA = .;
   IF (INHNEWB >= 9981) THEN INHNEWB = .;
   IF (INHNEWC >= 9981) THEN INHNEWC = .;
   IF (INHNEWD >= 9981) THEN INHNEWD = .;
   IF (INHNEWE >= 9981) THEN INHNEWE = .;
   IF (INHAGE >= 981) THEN INHAGE = .;
   IF (INHTOT >= 81) THEN INHTOT = .;
   IF (INHREC >= 81) THEN INHREC = .;
   IF (INHYRFRQ >= 81) THEN INHYRFRQ = .;
   IF (INHDY30A >= 81) THEN INHDY30A = .;
   IF (SKPANLRD >= 81) THEN SKPANLRD = .;
   IF (ANLREAD >= 81) THEN ANLREAD = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (METHDON >= 81) THEN METHDON = .;
   IF (MORPHINE >= 81) THEN MORPHINE = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (TALWIN >= 81) THEN TALWIN = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (ANLDKNAM >= 81) THEN ANLDKNAM = .;
   IF (ANLNOLST >= 81) THEN ANLNOLST = .;
   IF (ANALNEWA >= 9981) THEN ANALNEWA = .;
   IF (ANALNEWB >= 9981) THEN ANALNEWB = .;
   IF (ANALNEWC >= 9981) THEN ANALNEWC = .;
   IF (ANALNEWD >= 9981) THEN ANALNEWD = .;
   IF (ANALNEWE >= 9981) THEN ANALNEWE = .;
   IF (ANALNONE >= 81) THEN ANALNONE = .;
   IF (ANALAGE >= 981) THEN ANALAGE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (ANLYRFRQ >= 81) THEN ANLYRFRQ = .;
   IF (SKPTRNRD >= 81) THEN SKPTRNRD = .;
   IF (TRNREAD >= 81) THEN TRNREAD = .;
   IF (ATARAX >= 81) THEN ATARAX = .;
   IF (ATIVAN >= 81) THEN ATIVAN = .;
   IF (DIAZEPAM >= 81) THEN DIAZEPAM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (XANAX >= 81) THEN XANAX = .;
   IF (TRDKNAM >= 81) THEN TRDKNAM = .;
   IF (TRNOLST >= 81) THEN TRNOLST = .;
   IF (TRNEWA >= 9981) THEN TRNEWA = .;
   IF (TRNEWB >= 9981) THEN TRNEWB = .;
   IF (TRNEWC >= 9981) THEN TRNEWC = .;
   IF (TRNEWD >= 9981) THEN TRNEWD = .;
   IF (TRNEWE >= 9981) THEN TRNEWE = .;
   IF (NOTRANQ >= 81) THEN NOTRANQ = .;
   IF (TRANAGE >= 981) THEN TRANAGE = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (TRNYRFRQ >= 81) THEN TRNYRFRQ = .;
   IF (SKPSTMRD >= 81) THEN SKPSTMRD = .;
   IF (STMREAD >= 81) THEN STMREAD = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (FASTIN >= 81) THEN FASTIN = .;
   IF (IONAMIN >= 81) THEN IONAMIN = .;
   IF (METHAMP >= 81) THEN METHAMP = .;
   IF (METHI >= 81) THEN METHI = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (STMDKNAM >= 81) THEN STMDKNAM = .;
   IF (STMNOLST >= 81) THEN STMNOLST = .;
   IF (STIMNEWA >= 9981) THEN STIMNEWA = .;
   IF (STIMNEWB >= 9981) THEN STIMNEWB = .;
   IF (STIMNEWC >= 9981) THEN STIMNEWC = .;
   IF (STIMNEWD >= 9981) THEN STIMNEWD = .;
   IF (STIMNEWE >= 9981) THEN STIMNEWE = .;
   IF (NOSTIMS >= 81) THEN NOSTIMS = .;
   IF (STIMAGE >= 981) THEN STIMAGE = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STMYRFRQ >= 81) THEN STMYRFRQ = .;
   IF (SKPSEDRD >= 81) THEN SKPSEDRD = .;
   IF (SEDREAD >= 81) THEN SEDREAD = .;
   IF (DALMANE >= 81) THEN DALMANE = .;
   IF (HALCION >= 81) THEN HALCION = .;
   IF (METHAQ >= 81) THEN METHAQ = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (PHENOBAR >= 81) THEN PHENOBAR = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (SEDDKNAM >= 81) THEN SEDDKNAM = .;
   IF (SEDNOLST >= 81) THEN SEDNOLST = .;
   IF (SEDNEWA >= 9981) THEN SEDNEWA = .;
   IF (SEDNEWB >= 9981) THEN SEDNEWB = .;
   IF (SEDNEWC >= 9981) THEN SEDNEWC = .;
   IF (SEDNEWD >= 9981) THEN SEDNEWD = .;
   IF (SEDNEWE >= 9981) THEN SEDNEWE = .;
   IF (NOSEDAT >= 81) THEN NOSEDAT = .;
   IF (SEDAGE >= 981) THEN SEDAGE = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (SEDYRFRQ >= 81) THEN SEDYRFRQ = .;
   IF (BIRYEAR2 >= 9981) THEN BIRYEAR2 = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP = 9) THEN IIHOGRP = .;
   IF (IRHOGRP2 >= 81) THEN IRHOGRP2 = .;
   IF (IIHOGRP2 = 9) THEN IIHOGRP2 = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT = 9) THEN IIMARIT = .;
   IF (IREDUC2 >= 81) THEN IREDUC2 = .;
   IF (IRWORKST >= 81) THEN IRWORKST = .;
   IF (IRCIGRC = 9) THEN IRCIGRC = .;
   IF (IROTBRC = 9) THEN IROTBRC = .;
   IF (IRALCRC = 9) THEN IRALCRC = .;
   IF (IRMJRC = 9) THEN IRMJRC = .;
   IF (IRCOCRC = 9) THEN IRCOCRC = .;
   IF (IRCRKRC = 9) THEN IRCRKRC = .;
   IF (IRHERRC = 9) THEN IRHERRC = .;
   IF (IRHALRC = 9) THEN IRHALRC = .;
   IF (IRLSDRC = 9) THEN IRLSDRC = .;
   IF (IRPCPRC = 9) THEN IRPCPRC = .;
   IF (IRINHRC = 9) THEN IRINHRC = .;
   IF (IRANLRC = 9) THEN IRANLRC = .;
   IF (IRTRNRC = 9) THEN IRTRNRC = .;
   IF (IRSTMRC = 9) THEN IRSTMRC = .;
   IF (IRSEDRC = 9) THEN IRSEDRC = .;
   IF (IRALCFQ >= 81) THEN IRALCFQ = .;
   IF (IRMJFQ >= 81) THEN IRMJFQ = .;
   IF (IRCOCFQ >= 81) THEN IRCOCFQ = .;
   IF (IRCRKFQ >= 81) THEN IRCRKFQ = .;
   IF (IRHERFQ >= 81) THEN IRHERFQ = .;
   IF (IRHALFQ >= 81) THEN IRHALFQ = .;
   IF (IRINHFQ >= 81) THEN IRINHFQ = .;
   IF (IRANLFQ >= 81) THEN IRANLFQ = .;
   IF (IRTRNFQ >= 81) THEN IRTRNFQ = .;
   IF (IRSTMFQ >= 81) THEN IRSTMFQ = .;
   IF (IRSEDFQ >= 81) THEN IRSEDFQ = .;
   IF (MARISTAT = 3) THEN MARISTAT = .;
   IF (NOTMAR = 3) THEN NOTMAR = .;
   IF (BINGEDRK = 99) THEN BINGEDRK = .;
   IF (HVYDRK2 = 99) THEN HVYDRK2 = .;
   IF (BINGEHVY = 99) THEN BINGEHVY = .;
   IF (MJDY30A3 = 5 OR MJDY30A3 = 6) THEN MJDY30A3 = .;
   IF (CG04 >= 81) THEN CG04 = .;
   IF (CG12 >= 81) THEN CG12 = .;
   IF (AL03 >= 81) THEN AL03 = .;
   IF (AL04 >= 81) THEN AL04 = .;
   IF (MJ04 >= 81) THEN MJ04 = .;
   IF (MJ05 >= 81) THEN MJ05 = .;
   IF (CC04 >= 81) THEN CC04 = .;
   IF (CC05 >= 81) THEN CC05 = .;
   IF (CK04 >= 81) THEN CK04 = .;
   IF (CK05 >= 81) THEN CK05 = .;
   IF (HE04 >= 81) THEN HE04 = .;
   IF (HE05 >= 81) THEN HE05 = .;
   IF (LS04 >= 81) THEN LS04 = .;
   IF (LS05 >= 81) THEN LS05 = .;
   IF (LS07 >= 81) THEN LS07 = .;
   IF (LS08 >= 81) THEN LS08 = .;
   IF (IN04 >= 81) THEN IN04 = .;
   IF (IN05 >= 81) THEN IN05 = .;
   IF (PK04 >= 81) THEN PK04 = .;
   IF (PK05 >= 81) THEN PK05 = .;
   IF (TR04 >= 81) THEN TR04 = .;
   IF (TR05 >= 81) THEN TR05 = .;
   IF (ST04 >= 81) THEN ST04 = .;
   IF (ST05 >= 81) THEN ST05 = .;
   IF (SE04 >= 81) THEN SE04 = .;
   IF (SE05 >= 81) THEN SE05 = .;
   IF (SKPSDRD >= 81) THEN SKPSDRD = .;
   IF (SDREAD >= 81) THEN SDREAD = .;
   IF (HRANYFRM >= 81) THEN HRANYFRM = .;
   IF (HERSMOKE >= 81) THEN HERSMOKE = .;
   IF (HRSMKREC >= 81) THEN HRSMKREC = .;
   IF (HERSNIFF >= 81) THEN HERSNIFF = .;
   IF (HRSNFREC >= 81) THEN HRSNFREC = .;
   IF (GNNDLLIF >= 81) THEN GNNDLLIF = .;
   IF (COCNEEDL >= 81) THEN COCNEEDL = .;
   IF (CONDLREC >= 81) THEN CONDLREC = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (HRNDLREC >= 81) THEN HRNDLREC = .;
   IF (STNEEDLE >= 81) THEN STNEEDLE = .;
   IF (STNDLREC >= 81) THEN STNDLREC = .;
   IF (GNNDREUS >= 81) THEN GNNDREUS = .;
   IF (GNNDLSH1 >= 81) THEN GNNDLSH1 = .;
   IF (GNNDCLEN >= 81) THEN GNNDCLEN = .;
   IF (GNNDLSH2 >= 81) THEN GNNDLSH2 = .;
   IF (GNNDGET >= 81) THEN GNNDGET = .;
   IF (GNNDGTSP >= 81) THEN GNNDGTSP = .;
   IF (SKPRSKRD >= 81) THEN SKPRSKRD = .;
   IF (RSKREAD >= 81) THEN RSKREAD = .;
   IF (RSKPKCIG >= 81) THEN RSKPKCIG = .;
   IF (RSKMJOCC >= 81) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 81) THEN RSKMJREG = .;
   IF (RKTRYLSD >= 81) THEN RKTRYLSD = .;
   IF (RKLSDREG >= 81) THEN RKLSDREG = .;
   IF (RKTRYHER >= 81) THEN RKTRYHER = .;
   IF (RKHERREG >= 81) THEN RKHERREG = .;
   IF (RKCOCOCC >= 81) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 81) THEN RKCOCREG = .;
   IF (RK5DRINK >= 81) THEN RK5DRINK = .;
   IF (RSKBINGE >= 81) THEN RSKBINGE = .;
   IF (RSKDIFMJ >= 81) THEN RSKDIFMJ = .;
   IF (RKDIFLSD >= 81) THEN RKDIFLSD = .;
   IF (RKDIFCOC >= 81) THEN RKDIFCOC = .;
   IF (RKDIFCRK >= 81) THEN RKDIFCRK = .;
   IF (RKDIFHER >= 81) THEN RKDIFHER = .;
   IF (RSKSELL >= 81) THEN RSKSELL = .;
   IF (RKFQDNGR >= 81) THEN RKFQDNGR = .;
   IF (RKFQRSKY >= 81) THEN RKFQRSKY = .;
   IF (RKFQPBLT >= 81) THEN RKFQPBLT = .;
   IF (RKFQDBLT >= 81) THEN RKFQDBLT = .;
   IF (SKPDRGRD >= 81) THEN SKPDRGRD = .;
   IF (DRGREAD >= 81) THEN DRGREAD = .;
   IF (USEDCIG >= 81) THEN USEDCIG = .;
   IF (USEDALC >= 81) THEN USEDALC = .;
   IF (USEDMRJ >= 81) THEN USEDMRJ = .;
   IF (USEDCOC >= 81) THEN USEDCOC = .;
   IF (USEDHER >= 81) THEN USEDHER = .;
   IF (USEDHAL >= 81) THEN USEDHAL = .;
   IF (USEDINH >= 81) THEN USEDINH = .;
   IF (USEDANL >= 81) THEN USEDANL = .;
   IF (USEDTRN >= 81) THEN USEDTRN = .;
   IF (USEDSTM >= 81) THEN USEDSTM = .;
   IF (USEDSED >= 81) THEN USEDSED = .;
   IF (NODRUGYR >= 81) THEN NODRUGYR = .;
   IF (GRTMCIG >= 81) THEN GRTMCIG = .;
   IF (GRTMALC >= 81) THEN GRTMALC = .;
   IF (GRTMMRJ >= 81) THEN GRTMMRJ = .;
   IF (GRTMCOC >= 81) THEN GRTMCOC = .;
   IF (GRTMHER >= 81) THEN GRTMHER = .;
   IF (GRTMHAL >= 81) THEN GRTMHAL = .;
   IF (GRTMINH >= 81) THEN GRTMINH = .;
   IF (GRTMANL >= 81) THEN GRTMANL = .;
   IF (GRTMTRN >= 81) THEN GRTMTRN = .;
   IF (GRTMSTM >= 81) THEN GRTMSTM = .;
   IF (GRTMSED >= 81) THEN GRTMSED = .;
   IF (LAMTCIG >= 81) THEN LAMTCIG = .;
   IF (LAMTALC >= 81) THEN LAMTALC = .;
   IF (LAMTMRJ >= 81) THEN LAMTMRJ = .;
   IF (LAMTCOC >= 81) THEN LAMTCOC = .;
   IF (LAMTHER >= 81) THEN LAMTHER = .;
   IF (LAMTHAL >= 81) THEN LAMTHAL = .;
   IF (LAMTINH >= 81) THEN LAMTINH = .;
   IF (LAMTANL >= 81) THEN LAMTANL = .;
   IF (LAMTTRN >= 81) THEN LAMTTRN = .;
   IF (LAMTSTM >= 81) THEN LAMTSTM = .;
   IF (LAMTSED >= 81) THEN LAMTSED = .;
   IF (BTOLCIG >= 81) THEN BTOLCIG = .;
   IF (BTOLALC >= 81) THEN BTOLALC = .;
   IF (BTOLMRJ >= 81) THEN BTOLMRJ = .;
   IF (BTOLCOC >= 81) THEN BTOLCOC = .;
   IF (BTOLHER >= 81) THEN BTOLHER = .;
   IF (BTOLHAL >= 81) THEN BTOLHAL = .;
   IF (BTOLINH >= 81) THEN BTOLINH = .;
   IF (BTOLANL >= 81) THEN BTOLANL = .;
   IF (BTOLTRN >= 81) THEN BTOLTRN = .;
   IF (BTOLSTM >= 81) THEN BTOLSTM = .;
   IF (BTOLSED >= 81) THEN BTOLSED = .;
   IF (ACRDCIG >= 81) THEN ACRDCIG = .;
   IF (ACRDALC >= 81) THEN ACRDALC = .;
   IF (ACRDMRJ >= 81) THEN ACRDMRJ = .;
   IF (ACRDCOC >= 81) THEN ACRDCOC = .;
   IF (ACRDHER >= 81) THEN ACRDHER = .;
   IF (ACRDHAL >= 81) THEN ACRDHAL = .;
   IF (ACRDINH >= 81) THEN ACRDINH = .;
   IF (ACRDANL >= 81) THEN ACRDANL = .;
   IF (ACRDTRN >= 81) THEN ACRDTRN = .;
   IF (ACRDSTM >= 81) THEN ACRDSTM = .;
   IF (ACRDSED >= 81) THEN ACRDSED = .;
   IF (EMPBCIG >= 81) THEN EMPBCIG = .;
   IF (EMPBALC >= 81) THEN EMPBALC = .;
   IF (EMPBMRJ >= 81) THEN EMPBMRJ = .;
   IF (EMPBCOC >= 81) THEN EMPBCOC = .;
   IF (EMPBHER >= 81) THEN EMPBHER = .;
   IF (EMPBHAL >= 81) THEN EMPBHAL = .;
   IF (EMPBINH >= 81) THEN EMPBINH = .;
   IF (EMPBANL >= 81) THEN EMPBANL = .;
   IF (EMPBTRN >= 81) THEN EMPBTRN = .;
   IF (EMPBSTM >= 81) THEN EMPBSTM = .;
   IF (EMPBSED >= 81) THEN EMPBSED = .;
   IF (HLPBCIG >= 81) THEN HLPBCIG = .;
   IF (HLPBALC >= 81) THEN HLPBALC = .;
   IF (HLPBMRJ >= 81) THEN HLPBMRJ = .;
   IF (HLPBCOC >= 81) THEN HLPBCOC = .;
   IF (HLPBHER >= 81) THEN HLPBHER = .;
   IF (HLPBHAL >= 81) THEN HLPBHAL = .;
   IF (HLPBINH >= 81) THEN HLPBINH = .;
   IF (HLPBANL >= 81) THEN HLPBANL = .;
   IF (HLPBTRN >= 81) THEN HLPBTRN = .;
   IF (HLPBSTM >= 81) THEN HLPBSTM = .;
   IF (HLPBSED >= 81) THEN HLPBSED = .;
   IF (UCDCIG >= 81) THEN UCDCIG = .;
   IF (UCDALC >= 81) THEN UCDALC = .;
   IF (UCDMRJ >= 81) THEN UCDMRJ = .;
   IF (UCDCOC >= 81) THEN UCDCOC = .;
   IF (UCDHER >= 81) THEN UCDHER = .;
   IF (UCDHAL >= 81) THEN UCDHAL = .;
   IF (UCDINH >= 81) THEN UCDINH = .;
   IF (UCDANL >= 81) THEN UCDANL = .;
   IF (UCDTRN >= 81) THEN UCDTRN = .;
   IF (UCDSTM >= 81) THEN UCDSTM = .;
   IF (UCDSED >= 81) THEN UCDSED = .;
   IF (SKPSPTRD >= 81) THEN SKPSPTRD = .;
   IF (SPTREAD >= 81) THEN SPTREAD = .;
   IF (NDTXRCVD >= 81) THEN NDTXRCVD = .;
   IF (NDTXNEED >= 81) THEN NDTXNEED = .;
   IF (NDTXALC >= 81) THEN NDTXALC = .;
   IF (NDTXMJ >= 81) THEN NDTXMJ = .;
   IF (NDTXCOC >= 81) THEN NDTXCOC = .;
   IF (NDTXHER >= 81) THEN NDTXHER = .;
   IF (NDTXHAL >= 81) THEN NDTXHAL = .;
   IF (NDTXINH >= 81) THEN NDTXINH = .;
   IF (NDTXANL >= 81) THEN NDTXANL = .;
   IF (NDTXTRAN >= 81) THEN NDTXTRAN = .;
   IF (NDTXSTIM >= 81) THEN NDTXSTIM = .;
   IF (NDTXSED >= 81) THEN NDTXSED = .;
   IF (NDTXSOD >= 81) THEN NDTXSOD = .;
   IF (NDTXDRG1 >= 9981) THEN NDTXDRG1 = .;
   IF (NDTXDRG2 >= 9981) THEN NDTXDRG2 = .;
   IF (NDTXDRG3 >= 9981) THEN NDTXDRG3 = .;
   IF (NDTXDRG4 >= 9981) THEN NDTXDRG4 = .;
   IF (NDTXDRG5 >= 9981) THEN NDTXDRG5 = .;
   IF (NDTXSTEP >= 81) THEN NDTXSTEP = .;
   IF (NDTXTRSP >= 81) THEN NDTXTRSP = .;
   IF (NDTXTFAR >= 81) THEN NDTXTFAR = .;
   IF (NDTXBDHR >= 81) THEN NDTXBDHR = .;
   IF (NDTXOPEN >= 81) THEN NDTXOPEN = .;
   IF (NDTXTYPE >= 81) THEN NDTXTYPE = .;
   IF (NDTXNHCV >= 81) THEN NDTXNHCV = .;
   IF (NDTXNOCV >= 81) THEN NDTXNOCV = .;
   IF (NDTXCOST >= 81) THEN NDTXCOST = .;
   IF (NDTXHCAP >= 81) THEN NDTXHCAP = .;
   IF (NDTXTCMP >= 81) THEN NDTXTCMP = .;
   IF (NDTXLANG >= 81) THEN NDTXLANG = .;
   IF (NDTXSPSV >= 81) THEN NDTXSPSV = .;
   IF (NDTXSOR >= 81) THEN NDTXSOR = .;
   IF (NDTXRSC1 >= 81) THEN NDTXRSC1 = .;
   IF (BOOKED >= 81) THEN BOOKED = .;
   IF (NOBOOKYR >= 81) THEN NOBOOKYR = .;
   IF (BKLARCNY >= 81) THEN BKLARCNY = .;
   IF (BKBURGL >= 81) THEN BKBURGL = .;
   IF (BKAGASLT >= 81) THEN BKAGASLT = .;
   IF (BKSMASLT >= 81) THEN BKSMASLT = .;
   IF (BKMVTHFT >= 81) THEN BKMVTHFT = .;
   IF (BKROB >= 81) THEN BKROB = .;
   IF (BKRAPE >= 81) THEN BKRAPE = .;
   IF (BKMURDER >= 81) THEN BKMURDER = .;
   IF (BKARSON >= 81) THEN BKARSON = .;
   IF (BKDRVINF >= 81) THEN BKDRVINF = .;
   IF (BKDRUNK >= 81) THEN BKDRUNK = .;
   IF (BKDRUG >= 81) THEN BKDRUG = .;
   IF (BKPROS >= 81) THEN BKPROS = .;
   IF (BKVANDAL >= 81) THEN BKVANDAL = .;
   IF (BKOTH >= 81) THEN BKOTH = .;
   IF (BKOTHOFF >= 81) THEN BKOTHOFF = .;
   IF (PROBATON >= 81) THEN PROBATON = .;
   IF (PAROLE >= 81) THEN PAROLE = .;
   IF (DRVALDR >= 81) THEN DRVALDR = .;
   IF (DRIVEAL >= 81) THEN DRIVEAL = .;
   IF (DRIVEDR >= 81) THEN DRIVEDR = .;
   IF (SKPTMTRD >= 81) THEN SKPTMTRD = .;
   IF (TMTREAD >= 81) THEN TMTREAD = .;
   IF (TXEVER >= 81) THEN TXEVER = .;
   IF (TXSTRTL2 >= 981) THEN TXSTRTL2 = .;
   IF (TXYREVER >= 81) THEN TXYREVER = .;
   IF (TXSTRTY2 >= 981) THEN TXSTRTY2 = .;
   IF (TXALHOSP >= 81) THEN TXALHOSP = .;
   IF (TXALRFIN >= 81) THEN TXALRFIN = .;
   IF (TXALRFOP >= 81) THEN TXALRFOP = .;
   IF (TXALMHC >= 81) THEN TXALMHC = .;
   IF (TXALEMRG >= 81) THEN TXALEMRG = .;
   IF (TXALDOC >= 81) THEN TXALDOC = .;
   IF (TXALJAIL >= 81) THEN TXALJAIL = .;
   IF (TXALSHG >= 81) THEN TXALSHG = .;
   IF (TXALSOP >= 81) THEN TXALSOP = .;
   IF (TXALSP >= 81) THEN TXALSP = .;
   IF (TXDRHOSP >= 81) THEN TXDRHOSP = .;
   IF (TXDRFIN >= 81) THEN TXDRFIN = .;
   IF (TXDRFOP >= 81) THEN TXDRFOP = .;
   IF (TXDRMHC >= 81) THEN TXDRMHC = .;
   IF (TXDREMRG >= 81) THEN TXDREMRG = .;
   IF (TXDRDOC >= 81) THEN TXDRDOC = .;
   IF (TXDRJAIL >= 81) THEN TXDRJAIL = .;
   IF (TXDRSHG >= 81) THEN TXDRSHG = .;
   IF (TXDRSOP >= 81) THEN TXDRSOP = .;
   IF (TXDRSP >= 81) THEN TXDRSP = .;
   IF (TXYRINS >= 81) THEN TXYRINS = .;
   IF (TXYRCARE >= 81) THEN TXYRCARE = .;
   IF (TXYRCAID >= 81) THEN TXYRCAID = .;
   IF (TXYRPUBP >= 81) THEN TXYRPUBP = .;
   IF (TXYRSAVE >= 81) THEN TXYRSAVE = .;
   IF (TXYRFMLY >= 81) THEN TXYRFMLY = .;
   IF (TXYRCORT >= 81) THEN TXYRCORT = .;
   IF (TXYRMILC >= 81) THEN TXYRMILC = .;
   IF (TXYREMPL >= 81) THEN TXYREMPL = .;
   IF (TXYRFREE >= 81) THEN TXYRFREE = .;
   IF (TXYRSOS >= 81) THEN TXYRSOS = .;
   IF (TXYRSP >= 81) THEN TXYRSP = .;
   IF (TXYREMG2 >= 981) THEN TXYREMG2 = .;
   IF (TXADGREC >= 81) THEN TXADGREC = .;
   IF (TXLTHOSP >= 81) THEN TXLTHOSP = .;
   IF (TXLTRFIN >= 81) THEN TXLTRFIN = .;
   IF (TXLTRFOP >= 81) THEN TXLTRFOP = .;
   IF (TXLTMHC >= 81) THEN TXLTMHC = .;
   IF (TXLTEMRG >= 81) THEN TXLTEMRG = .;
   IF (TXLTDOC >= 81) THEN TXLTDOC = .;
   IF (TXLTJAIL >= 81) THEN TXLTJAIL = .;
   IF (TXLTSHG >= 81) THEN TXLTSHG = .;
   IF (TXLTSOP >= 81) THEN TXLTSOP = .;
   IF (TXLTSP >= 81) THEN TXLTSP = .;
   IF (TXLTALC >= 81) THEN TXLTALC = .;
   IF (TXLTMJ >= 81) THEN TXLTMJ = .;
   IF (TXLTCOC >= 81) THEN TXLTCOC = .;
   IF (TXLTHER >= 81) THEN TXLTHER = .;
   IF (TXLTHAL >= 81) THEN TXLTHAL = .;
   IF (TXLTINH >= 81) THEN TXLTINH = .;
   IF (TXLTANL >= 81) THEN TXLTANL = .;
   IF (TXLTRAN >= 81) THEN TXLTRAN = .;
   IF (TXLTSTIM >= 81) THEN TXLTSTIM = .;
   IF (TXLTSED >= 81) THEN TXLTSED = .;
   IF (TXLTSOD >= 81) THEN TXLTSOD = .;
   IF (TXLTA >= 9981) THEN TXLTA = .;
   IF (TXLTB >= 9981) THEN TXLTB = .;
   IF (TXLTC >= 9981) THEN TXLTC = .;
   IF (TXLTD >= 9981) THEN TXLTD = .;
   IF (TXLTE >= 9981) THEN TXLTE = .;
   IF (TXDRGA >= 9981) THEN TXDRGA = .;
   IF (TXDRGB >= 9981) THEN TXDRGB = .;
   IF (TXDRGC >= 9981) THEN TXDRGC = .;
   IF (TXDRGD >= 9981) THEN TXDRGD = .;
   IF (TXDRGE >= 9981) THEN TXDRGE = .;
   IF (TXOUTC >= 81) THEN TXOUTC = .;
   IF (TXTIME >= 9975) THEN TXTIME = .;
   IF (TXPDINS >= 81) THEN TXPDINS = .;
   IF (TXPDCARE >= 81) THEN TXPDCARE = .;
   IF (TXPDCAID >= 81) THEN TXPDCAID = .;
   IF (TXPDPUBP >= 81) THEN TXPDPUBP = .;
   IF (TXPDSAVE >= 81) THEN TXPDSAVE = .;
   IF (TXPDFMLY >= 81) THEN TXPDFMLY = .;
   IF (TXPDCORT >= 81) THEN TXPDCORT = .;
   IF (TXPDMILC >= 81) THEN TXPDMILC = .;
   IF (TXPDEMPL >= 81) THEN TXPDEMPL = .;
   IF (TXPDFREE >= 81) THEN TXPDFREE = .;
   IF (TXPDSOS >= 81) THEN TXPDSOS = .;
   IF (TXPDSP >= 81) THEN TXPDSP = .;
   IF (TXENROLL >= 81) THEN TXENROLL = .;
   IF (SKPDEXRD >= 81) THEN SKPDEXRD = .;
   IF (DEXREAD >= 81) THEN DEXREAD = .;
   IF (DXMJRET >= 81) THEN DXMJRET = .;
   IF (DXCCRET >= 81) THEN DXCCRET = .;
   IF (DXCGRLF >= 81) THEN DXCGRLF = .;
   IF (DXCG50LF >= 81) THEN DXCG50LF = .;
   IF (DXCG30US >= 81) THEN DXCG30US = .;
   IF (SKPYEXRD >= 81) THEN SKPYEXRD = .;
   IF (YEXREAD >= 81) THEN YEXREAD = .;
   IF (YELIVNBR >= 81) THEN YELIVNBR = .;
   IF (YECRIME >= 81) THEN YECRIME = .;
   IF (YESELLDG >= 81) THEN YESELLDG = .;
   IF (YEPPHLP >= 81) THEN YEPPHLP = .;
   IF (YEFMVIOL >= 81) THEN YEFMVIOL = .;
   IF (YESMRACE >= 81) THEN YESMRACE = .;
   IF (YECONFLT >= 81) THEN YECONFLT = .;
   IF (YESTFGT >= 81) THEN YESTFGT = .;
   IF (YEEMTBLD >= 81) THEN YEEMTBLD = .;
   IF (YEPPVSIT >= 81) THEN YEPPVSIT = .;
   IF (YEGRAFTI >= 81) THEN YEGRAFTI = .;
   IF (YESAFE >= 81) THEN YESAFE = .;
   IF (YEPPMOVE >= 81) THEN YEPPMOVE = .;
   IF (YEAPKCIG >= 81) THEN YEAPKCIG = .;
   IF (YEAMJEVR >= 81) THEN YEAMJEVR = .;
   IF (YEAMJMO >= 81) THEN YEAMJMO = .;
   IF (YEAALDLY >= 81) THEN YEAALDLY = .;
   IF (YEMV5YR2 >= 81) THEN YEMV5YR2 = .;
   IF (YEADOCIG >= 81) THEN YEADOCIG = .;
   IF (YEADOMRJ >= 81) THEN YEADOMRJ = .;
   IF (YEADOALC >= 81) THEN YEADOALC = .;
   IF (YEADODNK >= 81) THEN YEADODNK = .;
   IF (YEPCHKHW >= 81) THEN YEPCHKHW = .;
   IF (YEPHLPHW >= 81) THEN YEPHLPHW = .;
   IF (YEPCHORE >= 81) THEN YEPCHORE = .;
   IF (YEPLMTTV >= 81) THEN YEPLMTTV = .;
   IF (YEPLMTSN >= 81) THEN YEPLMTSN = .;
   IF (YEPGDJOB >= 81) THEN YEPGDJOB = .;
   IF (YEPPROUD >= 81) THEN YEPPROUD = .;
   IF (YEPPKCIG >= 81) THEN YEPPKCIG = .;
   IF (YEPMJEVR >= 81) THEN YEPMJEVR = .;
   IF (YEPMJMO >= 81) THEN YEPMJMO = .;
   IF (YEPALDLY >= 81) THEN YEPALDLY = .;
   IF (YEPAR98 >= 81) THEN YEPAR98 = .;
   IF (YEENRLYR >= 81) THEN YEENRLYR = .;
   IF (YESCHFLT >= 81) THEN YESCHFLT = .;
   IF (YESCHWRK >= 81) THEN YESCHWRK = .;
   IF (YESCHIMP >= 81) THEN YESCHIMP = .;
   IF (YESCHINT >= 81) THEN YESCHINT = .;
   IF (YETCGJOB >= 81) THEN YETCGJOB = .;
   IF (YELSTGRD >= 81) THEN YELSTGRD = .;
   IF (YESTSCIG >= 81) THEN YESTSCIG = .;
   IF (YESTSMJ >= 81) THEN YESTSMJ = .;
   IF (YESTSALC >= 81) THEN YESTSALC = .;
   IF (YESTSDNK >= 81) THEN YESTSDNK = .;
   IF (YETRPCIG >= 81) THEN YETRPCIG = .;
   IF (YETRSCIG >= 81) THEN YETRSCIG = .;
   IF (YETRPALC >= 81) THEN YETRPALC = .;
   IF (YETRDALC >= 81) THEN YETRDALC = .;
   IF (YETRPIDG >= 81) THEN YETRPIDG = .;
   IF (YETRUIDG >= 81) THEN YETRUIDG = .;
   IF (YEYARGUP >= 81) THEN YEYARGUP = .;
   IF (YEYFGTSW >= 81) THEN YEYFGTSW = .;
   IF (YEYFGTGP >= 81) THEN YEYFGTGP = .;
   IF (YEYHGUN >= 81) THEN YEYHGUN = .;
   IF (YEYSELL >= 81) THEN YEYSELL = .;
   IF (YEYSTOLE >= 81) THEN YEYSTOLE = .;
   IF (YEYATTAK >= 81) THEN YEYATTAK = .;
   IF (YEGPKCIG >= 81) THEN YEGPKCIG = .;
   IF (YEGMJEVR >= 81) THEN YEGMJEVR = .;
   IF (YEGMJMO >= 81) THEN YEGMJMO = .;
   IF (YEGALDLY >= 81) THEN YEGALDLY = .;
   IF (YEFPKCIG >= 81) THEN YEFPKCIG = .;
   IF (YEFMJEVR >= 81) THEN YEFMJEVR = .;
   IF (YEFMJMO >= 81) THEN YEFMJMO = .;
   IF (YEFALDLY >= 81) THEN YEFALDLY = .;
   IF (YEFDCIG >= 81) THEN YEFDCIG = .;
   IF (YEFDMJ >= 81) THEN YEFDMJ = .;
   IF (YEFDALC >= 81) THEN YEFDALC = .;
   IF (YEFDDNK >= 81) THEN YEFDDNK = .;
   IF (YETLKNON >= 81) THEN YETLKNON = .;
   IF (YETLKMOM >= 81) THEN YETLKMOM = .;
   IF (YETLKDAD >= 81) THEN YETLKDAD = .;
   IF (YETLKGPR >= 81) THEN YETLKGPR = .;
   IF (YETLKBGF >= 81) THEN YETLKBGF = .;
   IF (YETLKSIB >= 81) THEN YETLKSIB = .;
   IF (YETLKSOR >= 81) THEN YETLKSOR = .;
   IF (YETLKFRN >= 81) THEN YETLKFRN = .;
   IF (YETLKNBR >= 81) THEN YETLKNBR = .;
   IF (YETLKTCH >= 81) THEN YETLKTCH = .;
   IF (YETLKPSY >= 81) THEN YETLKPSY = .;
   IF (YETLKCLG >= 81) THEN YETLKCLG = .;
   IF (YETLKSOP >= 81) THEN YETLKSOP = .;
   IF (YETLKSP >= 900) THEN YETLKSP = .;
   IF (YETLKNR >= 981) THEN YETLKNR = .;
   IF (YEMOSNON >= 81) THEN YEMOSNON = .;
   IF (YEMOSMOM >= 81) THEN YEMOSMOM = .;
   IF (YEMOSDAD >= 81) THEN YEMOSDAD = .;
   IF (YEMOSGPR >= 81) THEN YEMOSGPR = .;
   IF (YEMOSBGF >= 81) THEN YEMOSBGF = .;
   IF (YEMOSSIB >= 81) THEN YEMOSSIB = .;
   IF (YEMOSSOR >= 81) THEN YEMOSSOR = .;
   IF (YEMOSFRN >= 81) THEN YEMOSFRN = .;
   IF (YEMOSNBR >= 81) THEN YEMOSNBR = .;
   IF (YEMOSTCH >= 81) THEN YEMOSTCH = .;
   IF (YEMOSPSY >= 81) THEN YEMOSPSY = .;
   IF (YEMOSCLG >= 81) THEN YEMOSCLG = .;
   IF (YEMOSSOP >= 81) THEN YEMOSSOP = .;
   IF (YEMOSSP >= 981) THEN YEMOSSP = .;
   IF (YEMOSNR >= 981) THEN YEMOSNR = .;
   IF (YEBIGBRO >= 81) THEN YEBIGBRO = .;
   IF (YEPRBSLV >= 81) THEN YEPRBSLV = .;
   IF (YEVIOPRV >= 81) THEN YEVIOPRV = .;
   IF (YEYMCA >= 81) THEN YEYMCA = .;
   IF (YESCOUTS >= 81) THEN YESCOUTS = .;
   IF (YEPRVLES >= 81) THEN YEPRVLES = .;
   IF (YEDGPRGP >= 81) THEN YEDGPRGP = .;
   IF (YETEMSPT >= 81) THEN YETEMSPT = .;
   IF (YE4HCLUB >= 81) THEN YE4HCLUB = .;
   IF (YESLFHLP >= 81) THEN YESLFHLP = .;
   IF (YEBAND >= 81) THEN YEBAND = .;
   IF (YESCHCLB >= 81) THEN YESCHCLB = .;
   IF (YEVOLUNT >= 81) THEN YEVOLUNT = .;
   IF (YESTGOVT >= 81) THEN YESTGOVT = .;
   IF (YEPRGSTD >= 81) THEN YEPRGSTD = .;
   IF (YEJBSKIL >= 81) THEN YEJBSKIL = .;
   IF (YECHOIR >= 81) THEN YECHOIR = .;
   IF (YEDECLAS >= 81) THEN YEDECLAS = .;
   IF (YEDERGLR >= 81) THEN YEDERGLR = .;
   IF (YEDESPCL >= 81) THEN YEDESPCL = .;
   IF (YEMSGYR >= 81) THEN YEMSGYR = .;
   IF (YEYSTRES >= 81) THEN YEYSTRES = .;
   IF (YEFMSTRS >= 81) THEN YEFMSTRS = .;
   IF (SKPSENRD >= 81) THEN SKPSENRD = .;
   IF (SENREAD >= 81) THEN SENREAD = .;
   IF (SNLIVNBR >= 81) THEN SNLIVNBR = .;
   IF (SNCRIME >= 81) THEN SNCRIME = .;
   IF (SNSELLDG >= 81) THEN SNSELLDG = .;
   IF (SNPPVAL >= 81) THEN SNPPVAL = .;
   IF (SNFMVIOL >= 81) THEN SNFMVIOL = .;
   IF (SNSMRACE >= 81) THEN SNSMRACE = .;
   IF (SNCONFLT >= 81) THEN SNCONFLT = .;
   IF (SNSTFGT >= 81) THEN SNSTFGT = .;
   IF (SNEMTBLD >= 81) THEN SNEMTBLD = .;
   IF (SNPPHLP >= 81) THEN SNPPHLP = .;
   IF (SNGRAFTI >= 81) THEN SNGRAFTI = .;
   IF (SNPPVSIT >= 81) THEN SNPPVSIT = .;
   IF (SNSAFE >= 81) THEN SNSAFE = .;
   IF (SNPPMOVE >= 81) THEN SNPPMOVE = .;
   IF (SNAPKCIG >= 81) THEN SNAPKCIG = .;
   IF (SNAMJEVR >= 81) THEN SNAMJEVR = .;
   IF (SNAMJMO >= 81) THEN SNAMJMO = .;
   IF (SNAALDLY >= 81) THEN SNAALDLY = .;
   IF (SNAALDRV >= 81) THEN SNAALDRV = .;
   IF (SNMV5YR2 >= 81) THEN SNMV5YR2 = .;
   IF (SNPPHHLD >= 81) THEN SNPPHHLD = .;
   IF (SNINSULT >= 81) THEN SNINSULT = .;
   IF (SNSRARGU >= 81) THEN SNSRARGU = .;
   IF (SNSMARGU >= 81) THEN SNSMARGU = .;
   IF (SNSPOUSE >= 81) THEN SNSPOUSE = .;
   IF (SNSPACTV >= 81) THEN SNSPACTV = .;
   IF (SNSPANGR >= 81) THEN SNSPANGR = .;
   IF (SNSPHITU >= 81) THEN SNSPHITU = .;
   IF (SNYHITSP >= 81) THEN SNYHITSP = .;
   IF (SNSPCRIT >= 81) THEN SNSPCRIT = .;
   IF (SNSPCONC >= 81) THEN SNSPCONC = .;
   IF (SNYSTRES >= 81) THEN SNYSTRES = .;
   IF (SNFMSTRS >= 81) THEN SNFMSTRS = .;
   IF (SNFRCONC >= 81) THEN SNFRCONC = .;
   IF (SNFRACTV >= 81) THEN SNFRACTV = .;
   IF (SNFRCARE >= 81) THEN SNFRCARE = .;
   IF (SNYHGUN >= 81) THEN SNYHGUN = .;
   IF (SNYSELL >= 81) THEN SNYSELL = .;
   IF (SNYSTOLE >= 81) THEN SNYSTOLE = .;
   IF (SNYATTAK >= 81) THEN SNYATTAK = .;
   IF (SNFACIG >= 81) THEN SNFACIG = .;
   IF (SNFAMJEV >= 81) THEN SNFAMJEV = .;
   IF (SNFAMJMO >= 81) THEN SNFAMJMO = .;
   IF (SNFAALDY >= 81) THEN SNFAALDY = .;
   IF (SNFAALDV >= 81) THEN SNFAALDV = .;
   IF (SNFDCIG >= 81) THEN SNFDCIG = .;
   IF (SNFDMJ >= 81) THEN SNFDMJ = .;
   IF (SNFDALC >= 81) THEN SNFDALC = .;
   IF (SNFDDRNK >= 81) THEN SNFDDRNK = .;
   IF (MOVESPY2 >= 81) THEN MOVESPY2 = .;
   IF (EDU2NDQ2 >= 81) THEN EDU2NDQ2 = .;
   IF (STUDNT97 >= 81) THEN STUDNT97 = .;
   IF (STDT9497 >= 81) THEN STDT9497 = .;
   IF (SKPSCHGR >= 81) THEN SKPSCHGR = .;
   IF (SKPSCHAG >= 81) THEN SKPSCHAG = .;
   IF (LFTSCHRS >= 81) THEN LFTSCHRS = .;
   IF (LFTSCHA2 >= 981) THEN LFTSCHA2 = .;
   IF (SCHDYS97 >= 81) THEN SCHDYS97 = .;
   IF (SCHD9497 >= 81) THEN SCHD9497 = .;
   IF (SKIPPD97 >= 81) THEN SKIPPD97 = .;
   IF (SKIP9497 >= 81) THEN SKIP9497 = .;
   IF (NJOBSPY2 >= 81) THEN NJOBSPY2 = .;
   IF (WRKSTAT2 >= 81) THEN WRKSTAT2 = .;
   IF (WKST2NDQ >= 81) THEN WKST2NDQ = .;
   IF (WKSWKST >= 81) THEN WKSWKST = .;
   IF (SKPWKST1 >= 81) THEN SKPWKST1 = .;
   IF (BUSSIZE >= 81) THEN BUSSIZE = .;
   IF (LOCSIZE >= 81) THEN LOCSIZE = .;
   IF (DRGINFO >= 81) THEN DRGINFO = .;
   IF (DRGPLCY >= 81) THEN DRGPLCY = .;
   IF (PLCYCOV >= 81) THEN PLCYCOV = .;
   IF (DRGPRGM >= 81) THEN DRGPRGM = .;
   IF (USALCTST >= 81) THEN USALCTST = .;
   IF (USDRGTST >= 81) THEN USDRGTST = .;
   IF (SKPWKTST >= 81) THEN SKPWKTST = .;
   IF (TSTHIRE >= 81) THEN TSTHIRE = .;
   IF (TSTRAND >= 81) THEN TSTRAND = .;
   IF (TSTSUSP >= 81) THEN TSTSUSP = .;
   IF (TSTACCD >= 81) THEN TSTACCD = .;
   IF (TSTTRMT >= 81) THEN TSTTRMT = .;
   IF (WRKHIRE >= 81) THEN WRKHIRE = .;
   IF (WRKRAND >= 81) THEN WRKRAND = .;
   IF (WRKSUSP >= 81) THEN WRKSUSP = .;
   IF (WRKACCD >= 81) THEN WRKACCD = .;
   IF (PAYMO >= 81) THEN PAYMO = .;
   IF (PAYYR2 >= 981) THEN PAYYR2 = .;
   IF (ROCCUP2 >= 981) THEN ROCCUP2 = .;
   IF (BUSINES2 >= 981) THEN BUSINES2 = .;
   IF (SKPWKST2 >= 81) THEN SKPWKST2 = .;
   IF (WORKDAYS >= 81) THEN WORKDAYS = .;
   IF (WORKBLAH >= 81) THEN WORKBLAH = .;
   IF (JBLOSEYR >= 81) THEN JBLOSEYR = .;
   IF (JBFNDNEW >= 81) THEN JBFNDNEW = .;
   IF (JBSATIS >= 81) THEN JBSATIS = .;
   IF (QD46_2 >= 81) THEN QD46_2 = .;
   IF (PREGNANT >= 81) THEN PREGNANT = .;
   IF (PREGMOS >= 81) THEN PREGMOS = .;
   IF (CWE >= 81) THEN CWE = .;
   IF (CWESC1 >= 981) THEN CWESC1 = .;
   IF (CWESC2 >= 981) THEN CWESC2 = .;
   IF (FULLPART >= 81) THEN FULLPART = .;
   IF (RLGSVC98 >= 81) THEN RLGSVC98 = .;
   IF (RLGIMPRT >= 81) THEN RLGIMPRT = .;
   IF (RLGDECSN >= 81) THEN RLGDECSN = .;
   IF (RLGFRNDS >= 81) THEN RLGFRNDS = .;
   IF (NUERTMT2 >= 81) THEN NUERTMT2 = .;
   IF (NUHSPOV2 >= 81) THEN NUHSPOV2 = .;
   IF (NUHSPPE2 >= 81) THEN NUHSPPE2 = .;
   IF (OUTPTPE >= 81) THEN OUTPTPE = .;
   IF (PROXABLE >= 81) THEN PROXABLE = .;
   IF (PROXYREL >= 981) THEN PROXYREL = .;
   IF (PROXHOME >= 81) THEN PROXHOME = .;
   IF (PROXJOIN >= 81) THEN PROXJOIN = .;
   IF (CAREUSU >= 81) THEN CAREUSU = .;
   IF (NCARERSN >= 81) THEN NCARERSN = .;
   IF (NCRRSNSP >= 81) THEN NCRRSNSP = .;
   IF (NCRRSNSC >= 81) THEN NCRRSNSC = .;
   IF (CAREOFT >= 81) THEN CAREOFT = .;
   IF (PYRCARE >= 81) THEN PYRCARE = .;
   IF (PYRCRTYP >= 81) THEN PYRCRTYP = .;
   IF (PYRCRTSP >= 81) THEN PYRCRTSP = .;
   IF (PYRCRTSC >= 81) THEN PYRCRTSC = .;
   IF (CARENOW >= 81) THEN CARENOW = .;
   IF (MNRSNNCR >= 81) THEN MNRSNNCR = .;
   IF (MNRSNNSP >= 81) THEN MNRSNNSP = .;
   IF (MNRSNNSC >= 81) THEN MNRSNNSC = .;
   IF (UCARETYP >= 81) THEN UCARETYP = .;
   IF (UCRTYPSP >= 81) THEN UCRTYPSP = .;
   IF (UCRTYPSC >= 81) THEN UCRTYPSC = .;
   IF (MEDICARE >= 81) THEN MEDICARE = .;
   IF (MEDICAID >= 81) THEN MEDICAID = .;
   IF (CHAMPUS >= 81) THEN CHAMPUS = .;
   IF (PRVHLTIN >= 81) THEN PRVHLTIN = .;
   IF (GRPHLTIN >= 81) THEN GRPHLTIN = .;
   IF (HLTINALC >= 81) THEN HLTINALC = .;
   IF (HLTINDRG >= 81) THEN HLTINDRG = .;
   IF (HLTINMNT >= 81) THEN HLTINMNT = .;
   IF (SKHLCCOV >= 81) THEN SKHLCCOV = .;
   IF (HLCNOTYR >= 81) THEN HLCNOTYR = .;
   IF (HLCNOTMO >= 81) THEN HLCNOTMO = .;
   IF (HLCLAST >= 81) THEN HLCLAST = .;
   IF (HLCPRIVT >= 81) THEN HLCPRIVT = .;
   IF (HLCMCAID >= 81) THEN HLCMCAID = .;
   IF (HLCMILT >= 81) THEN HLCMILT = .;
   IF (HLCMCARE >= 81) THEN HLCMCARE = .;
   IF (HLCOGOVT >= 81) THEN HLCOGOVT = .;
   IF (HLCOTHER >= 81) THEN HLCOTHER = .;
   IF (HLCOTHSP >= 81) THEN HLCOTHSP = .;
   IF (HLNLOSJB >= 81) THEN HLNLOSJB = .;
   IF (HLNMAJOB >= 81) THEN HLNMAJOB = .;
   IF (HLNMASOR >= 81) THEN HLNMASOR = .;
   IF (HLNCOST >= 81) THEN HLNCOST = .;
   IF (HLNINELG >= 81) THEN HLNINELG = .;
   IF (HLNNOFFR >= 81) THEN HLNNOFFR = .;
   IF (HLNDIVOR >= 81) THEN HLNDIVOR = .;
   IF (HLNDEATH >= 81) THEN HLNDEATH = .;
   IF (HLNREFUS >= 81) THEN HLNREFUS = .;
   IF (HLNNONED >= 81) THEN HLNNONED = .;
   IF (HLNSOR >= 81) THEN HLNSOR = .;
   IF (HLNSORSP >= 81) THEN HLNSORSP = .;
   IF (SOC1 >= 81) THEN SOC1 = .;
   IF (SOC2 >= 81) THEN SOC2 = .;
   IF (SSI1 >= 81) THEN SSI1 = .;
   IF (SSI2 >= 81) THEN SSI2 = .;
   IF (PMT1 >= 81) THEN PMT1 = .;
   IF (PMT2 >= 81) THEN PMT2 = .;
   IF (AFDC >= 81) THEN AFDC = .;
   IF (FSTAMP >= 81) THEN FSTAMP = .;
   IF (SVC1 >= 81) THEN SVC1 = .;
   IF (SVC2 >= 81) THEN SVC2 = .;
   IF (WELMOS >= 81) THEN WELMOS = .;
   IF (INT1 >= 81) THEN INT1 = .;
   IF (INT2 >= 81) THEN INT2 = .;
   IF (CHD1 >= 81) THEN CHD1 = .;
   IF (CHD2 >= 81) THEN CHD2 = .;
   IF (WAGE1 >= 81) THEN WAGE1 = .;
   IF (WAGE2 >= 81) THEN WAGE2 = .;
   IF (OTH1 >= 81) THEN OTH1 = .;
   IF (OTH2 >= 81) THEN OTH2 = .;
   IF (PINC1 >= 81) THEN PINC1 = .;
   IF (PINC2 >= 81) THEN PINC2 = .;
   IF (SKPTFMIN >= 81) THEN SKPTFMIN = .;
   IF (FINC1 >= 81) THEN FINC1 = .;
   IF (FINC2 >= 81) THEN FINC2 = .;
   IF (TELNO2 >= 81) THEN TELNO2 = .;
   IF (IRAFDC >= 81) THEN IRAFDC = .;
   IF (IRWELMOS >= 81) THEN IRWELMOS = .;
   IF (IRFINC1 >= 81) THEN IRFINC1 = .;
   IF (IIFINC1 = 9) THEN IIFINC1 = .;
   IF (IISOC2 = 9) THEN IISOC2 = .;
   IF (IISSI2 = 9) THEN IISSI2 = .;
   IF (IIPMT2 = 9) THEN IIPMT2 = .;
   IF (IISVC2 = 9) THEN IISVC2 = .;
   IF (IIINT2 = 9) THEN IIINT2 = .;
   IF (IRCHD2 = 9) THEN IRCHD2 = .;
   IF (IICHD2 = 9) THEN IICHD2 = .;
   IF (IIWAGE2 = 9) THEN IIWAGE2 = .;
   IF (IIOTH2 = 9) THEN IIOTH2 = .;
   IF (IRPINC2 >= 81) THEN IRPINC2 = .;
   IF (IRFINC2 >= 81) THEN IRFINC2 = .;
   IF (IIFINC2 = 9) THEN IIFINC2 = .;
   IF (NEEDLREC >= 81) THEN NEEDLREC = .;
   IF (CIGARMON >= 81) THEN CIGARMON = .;
   IF (CIGRLIFE >= 81) THEN CIGRLIFE = .;
   IF (IRCGRMN = 9) THEN IRCGRMN = .;
   IF (MOSCOUNT >= 81) THEN MOSCOUNT = .;
   IF (YTFLADLY = 99) THEN YTFLADLY = .;
   IF (INTMONTH >= 81) THEN INTMONTH = .;
   IF (BHOUR >= 81) THEN BHOUR = .;
   IF (BMIN >= 81) THEN BMIN = .;
   IF (BAP >= 81) THEN BAP = .;
   IF (ETIMEHR >= 81) THEN ETIMEHR = .;
   IF (ETIMEMN >= 81) THEN ETIMEMN = .;
   IF (EAP >= 81) THEN EAP = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (PPRES >= 81) THEN PPRES = .;
   IF (SPRES >= 81) THEN SPRES = .;
   IF (PARPRES >= 81) THEN PARPRES = .;
   IF (OARPRES >= 81) THEN OARPRES = .;
   IF (OAPRES >= 81) THEN OAPRES = .;
   IF (CPRES >= 81) THEN CPRES = .;
   IF (OPRESNSP >= 81) THEN OPRESNSP = .;
   IF (OPRESSPA >= 900) THEN OPRESSPA = .;
   IF (OPRESSPB >= 900) THEN OPRESSPB = .;
   IF (WHOMARKD >= 81) THEN WHOMARKD = .;
   IF (GQTYPE = 9) THEN GQTYPE = .;
   IF (ALCDAYS2 = 6) THEN ALCDAYS2 = .;
   IF (ALCDAYS3 = 6) THEN ALCDAYS3 = .;
   IF (ALCTRY2 >= 81) THEN ALCTRY2 = .;
   IF (ALCUSE = 5) THEN ALCUSE = .;
   IF (ANALAGE2 >= 81) THEN ANALAGE2 = .;
   IF (AVCIG2 = 4) THEN AVCIG2 = .;
   IF (CIGTRY2 >= 81) THEN CIGTRY2 = .;
   IF (COCAGE2 >= 81) THEN COCAGE2 = .;
   IF (COCTOT3 = 99) THEN COCTOT3 = .;
   IF (DRALHLP3 = 99) THEN DRALHLP3 = .;
   IF (DRNKHLP3 = 99) THEN DRNKHLP3 = .;
   IF (DROPMF = 99) THEN DROPMF = .;
   IF (FERTAGE = 99) THEN FERTAGE = .;
   IF (HALLAGE2 >= 81) THEN HALLAGE2 = .;
   IF (HERAGE2 >= 81) THEN HERAGE2 = .;
   IF (INHAGE2 >= 81) THEN INHAGE2 = .;
   IF (MJAGE2 >= 81) THEN MJAGE2 = .;
   IF (MJTOT3 = 99) THEN MJTOT3 = .;
   IF (PREG3 = 99) THEN PREG3 = .;
   IF (PSYAGE >= 81) THEN PSYAGE = .;
   IF (RACESEX = 99) THEN RACESEX = .;
   IF (RDIFCOC = 99) THEN RDIFCOC = .;
   IF (RDIFCRK = 99) THEN RDIFCRK = .;
   IF (RDIFHER = 99) THEN RDIFHER = .;
   IF (RDIFLSD = 99) THEN RDIFLSD = .;
   IF (RDIFMJ = 99) THEN RDIFMJ = .;
   IF (RSKALC1 = 99) THEN RSKALC1 = .;
   IF (RSKALC2 = 99) THEN RSKALC2 = .;
   IF (RSKCIG = 99) THEN RSKCIG = .;
   IF (RSKCOC1 = 99) THEN RSKCOC1 = .;
   IF (RSKCOC2 = 99) THEN RSKCOC2 = .;
   IF (RSKHER1 = 99) THEN RSKHER1 = .;
   IF (RSKHER2 = 99) THEN RSKHER2 = .;
   IF (RSKLSD1 = 99) THEN RSKLSD1 = .;
   IF (RSKMJ1 = 99) THEN RSKMJ1 = .;
   IF (RSKMJ2 = 99) THEN RSKMJ2 = .;
   IF (SEDAGE2 >= 81) THEN SEDAGE2 = .;
   IF (STIMAGE2 >= 81) THEN STIMAGE2 = .;
   IF (TRANAGE2 = 99) THEN TRANAGE2 = .;
   IF (TRIMEST2 = 99) THEN TRIMEST2 = .;
   IF (TRMTHLP3 = 99) THEN TRMTHLP3 = .;
*/

* SAS FORMAT STATEMENT;

  FORMAT SKPMARTL skpmartl. MARITAL marital. NOMARR2 nomarr2f.
         SKPMILT skpmilt. SERVICE service. MILSTAT milstat.
         EDUC2 educ2fff. DIPLOMA diploma. ENROLL97 enroll9f.
         ENRL9497 enrl949f. WORKSTAT workstat. HEIGHT2 height2f.
         POUNDS2 pounds2f. HEALTH health. CIGEVER cigever.
         CIGTRY cigtry. CIGTOT cigtot. CIGREC cigrec.
         CIG30USE cig30use. AVCIG avcig. CIG30WOK cig30wok.
         CIGEVYDA cigevyda. CIGAGE cigage. CIGYRS cigyrs.
         SNUFEVER snufever. SNUFREC snufrec. SKPALCRD skpalcrd.
         ALCREAD alcread. ALCEVER alcever. ALCTRY alctry.
         ALCREC alcrec. ALCPAT alcpat. DRUNKYR drunkyr.
         ALCDAYS alcdays. NODR30A nodr30a. DR5DAY dr5day.
         MJEVER mjever. MJAGE mjage. MJTOT mjtot.
         MJREC mjrec. MJYRFREQ mjyrfreq. MJDAY30A mjday30a.
         SKPCOCRD skpcocrd. COCREAD cocread. COCEVER cocever.
         COCAGE cocage. COCTOT coctot. COCREC cocrec.
         COCYRFRQ cocyrfrq. COCUS30A cocus30a. SKPCRKRD skpcrkrd.
         CRKREAD crkread. CRKEVER crkever. CRKAGE crkage.
         CRKTOT crktot. CRAKREC crakrec. CRKYRFRQ crkyrfrq.
         CRKUS30A crkus30a. SKPHERRD skpherrd. HERREAD herread.
         HEREVER herever. HERAGE herage. HERTOT hertot.
         HERREC herrec. HERYRFRQ heryrfrq. HER30USE her30use.
         SKPHALRD skphalrd. HALREAD halread. LSD lsd.
         PCP pcp. PEYOTE peyote. MESC mesc.
         PSILCY psilcy. ECSTASY ecstasy. HALDKNAM haldknam.
         HALNOLST halnolst. HALNEWA halnewa. HALNEWB halnewb.
         HALNEWC halnewc. HALNEWD halnewd. HALNEWE halnewe.
         HALLAGE hallage. HALLTOT halltot. HALLREC hallrec.
         HALYRFRQ halyrfrq. HAL30USE hal30use. LSDREC lsdrec.
         PCPREC pcprec. SKPINHRD skpinhrd. INHREAD inhread.
         AMYLNIT amylnit. CLEFLU cleflu. GAS gas.
         GLUE glue. ETHER ether. SOLVENT solvent.
         LGAS lgas. NITOXID nitoxid. SPPAINT sppaint.
         AEROS aeros. INHDKNAM inhdknam. INHNOLST inhnolst.
         INHNEWA inhnewa. INHNEWB inhnewb. INHNEWC inhnewc.
         INHNEWD inhnewd. INHNEWE inhnewe. INHAGE inhage.
         INHTOT inhtot. INHREC inhrec. INHYRFRQ inhyrfrq.
         INHDY30A inhdy30a. SKPANLRD skpanlrd. ANLREAD anlread.
         CODEINE codeine. DARVON darvon. DEMEROL demerol.
         DILAUD dilaud. METHDON methdon. MORPHINE morphine.
         PERCODAN percodan. TALWIN talwin. TYLCOD tylcod.
         ANLDKNAM anldknam. ANLNOLST anlnolst. ANALNEWA analnewa.
         ANALNEWB analnewb. ANALNEWC analnewc. ANALNEWD analnewd.
         ANALNEWE analnewe. ANALNONE analnone. ANALAGE analage.
         ANALTOT analtot. ANALREC analrec. ANLYRFRQ anlyrfrq.
         SKPTRNRD skptrnrd. TRNREAD trnread. ATARAX atarax.
         ATIVAN ativan. DIAZEPAM diazepam. LIBRIUM librium.
         TRANXENE tranxene. VALIUM valium. XANAX xanax.
         TRDKNAM trdknam. TRNOLST trnolst. TRNEWA trnewa.
         TRNEWB trnewb. TRNEWC trnewc. TRNEWD trnewd.
         TRNEWE trnewe. NOTRANQ notranq. TRANAGE tranage.
         TRANTOT trantot. TRANREC tranrec. TRNYRFRQ trnyrfrq.
         SKPSTMRD skpstmrd. STMREAD stmread. BENZ benz.
         BIPHET biphet. DEXAMYL dexamyl. DEXED dexed.
         FASTIN fastin. IONAMIN ionamin. METHAMP methamp.
         METHI methi. PRELUDIN preludin. STMDKNAM stmdknam.
         STMNOLST stmnolst. STIMNEWA stimnewa. STIMNEWB stimnewb.
         STIMNEWC stimnewc. STIMNEWD stimnewd. STIMNEWE stimnewe.
         NOSTIMS nostims. STIMAGE stimage. STIMTOT stimtot.
         STIMREC stimrec. STMYRFRQ stmyrfrq. SKPSEDRD skpsedrd.
         SEDREAD sedread. DALMANE dalmane. HALCION halcion.
         METHAQ methaq. NEMBUTAL nembutal. PHENOBAR phenobar.
         PLACIDYL placidyl. SECONAL seconal. TUINAL tuinal.
         SEDDKNAM seddknam. SEDNOLST sednolst. SEDNEWA sednewa.
         SEDNEWB sednewb. SEDNEWC sednewc. SEDNEWD sednewd.
         SEDNEWE sednewe. NOSEDAT nosedat. SEDAGE sedage.
         SEDTOT sedtot. SEDREC sedrec. SEDYRFRQ sedyrfrq.
         BIRYEAR2 biryearf. EIBDATE eibdate. IRAGE2 irage2ff.
         IIAGE iiage. IRSEX irsex. IISEX iisex.
         IRRACE irrace. IIRACE iirace. IRHOIND irhoind.
         IIHOIND iihoind. IRHOGRP irhogrp. IIHOGRP iihogrp.
         IRHOGRP2 irhogrpf. IIHOGRP2 iihogrpf. IRMARIT irmarit.
         IIMARIT iimarit. IREDUC2 ireduc2f. IIEDUC iieduc.
         IRHSGRAD irhsgrad. IIHSGRAD iihsgrad. IRWORKST irworkst.
         IIWORKST iiworkst. IRCIGRC ircigrc. IICIGRC iicigrc.
         IROTBRC irotbrc. IIOTBRC iiotbrc. IRALCRC iralcrc.
         IIALCRC iialcrc. IRMJRC irmjrc. IIMJRC iimjrc.
         IRCOCRC ircocrc. IICOCRC iicocrc. IRCRKRC ircrkrc.
         IICRKRC iicrkrc. IRHERRC irherrc. IIHERRC iiherrc.
         IRHALRC irhalrc. IIHALRC iihalrc. IRLSDRC irlsdrc.
         IILSDRC iilsdrc. IRPCPRC irpcprc. IIPCPRC iipcprc.
         IRINHRC irinhrc. IIINHRC iiinhrc. IRANLRC iranlrc.
         IIANLRC iianlrc. IRTRNRC irtrnrc. IITRNRC iitrnrc.
         IRSTMRC irstmrc. IISTMRC iistmrc. IRSEDRC irsedrc.
         IISEDRC iisedrc. IRALCFQ iralcfq. IIALCFQ iialcfq.
         IRMJFQ irmjfq. IIMJFQ iimjfq. IRCOCFQ ircocfq.
         IICOCFQ iicocfq. IRCRKFQ ircrkfq. IICRKFQ iicrkfq.
         IRHERFQ irherfq. IIHERFQ iiherfq. IRHALFQ irhalfq.
         IIHALFQ iihalfq. IRINHFQ irinhfq. IIINHFQ iiinhfq.
         IRANLFQ iranlfq. IIANLFQ iianlfq. IRTRNFQ irtrnfq.
         IITRNFQ iitrnfq. IRSTMFQ irstmfq. IISTMFQ iistmfq.
         IRSEDFQ irsedfq. IISEDFQ iisedfq. CATAGE catage.
         CATAG2 catag2ff. CATAG3 catag3ff. RACE race.
         HISPRACE hisprace. EDUCCAT2 educcatf. EMPSTAT2 empstatf.
         MARISTAT maristat. NOTMAR notmar. CIGFLAG cigflag.
         CIGYR cigyr. CIGMON cigmon. SMKFLAG smkflag.
         SMKYR smkyr. SMKMON smkmon. ALCFLAG alcflag.
         ALCYR alcyr. ALCMON alcmon. MRJFLAG mrjflag.
         MRJYR mrjyr. MRJMON mrjmon. COCFLAG cocflag.
         COCYR cocyr. COCMON cocmon. CRKFLAG crkflag.
         CRKYR crkyr. CRKMON crkmon. HERFLAG herflag.
         HERYR heryr. HERMON hermon. HALFLAG halflag.
         HALYR halyr. HALMON halmon. LSDFLAG lsdflag.
         LSDYR lsdyr. LSDMON lsdmon. PCPFLAG pcpflag.
         PCPYR pcpyr. PCPMON pcpmon. INHFLAG inhflag.
         INHYR inhyr. INHMON inhmon. ANLFLAG anlflag.
         ANLYR anlyr. ANLMON anlmon. TRQFLAG trqflag.
         TRQYR trqyr. TRQMON trqmon. STMFLAG stmflag.
         STMYR stmyr. STMMON stmmon. SEDFLAG sedflag.
         SEDYR sedyr. SEDMON sedmon. ALCYRF alcyrf.
         ALCMONF alcmonf. ALCWKF alcwkf. ALCOCCF alcoccf.
         ALCDLYF alcdlyf. MRJYRF mrjyrf. MRJMONF mrjmonf.
         MRJWKF mrjwkf. MRJOCCF mrjoccf. MRJDLYF mrjdlyf.
         COCYRF cocyrf. COCMONF cocmonf. COCWKF cocwkf.
         COCOCCF cococcf. COCDLYF cocdlyf. CRKYRF crkyrf.
         CRKMONF crkmonf. CRKWKF crkwkf. CRKOCCF crkoccf.
         CRKDLYF crkdlyf. HERYRF heryrf. HERMONF hermonf.
         HERWKF herwkf. HEROCCF heroccf. HERDLYF herdlyf.
         HALYRF halyrf. HALMONF halmonf. HALWKF halwkf.
         HALOCCF haloccf. HALDLYF haldlyf. INHYRF inhyrf.
         INHMONF inhmonf. INHWKF inhwkf. INHOCCF inhoccf.
         INHDLYF inhdlyf. ANLYRF anlyrf. ANLMONF anlmonf.
         ANLWKF anlwkf. ANLOCCF anloccf. ANLDLYF anldlyf.
         TRQYRF trqyrf. TRQMONF trqmonf. TRQWKF trqwkf.
         TRQOCCF trqoccf. TRQDLYF trqdlyf. STMYRF stmyrf.
         STMMONF stmmonf. STMWKF stmwkf. STMOCCF stmoccf.
         STMDLYF stmdlyf. SEDYRF sedyrf. SEDMONF sedmonf.
         SEDWKF sedwkf. SEDOCCF sedoccf. SEDDLYF seddlyf.
         PSYFLAG2 psyflagf. PSYYR2 psyyr2ff. PSYMON2 psymon2f.
         SUMFLAG sumflag. SUMYR sumyr. SUMMON summon.
         MJOFLAG mjoflag. MJOYR2 mjoyr2ff. MJOMON2 mjomon2f.
         IEMFLAG iemflag. IEMYR iemyr. IEMMON iemmon.
         BINGEDRK bingedrk. HVYDRK2 hvydrk2f. BINGEHVY bingehvy.
         PEYOTE2 peyote2f. MESC2 mesc2fff. PSILCY2 psilcy2f.
         ECSTASY2 ecstasyf. METHAMP2 methampf. AMYLNIT2 amylnitf.
         CLEFLU2 cleflu2f. GAS2 gas2ffff. GLUE2 glue2fff.
         ETHER2 ether2ff. SOLVENT2 solventf. LGAS2 lgas2fff.
         NITOXID2 nitoxidf. SPPAINT2 sppaintf. AEROS2 aeros2ff.
         MJDY30A3 mjdy30af. CG04 cg04ffff. CG12 cg12ffff.
         AL03 al03ffff. AL04 al04ffff. MJ04 mj04ffff.
         MJ05 mj05ffff. CC04 cc04ffff. CC05 cc05ffff.
         CK04 ck04ffff. CK05 ck05ffff. HE04 he04ffff.
         HE05 he05ffff. LS04 ls04ffff. LS05 ls05ffff.
         LS07 ls07ffff. LS08 ls08ffff. IN04 in04ffff.
         IN05 in05ffff. PK04 pk04ffff. PK05 pk05ffff.
         TR04 tr04ffff. TR05 tr05ffff. ST04 st04ffff.
         ST05 st05ffff. SE04 se04ffff. SE05 se05ffff.
         SKPSDRD skpsdrd. SDREAD sdread. HRANYFRM hranyfrm.
         HERSMOKE hersmoke. HRSMKREC hrsmkrec. HERSNIFF hersniff.
         HRSNFREC hrsnfrec. GNNDLLIF gnndllif. COCNEEDL cocneedl.
         CONDLREC condlrec. HERNEEDL herneedl. HRNDLREC hrndlrec.
         STNEEDLE stneedle. STNDLREC stndlrec. GNNDREUS gnndreus.
         GNNDLSH1 gnndlshf. GNNDCLEN gnndclen. GNNDLSH2 gnndls0f.
         GNNDGET gnndget. GNNDGTSP gnndgtsp. SKPRSKRD skprskrd.
         RSKREAD rskread. RSKPKCIG rskpkcig. RSKMJOCC rskmjocc.
         RSKMJREG rskmjreg. RKTRYLSD rktrylsd. RKLSDREG rklsdreg.
         RKTRYHER rktryher. RKHERREG rkherreg. RKCOCOCC rkcococc.
         RKCOCREG rkcocreg. RK5DRINK rk5drink. RSKBINGE rskbinge.
         RSKDIFMJ rskdifmj. RKDIFLSD rkdiflsd. RKDIFCOC rkdifcoc.
         RKDIFCRK rkdifcrk. RKDIFHER rkdifher. RSKSELL rsksell.
         RKFQDNGR rkfqdngr. RKFQRSKY rkfqrsky. RKFQPBLT rkfqpblt.
         RKFQDBLT rkfqdblt. SKPDRGRD skpdrgrd. DRGREAD drgread.
         USEDCIG usedcig. USEDALC usedalc. USEDMRJ usedmrj.
         USEDCOC usedcoc. USEDHER usedher. USEDHAL usedhal.
         USEDINH usedinh. USEDANL usedanl. USEDTRN usedtrn.
         USEDSTM usedstm. USEDSED usedsed. NODRUGYR nodrugyr.
         GRTMCIG grtmcig. GRTMALC grtmalc. GRTMMRJ grtmmrj.
         GRTMCOC grtmcoc. GRTMHER grtmher. GRTMHAL grtmhal.
         GRTMINH grtminh. GRTMANL grtmanl. GRTMTRN grtmtrn.
         GRTMSTM grtmstm. GRTMSED grtmsed. LAMTCIG lamtcig.
         LAMTALC lamtalc. LAMTMRJ lamtmrj. LAMTCOC lamtcoc.
         LAMTHER lamther. LAMTHAL lamthal. LAMTINH lamtinh.
         LAMTANL lamtanl. LAMTTRN lamttrn. LAMTSTM lamtstm.
         LAMTSED lamtsed. BTOLCIG btolcig. BTOLALC btolalc.
         BTOLMRJ btolmrj. BTOLCOC btolcoc. BTOLHER btolher.
         BTOLHAL btolhal. BTOLINH btolinh. BTOLANL btolanl.
         BTOLTRN btoltrn. BTOLSTM btolstm. BTOLSED btolsed.
         ACRDCIG acrdcig. ACRDALC acrdalc. ACRDMRJ acrdmrj.
         ACRDCOC acrdcoc. ACRDHER acrdher. ACRDHAL acrdhal.
         ACRDINH acrdinh. ACRDANL acrdanl. ACRDTRN acrdtrn.
         ACRDSTM acrdstm. ACRDSED acrdsed. EMPBCIG empbcig.
         EMPBALC empbalc. EMPBMRJ empbmrj. EMPBCOC empbcoc.
         EMPBHER empbher. EMPBHAL empbhal. EMPBINH empbinh.
         EMPBANL empbanl. EMPBTRN empbtrn. EMPBSTM empbstm.
         EMPBSED empbsed. HLPBCIG hlpbcig. HLPBALC hlpbalc.
         HLPBMRJ hlpbmrj. HLPBCOC hlpbcoc. HLPBHER hlpbher.
         HLPBHAL hlpbhal. HLPBINH hlpbinh. HLPBANL hlpbanl.
         HLPBTRN hlpbtrn. HLPBSTM hlpbstm. HLPBSED hlpbsed.
         UCDCIG ucdcig. UCDALC ucdalc. UCDMRJ ucdmrj.
         UCDCOC ucdcoc. UCDHER ucdher. UCDHAL ucdhal.
         UCDINH ucdinh. UCDANL ucdanl. UCDTRN ucdtrn.
         UCDSTM ucdstm. UCDSED ucdsed. SKPSPTRD skpsptrd.
         SPTREAD sptread. NDTXRCVD ndtxrcvd. NDTXNEED ndtxneed.
         NDTXALC ndtxalc. NDTXMJ ndtxmj. NDTXCOC ndtxcoc.
         NDTXHER ndtxher. NDTXHAL ndtxhal. NDTXINH ndtxinh.
         NDTXANL ndtxanl. NDTXTRAN ndtxtran. NDTXSTIM ndtxstim.
         NDTXSED ndtxsed. NDTXSOD ndtxsod. NDTXDRG1 ndtxdrgf.
         NDTXDRG2 ndtxdr0f. NDTXDRG3 ndtxdr1f. NDTXDRG4 ndtxdr2f.
         NDTXDRG5 ndtxdr3f. NDTXSTEP ndtxstep. NDTXTRSP ndtxtrsp.
         NDTXTFAR ndtxtfar. NDTXBDHR ndtxbdhr. NDTXOPEN ndtxopen.
         NDTXTYPE ndtxtype. NDTXNHCV ndtxnhcv. NDTXNOCV ndtxnocv.
         NDTXCOST ndtxcost. NDTXHCAP ndtxhcap. NDTXTCMP ndtxtcmp.
         NDTXLANG ndtxlang. NDTXSPSV ndtxspsv. NDTXSOR ndtxsor.
         NDTXRSC1 ndtxrscf. BOOKED booked. NOBOOKYR nobookyr.
         BKLARCNY bklarcny. BKBURGL bkburgl. BKAGASLT bkagaslt.
         BKSMASLT bksmaslt. BKMVTHFT bkmvthft. BKROB bkrob.
         BKRAPE bkrape. BKMURDER bkmurder. BKARSON bkarson.
         BKDRVINF bkdrvinf. BKDRUNK bkdrunk. BKDRUG bkdrug.
         BKPROS bkpros. BKVANDAL bkvandal. BKOTH bkoth.
         BKOTHOFF bkothoff. PROBATON probaton. PAROLE parole.
         DRVALDR drvaldr. DRIVEAL driveal. DRIVEDR drivedr.
         SKPTMTRD skptmtrd. TMTREAD tmtread. TXEVER txever.
         TXSTRTL2 txstrtlf. TXYREVER txyrever. TXSTRTY2 txstrtyf.
         TXALHOSP txalhosp. TXALRFIN txalrfin. TXALRFOP txalrfop.
         TXALMHC txalmhc. TXALEMRG txalemrg. TXALDOC txaldoc.
         TXALJAIL txaljail. TXALSHG txalshg. TXALSOP txalsop.
         TXALSP txalsp. TXDRHOSP txdrhosp. TXDRFIN txdrfin.
         TXDRFOP txdrfop. TXDRMHC txdrmhc. TXDREMRG txdremrg.
         TXDRDOC txdrdoc. TXDRJAIL txdrjail. TXDRSHG txdrshg.
         TXDRSOP txdrsop. TXDRSP txdrsp. TXYRINS txyrins.
         TXYRCARE txyrcare. TXYRCAID txyrcaid. TXYRPUBP txyrpubp.
         TXYRSAVE txyrsave. TXYRFMLY txyrfmly. TXYRCORT txyrcort.
         TXYRMILC txyrmilc. TXYREMPL txyrempl. TXYRFREE txyrfree.
         TXYRSOS txyrsos. TXYRSP txyrsp. TXYREMG2 txyremgf.
         TXADGREC txadgrec. TXLTHOSP txlthosp. TXLTRFIN txltrfin.
         TXLTRFOP txltrfop. TXLTMHC txltmhc. TXLTEMRG txltemrg.
         TXLTDOC txltdoc. TXLTJAIL txltjail. TXLTSHG txltshg.
         TXLTSOP txltsop. TXLTSP txltsp. TXLTALC txltalc.
         TXLTMJ txltmj. TXLTCOC txltcoc. TXLTHER txlther.
         TXLTHAL txlthal. TXLTINH txltinh. TXLTANL txltanl.
         TXLTRAN txltran. TXLTSTIM txltstim. TXLTSED txltsed.
         TXLTSOD txltsod. TXLTA txlta. TXLTB txltb.
         TXLTC txltc. TXLTD txltd. TXLTE txlte.
         TXDRGA txdrga. TXDRGB txdrgb. TXDRGC txdrgc.
         TXDRGD txdrgd. TXDRGE txdrge. TXOUTC txoutc.
         TXTIME txtime. TXPDINS txpdins. TXPDCARE txpdcare.
         TXPDCAID txpdcaid. TXPDPUBP txpdpubp. TXPDSAVE txpdsave.
         TXPDFMLY txpdfmly. TXPDCORT txpdcort. TXPDMILC txpdmilc.
         TXPDEMPL txpdempl. TXPDFREE txpdfree. TXPDSOS txpdsos.
         TXPDSP txpdsp. TXENROLL txenroll. SKPDEXRD skpdexrd.
         DEXREAD dexread. DXMJRET dxmjret. DXCCRET dxccret.
         DXCGRLF dxcgrlf. DXCG50LF dxcg50lf. DXCG30US dxcg30us.
         SKPYEANS skpyeans. SKPYEXRD skpyexrd. YEXREAD yexread.
         YELIVNBR yelivnbr. YECRIME yecrime. YESELLDG yeselldg.
         YEPPHLP yepphlp. YEFMVIOL yefmviol. YESMRACE yesmrace.
         YECONFLT yeconflt. YESTFGT yestfgt. YEEMTBLD yeemtbld.
         YEPPVSIT yeppvsit. YEGRAFTI yegrafti. YESAFE yesafe.
         YEPPMOVE yeppmove. YEAPKCIG yeapkcig. YEAMJEVR yeamjevr.
         YEAMJMO yeamjmo. YEAALDLY yeaaldly. YEMV5YR2 yemv5yrf.
         YEADOCIG yeadocig. YEADOMRJ yeadomrj. YEADOALC yeadoalc.
         YEADODNK yeadodnk. YEPCHKHW yepchkhw. YEPHLPHW yephlphw.
         YEPCHORE yepchore. YEPLMTTV yeplmttv. YEPLMTSN yeplmtsn.
         YEPGDJOB yepgdjob. YEPPROUD yepproud. YEPPKCIG yeppkcig.
         YEPMJEVR yepmjevr. YEPMJMO yepmjmo. YEPALDLY yepaldly.
         YEPAR98 yepar98f. YEENRLYR yeenrlyr. YESCHFLT yeschflt.
         YESCHWRK yeschwrk. YESCHIMP yeschimp. YESCHINT yeschint.
         YETCGJOB yetcgjob. YELSTGRD yelstgrd. YESTSCIG yestscig.
         YESTSMJ yestsmj. YESTSALC yestsalc. YESTSDNK yestsdnk.
         YETRPCIG yetrpcig. YETRSCIG yetrscig. YETRPALC yetrpalc.
         YETRDALC yetrdalc. YETRPIDG yetrpidg. YETRUIDG yetruidg.
         YEYARGUP yeyargup. YEYFGTSW yeyfgtsw. YEYFGTGP yeyfgtgp.
         YEYHGUN yeyhgun. YEYSELL yeysell. YEYSTOLE yeystole.
         YEYATTAK yeyattak. YEGPKCIG yegpkcig. YEGMJEVR yegmjevr.
         YEGMJMO yegmjmo. YEGALDLY yegaldly. YEFPKCIG yefpkcig.
         YEFMJEVR yefmjevr. YEFMJMO yefmjmo. YEFALDLY yefaldly.
         YEFDCIG yefdcig. YEFDMJ yefdmj. YEFDALC yefdalc.
         YEFDDNK yefddnk. YETLKNON yetlknon. YETLKMOM yetlkmom.
         YETLKDAD yetlkdad. YETLKGPR yetlkgpr. YETLKBGF yetlkbgf.
         YETLKSIB yetlksib. YETLKSOR yetlksor. YETLKFRN yetlkfrn.
         YETLKNBR yetlknbr. YETLKTCH yetlktch. YETLKPSY yetlkpsy.
         YETLKCLG yetlkclg. YETLKSOP yetlksop. YETLKSP yetlksp.
         YETLKNR yetlknr. YEMOSNON yemosnon. YEMOSMOM yemosmom.
         YEMOSDAD yemosdad. YEMOSGPR yemosgpr. YEMOSBGF yemosbgf.
         YEMOSSIB yemossib. YEMOSSOR yemossor. YEMOSFRN yemosfrn.
         YEMOSNBR yemosnbr. YEMOSTCH yemostch. YEMOSPSY yemospsy.
         YEMOSCLG yemosclg. YEMOSSOP yemossop. YEMOSSP yemossp.
         YEMOSNR yemosnr. YEBIGBRO yebigbro. YEPRBSLV yeprbslv.
         YEVIOPRV yevioprv. YEYMCA yeymca. YESCOUTS yescouts.
         YEPRVLES yeprvles. YEDGPRGP yedgprgp. YETEMSPT yetemspt.
         YE4HCLUB ye4hclub. YESLFHLP yeslfhlp. YEBAND yeband.
         YESCHCLB yeschclb. YEVOLUNT yevolunt. YESTGOVT yestgovt.
         YEPRGSTD yeprgstd. YEJBSKIL yejbskil. YECHOIR yechoir.
         YEDECLAS yedeclas. YEDERGLR yederglr. YEDESPCL yedespcl.
         YEMSGYR yemsgyr. YEYSTRES yeystres. YEFMSTRS yefmstrs.
         SKPSENAN skpsenan. SKPSENRD skpsenrd. SENREAD senread.
         SNLIVNBR snlivnbr. SNCRIME sncrime. SNSELLDG snselldg.
         SNPPVAL snppval. SNFMVIOL snfmviol. SNSMRACE snsmrace.
         SNCONFLT snconflt. SNSTFGT snstfgt. SNEMTBLD snemtbld.
         SNPPHLP snpphlp. SNGRAFTI sngrafti. SNPPVSIT snppvsit.
         SNSAFE snsafe. SNPPMOVE snppmove. SNAPKCIG snapkcig.
         SNAMJEVR snamjevr. SNAMJMO snamjmo. SNAALDLY snaaldly.
         SNAALDRV snaaldrv. SNMV5YR2 snmv5yrf. SNPPHHLD snpphhld.
         SNINSULT sninsult. SNSRARGU snsrargu. SNSMARGU snsmargu.
         SNSPOUSE snspouse. SNSPACTV snspactv. SNSPANGR snspangr.
         SNSPHITU snsphitu. SNYHITSP snyhitsp. SNSPCRIT snspcrit.
         SNSPCONC snspconc. SNYSTRES snystres. SNFMSTRS snfmstrs.
         SNFRCONC snfrconc. SNFRACTV snfractv. SNFRCARE snfrcare.
         SNYHGUN snyhgun. SNYSELL snysell. SNYSTOLE snystole.
         SNYATTAK snyattak. SNFACIG snfacig. SNFAMJEV snfamjev.
         SNFAMJMO snfamjmo. SNFAALDY snfaaldy. SNFAALDV snfaaldv.
         SNFDCIG snfdcig. SNFDMJ snfdmj. SNFDALC snfdalc.
         SNFDDRNK snfddrnk. MOVESPY2 movespyf. EDU2NDQ2 edu2ndqf.
         STUDNT97 studnt9f. STDT9497 stdt949f. SKPSCHGR skpschgr.
         SKPSCHAG skpschag. LFTSCHRS lftschrs. LFTSCHA2 lftschaf.
         SCHDYS97 schdys9f. SCHD9497 schd949f. SKIPPD97 skippd9f.
         SKIP9497 skip949f. SKWRKAGE skwrkage. NJOBSPY2 njobspyf.
         WRKSTAT2 wrkstatf. WKST2NDQ wkst2ndq. WKSWKST wkswkst.
         SKPWKST1 skpwkstf. BUSSIZE bussize. LOCSIZE locsize.
         DRGINFO drginfo. DRGPLCY drgplcy. PLCYCOV plcycov.
         DRGPRGM drgprgm. USALCTST usalctst. USDRGTST usdrgtst.
         SKPWKTST skpwktst. TSTHIRE tsthire. TSTRAND tstrand.
         TSTSUSP tstsusp. TSTACCD tstaccd. TSTTRMT tsttrmt.
         WRKHIRE wrkhire. WRKRAND wrkrand. WRKSUSP wrksusp.
         WRKACCD wrkaccd. PAYMO paymo. PAYYR2 payyr2ff.
         ROCCUP2 roccup2f. BUSINES2 businesf. SKPWKST2 skpwks0f.
         WORKDAYS workdays. WORKBLAH workblah. JBLOSEYR jbloseyr.
         JBFNDNEW jbfndnew. JBSATIS jbsatis. QD46_2 qd46_2ff.
         SKPPREG skppreg. PREGNANT pregnant. PREGMOS pregmos.
         SKPCWE skpcwe. CWE cwe. CWESC1 cwesc1ff.
         CWESC2 cwesc2ff. FULLPART fullpart. RLGSVC98 rlgsvc9f.
         RLGIMPRT rlgimprt. RLGDECSN rlgdecsn. RLGFRNDS rlgfrnds.
         NUERTMT2 nuertmtf. NUHSPOV2 nuhspovf. NUHSPPE2 nuhsppef.
         OUTPTPE outptpe. PROXABLE proxable. PROXYREL proxyrel.
         PROXHOME proxhome. PROXJOIN proxjoin. CAREUSU careusu.
         NCARERSN ncarersn. NCRRSNSP ncrrsnsp. NCRRSNSC ncrrsnsc.
         CAREOFT careoft. PYRCARE pyrcare. PYRCRTYP pyrcrtyp.
         PYRCRTSP pyrcrtsp. PYRCRTSC pyrcrtsc. CARENOW carenow.
         MNRSNNCR mnrsnncr. MNRSNNSP mnrsnnsp. MNRSNNSC mnrsnnsc.
         UCARETYP ucaretyp. UCRTYPSP ucrtypsp. UCRTYPSC ucrtypsc.
         MEDICARE medicare. MEDICAID medicaid. CHAMPUS champus.
         PRVHLTIN prvhltin. GRPHLTIN grphltin. HLTINALC hltinalc.
         HLTINDRG hltindrg. HLTINMNT hltinmnt. SKHLCCOV skhlccov.
         HLCNOTYR hlcnotyr. HLCNOTMO hlcnotmo. HLCLAST hlclast.
         HLCPRIVT hlcprivt. HLCMCAID hlcmcaid. HLCMILT hlcmilt.
         HLCMCARE hlcmcare. HLCOGOVT hlcogovt. HLCOTHER hlcother.
         HLCOTHSP hlcothsp. HLNLOSJB hlnlosjb. HLNMAJOB hlnmajob.
         HLNMASOR hlnmasor. HLNCOST hlncost. HLNINELG hlninelg.
         HLNNOFFR hlnnoffr. HLNDIVOR hlndivor. HLNDEATH hlndeath.
         HLNREFUS hlnrefus. HLNNONED hlnnoned. HLNSOR hlnsor.
         HLNSORSP hlnsorsp. SOC1 soc1ffff. SOC2 soc2ffff.
         SSI1 ssi1ffff. SSI2 ssi2ffff. PMT1 pmt1ffff.
         PMT2 pmt2ffff. AFDC afdc. FSTAMP fstamp.
         SVC1 svc1ffff. SVC2 svc2ffff. WELFARE welfare.
         WELMOS welmos. INT1 int1ffff. INT2 int2ffff.
         CHD1 chd1ffff. CHD2 chd2ffff. WAGE1 wage1fff.
         WAGE2 wage2fff. OTH1 oth1ffff. OTH2 oth2ffff.
         PINC1 pinc1fff. PINC2 pinc2fff. SKPTFMIN skptfmin.
         FINC1 finc1fff. FINC2 finc2fff. TELNO2 telno2ff.
         IRPINSUR irpinsur. IIPINSUR iipinsur. IRINSUR irinsur.
         IIINSUR iiinsur. IRSOC1 irsoc1ff. IISOC1 iisoc1ff.
         IRSSI1 irssi1ff. IISSI1 iissi1ff. IRPMT1 irpmt1ff.
         IIPMT1 iipmt1ff. IRAFDC irafdc. IIAFDC iiafdc.
         IRFSTAMP irfstamp. IIFSTAMP iifstamp. IRSVC1 irsvc1ff.
         IISVC1 iisvc1ff. IRWELMOS irwelmos. IIWELMOS iiwelmos.
         IRINT1 irint1ff. IIINT1 iiint1ff. IRCHD1 irchd1ff.
         IICHD1 iichd1ff. IRWAGE1 irwage1f. IIWAGE1 iiwage1f.
         IROTH1 iroth1ff. IIOTH1 iioth1ff. IRPINC1 irpinc1f.
         IIPINC1 iipinc1f. IRFINC1 irfinc1f. IIFINC1 iifinc1f.
         IRSOC2 irsoc2ff. IISOC2 iisoc2ff. IRSSI2 irssi2ff.
         IISSI2 iissi2ff. IRPMT2 irpmt2ff. IIPMT2 iipmt2ff.
         IRSVC2 irsvc2ff. IISVC2 iisvc2ff. IRINT2 irint2ff.
         IIINT2 iiint2ff. IRCHD2 irchd2ff. IICHD2 iichd2ff.
         IRWAGE2 irwage2f. IIWAGE2 iiwage2f. IROTH2 iroth2ff.
         IIOTH2 iioth2ff. IRPINC2 irpinc2f. IIPINC2 iipinc2f.
         IRFINC2 irfinc2f. IIFINC2 iifinc2f. F15_44 f15_44ff.
         M15_44 m15_44ff. PREG preg. PREG2 preg2fff.
         TRIMEST trimest. NEEDLREC needlrec. NEDFLAG4 nedflagf.
         NEDYR4 nedyr4ff. HERSMOK2 hersmokf. HERSNIF2 hersni0f.
         ALCDEP alcdep. MRJDEP mrjdep. SUMDEP sumdep.
         HLTPRALC hltpralc. HLTPRMRJ hltprmrj. HLTPRSUM hltprsum.
         PSYPRALC psypralc. PSYPRMRJ psyprmrj. PSYPRSUM psyprsum.
         ALCTRT alctrt. MRJTRT mrjtrt. SUMTRT sumtrt.
         CIGARMON cigarmon. CIGRLIFE cigrlife. IRCGRLF ircgrlf.
         IRCGRMN ircgrmn. IICGRLF iicgrlf. IICGRMN iicgrmn.
         CGRFLAG cgrflag. CGRMON cgrmon. ACTALL actall.
         ACTSEL actsel. ADFLALDY adflaldy. ADFLPKCG adflpkcg.
         ADFLTMRJ adfltmrj. ADFLUMRJ adflumrj. ADULTALC adultalc.
         ADULTCIG adultcig. ADULTDRK adultdrk. ADULTMRJ adultmrj.
         ANYEDUC anyeduc. DRGRGCLS drgrgcls. DRGSPCLS drgspcls.
         DRPRVMES drprvmes. DRUGLECT druglect. ENROLLYR enrollyr.
         FAMSTRES famstres. FRDALDLY frdaldly. FRDMJEVR frdmjevr.
         FRDMJMO frdmjmo. FRDPKCIG frdpkcig. FRNDALC frndalc.
         FRNDCIG frndcig. FRNDDNK frnddnk. FRNDMJ frndmj.
         LIVNBRHD livnbrhd. MOSFRN mosfrn. MOSNON mosnon.
         MOSOTHER mosother. MOSPARNT mosparnt. NGHDBLDG nghdbldg.
         NGHDCNFT nghdcnft. NGHDCRIM nghdcrim. NGHDFGHT nghdfght.
         NGHDGRAF nghdgraf. NGHDHELP nghdhelp. NGHDMOVE nghdmove.
         NGHDRACE nghdrace. NGHDSAFE nghdsafe. NGHDSELL nghdsell.
         NGHDVIOL nghdviol. NGHDVSIT nghdvsit. PARALDLY paraldly.
         PARCHKHW parchkhw. PARCHORE parchore. PARGDJOB pargdjob.
         PARHLPHW parhlphw. PARLMTSN parlmtsn. PARLMTTV parlmttv.
         PARMJEVR parmjevr. PARMJMO parmjmo. PARPKCIG parpkcig.
         PARPROUD parproud. PRTALK98 prtalk9f. SCHFELT schfelt.
         SCHGDJOB schgdjob. SCHGRADE schgrade. SCHIMPRT schimprt.
         SCHINTRT schintrt. SCHWORK schwork. STDNDALC stdndalc.
         STDNPALC stdnpalc. STDNPCIG stdnpcig. STDNPIDG stdnpidg.
         STDNSCIG stdnscig. STDNUIDG stdnuidg. STDNTALC stdntalc.
         STDNTCIG stdntcig. STDNTDNK stdntdnk. STDNTMJ stdntmj.
         STRESPYR strespyr. TLKADULT tlkadult. TLKBGF tlkbgf.
         TLKDAD tlkdad. TLKMOM tlkmom. TLKNON tlknon.
         TLKNONAD tlknonad. TLKOTHER tlkother. YTFLADLY ytfladly.
         YTFLPKCG ytflpkcg. YTFLTMRJ ytfltmrj. YTFLUMRJ ytflumrj.
         YTHARGUE ythargue. YTHATTAK ythattak. YTHFIGHT ythfight.
         YTHGRPFT ythgrpft. YTHHGUN ythhgun. YTHSELL ythsell.
         YTHSTOLE ythstole. EIIDATE eiidate. BHOUR bhour.
         BMIN bmin. BAP bap. ETIMEHR etimehr.
         ETIMEMN etimemn. EAP eap. LANGVER langver.
         UNDINT undint. COOPINT coopint. PRIVACY privacy.
         PPRES ppres. SPRES spres. PARPRES parpres.
         OARPRES oarpres. OAPRES oapres. CPRES cpres.
         OPRESNSP opresnsp. OPRESSPA opresspa. OPRESSPB opresspb.
         WHOMARKD whomarkd. QUARTER quarter. GQTYPE gqtype.
         PDEN pden. PDEN2 pden2fff. REGION region.
         DIVIS2 divis2ff. BPCONC bpconc. NHNBPCON nhnbpcon.
         NHNBHCON nhnbhcon. HSPHCONC hsphconc. HSPPCONC hsppconc.
         NHBHCONC nhbhconc. NHBPCONC nhbpconc. OWNOCONC ownoconc.
         RURORURB rurorurb. URBPCT2 urbpct2f. ALCDAYS2 alcdaysf.
         ALCDAYS3 alcday0f. ALCILLL alcilll. ALCILLM alcillm.
         ALCILLY alcilly. ALCMRJL alcmrjl. ALCMRJM alcmrjm.
         ALCMRJY alcmrjy. ALCONLYL alconlyl. ALCONLYM alconlym.
         ALCONLYY alconlyy. ALCOTHL alcothl. ALCOTHM alcothm.
         ALCOTHY alcothy. ALCPRBS3 alcprbsf. ALC2PRB3 alc2prbf.
         ALC3PRB3 alc3prbf. ALCPSYL alcpsyl. ALCPSYM alcpsym.
         ALCPSYY alcpsyy. ALCTRY2 alctry2f. ALCUSE alcuse.
         ANALAGE2 analagef. AVCIG2 avcig2ff. AVCIG3 avcig3ff.
         BINGDRK2 bingdrkf. BKAGASL2 bkagaslf. BKANYLAW bkanylaw.
         BKARSON2 bkarsonf. BKBURGL2 bkburglf. BKDRUG2 bkdrug2f.
         BKDRUNK2 bkdrunkf. BKDRVIN2 bkdrvi0f. BKLARCN2 bklarcnf.
         BKMVTHF2 bkmvthff. BKROB2 bkrob2ff. BKSMASL2 bksmaslf.
         CIGPRBS3 cigprbsf. CIG2PRB3 cig2prbf. CIG3PRB3 cig3prbf.
         CIGTRY2 cigtry2f. COCPRBS3 cocprbsf. COC2PRB3 coc2prbf.
         COC3PRB3 coc3prbf. COCAGE2 cocage2f. COCTOT3 coctot3f.
         COCUSE cocuse. DRALHLP3 dralhlpf. DRINKER2 drinkerf.
         DRNKHLP3 drnkhlpf. DROPMF dropmf. DRUNKYR2 drunkyrf.
         DUI dui. FERTAGE fertage. HALLAGE2 hallagef.
         HERAGE2 herage2f. HERNEED2 herneedf. HVYDRK3 hvydrk3f.
         ILLONLYL illonlyl. ILLONLYM illonlym. ILLONLYY illonlyy.
         INHAGE2 inhage2f. IRACALC3 iracalcf. IRACCIG3 iraccigf.
         IRACCOC3 iraccocf. IRACMRJ3 iracmrjf. IRBTALC3 irbtalcf.
         IRBTCIG3 irbtcigf. IRBTCOC3 irbtcocf. IRBTMRJ3 irbtmrjf.
         IREMALC3 iremalcf. IREMCIG3 iremcigf. IREMCOC3 iremcocf.
         IREMMRJ3 iremmrjf. IRGRALC3 irgralcf. IRGRCIG3 irgrcigf.
         IRGRCOC3 irgrcocf. IRGRMRJ3 irgrmrjf. IRHLALC3 irhlalcf.
         IRHLCIG3 irhlcigf. IRHLCOC3 irhlcocf. IRHLMRJ3 irhlmrjf.
         IRLAALC3 irlaalcf. IRLACIG3 irlacigf. IRLACOC3 irlacocf.
         IRLAMRJ3 irlamrjf. IRUCALC3 irucalcf. IRUCCIG3 iruccigf.
         IRUCCOC3 iruccocf. IRUCMRJ3 irucmrjf. MARUSE maruse.
         MJAGE2 mjage2ff. MJTOT3 mjtot3ff. MRJPRBS3 mrjprbsf.
         MRJ2PRB3 mrj2prbf. MRJ3PRB3 mrj3prbf. MRJONLYL mrjonlyl.
         MRJONLYM mrjonlym. MRJONLYY mrjonlyy. NOTMARJ notmarj.
         OTHONLYL othonlyl. OTHONLYM othonlym. OTHONLYY othonlyy.
         PREG3 preg3fff. PSYAGE psyage. PSYONLYL psyonlyl.
         PSYONLYM psyonlym. PSYONLYY psyonlyy. RACESEX racesex.
         RACESEX2 racesexf. RDIFCOC rdifcoc. RDIFCRK rdifcrk.
         RDIFHER rdifher. RDIFLSD rdiflsd. RDIFMJ rdifmj.
         RSKALC1 rskalc1f. RSKALC2 rskalc2f. RSKCIG rskcig.
         RSKCOC1 rskcoc1f. RSKCOC2 rskcoc2f. RSKHER1 rskher1f.
         RSKHER2 rskher2f. RSKLSD1 rsklsd1f. RSKMJ1 rskmj1ff.
         RSKMJ2 rskmj2ff. RSKSELL2 rsksellf. SBELTRSK sbeltrsk.
         SEDAGE2 sedage2f. STIMAGE2 stimagef. SUB1LIF sub1lif.
         SUB1MON sub1mon. SUB1YR sub1yr. SUB2LIF sub2lif.
         SUB2MON sub2mon. SUB2YR sub2yr. SUB3LIF sub3lif.
         SUB3MON sub3mon. SUB3YR sub3yr. TRANAGE2 tranagef.
         TRIMEST2 trimestf. TRMTHLP3 trmthlpf.  ;

RUN ;
